=== modified file 'bzrlib/bundle/__init__.py'
--- bzrlib/bundle/__init__.py	2009-07-20 02:04:21 +0000
+++ bzrlib/bundle/__init__.py	2009-11-28 00:48:03 +0000
@@ -14,6 +14,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+from cStringIO import StringIO
+
 from bzrlib.symbol_versioning import deprecated_function, deprecated_in
 from bzrlib.lazy_import import lazy_import
 lazy_import(globals(), """
@@ -22,6 +24,7 @@
     urlutils,
     )
 from bzrlib.bundle import serializer as _serializer
+from bzrlib.merge_directive import MergeDirective
 from bzrlib.transport import (
     do_catching_redirections,
     get_transport,
@@ -51,33 +54,22 @@
 
 
 def read_mergeable_from_transport(transport, filename, _do_directive=True):
-    # All of this must be in the try/except
-    # Some transports cannot detect that we are trying to read a
-    # directory until we actually issue read() on the handle.
+    def get_bundle(transport):
+        return StringIO(transport.get_bytes(filename)), transport
+
+    def redirected_transport(transport, exception, redirection_notice):
+        note(redirection_notice)
+        url, filename = urlutils.split(exception.target,
+                                       exclude_trailing_slash=False)
+        if not filename:
+            raise errors.NotABundle('A directory cannot be a bundle')
+        return get_transport(url)
+
     try:
-        def get_bundle(transport):
-            return transport.get(filename), transport
-
-        def redirected_transport(transport, exception, redirection_notice):
-            note(redirection_notice)
-            url, filename = urlutils.split(exception.target,
-                                           exclude_trailing_slash=False)
-            if not filename:
-                raise errors.NotABundle('A directory cannot be a bundle')
-            return get_transport(url)
-
-        try:
-            f, transport = do_catching_redirections(get_bundle, transport,
+        bytef, transport = do_catching_redirections(get_bundle, transport,
                                                     redirected_transport)
-        except errors.TooManyRedirections:
-            raise errors.NotABundle(transport.clone(filename).base)
-
-        if _do_directive:
-            from bzrlib.merge_directive import MergeDirective
-            directive = MergeDirective.from_lines(f.readlines())
-            return directive, transport
-        else:
-            return _serializer.read_bundle(f), transport
+    except errors.TooManyRedirections:
+        raise errors.NotABundle(transport.clone(filename).base)
     except (errors.ConnectionReset, errors.ConnectionError), e:
         raise
     except (errors.TransportError, errors.PathError), e:
@@ -91,6 +83,11 @@
         # StubSFTPServer does fail during get() (because of prefetch)
         # so it has an opportunity to translate the error.
         raise errors.NotABundle(str(e))
-    except errors.NotAMergeDirective:
-        f.seek(0)
-        return _serializer.read_bundle(f), transport
+
+    if _do_directive:
+        try:
+            return MergeDirective.from_lines(bytef), transport
+        except errors.NotAMergeDirective:
+            bytef.seek(0)
+
+    return _serializer.read_bundle(bytef), transport

=== modified file 'bzrlib/merge_directive.py'
--- bzrlib/merge_directive.py	2009-10-29 05:49:32 +0000
+++ bzrlib/merge_directive.py	2009-11-28 00:48:03 +0000
@@ -371,15 +371,13 @@
         :return: a MergeRequest
         """
         line_iter = iter(lines)
+        firstline = ""
         for line in line_iter:
             if line.startswith('# Bazaar merge directive format '):
-                break
-        else:
-            if len(lines) > 0:
-                raise errors.NotAMergeDirective(lines[0])
-            else:
-                raise errors.NotAMergeDirective('')
-        return _format_registry.get(line[2:].rstrip())._from_lines(line_iter)
+                return _format_registry.get(line[2:].rstrip())._from_lines(
+                    line_iter)
+            firstline = firstline or line.strip()
+        raise errors.NotAMergeDirective(firstline)
 
     @classmethod
     def _from_lines(klass, line_iter):

=== modified file 'bzrlib/tests/blackbox/test_merge.py'
--- bzrlib/tests/blackbox/test_merge.py	2009-10-06 14:40:37 +0000
+++ bzrlib/tests/blackbox/test_merge.py	2009-11-09 00:39:44 +0000
@@ -589,6 +589,18 @@
         self.run_bzr('merge -d this other -r0..')
         self.failUnlessExists('this/other_file')
 
+    def test_merge_reversed_revision_range(self):
+        tree = self.make_branch_and_tree(".")
+        for f in ("a", "b"):
+            self.build_tree([f])
+            tree.add(f)
+            tree.commit("added "+f)
+        for context in (".", "", "a"):
+            self.run_bzr("merge -r 1..0 " + context)
+            self.failIfExists("a")
+            tree.revert()
+            self.failUnlessExists("a")
+
 
 class TestMergeForce(tests.TestCaseWithTransport):
 

=== modified file 'bzrlib/tests/blackbox/test_send.py'
--- bzrlib/tests/blackbox/test_send.py	2009-10-02 07:24:29 +0000
+++ bzrlib/tests/blackbox/test_send.py	2009-11-28 00:48:03 +0000
@@ -67,7 +67,7 @@
 
     def get_MD(self, args, cmd=None, wd='branch'):
         out = StringIO(self.run_send(args, cmd=cmd, wd=wd)[0])
-        return merge_directive.MergeDirective.from_lines(out.readlines())
+        return merge_directive.MergeDirective.from_lines(out)
 
     def assertBundleContains(self, revs, args, cmd=None, wd='branch'):
         md = self.get_MD(args, cmd=cmd, wd=wd)
@@ -322,8 +322,7 @@
         out, err = self.run_send(args)
         self.assertEquals(
             'Bundling %d revision(s).\n' % len(revs), err)
-        md = merge_directive.MergeDirective.from_lines(
-                StringIO(out).readlines())
+        md = merge_directive.MergeDirective.from_lines(StringIO(out))
         self.assertEqual('parent', md.base_revision_id)
         br = serializer.read_bundle(StringIO(md.get_raw_bundle()))
         self.assertEqual(set(revs), set(r.revision_id for r in br.revisions))

=== modified file 'doc/default.css'
--- doc/default.css	2009-09-10 02:09:26 +0000
+++ doc/default.css	2009-12-02 20:34:07 +0000
@@ -51,7 +51,7 @@
   }
 
 h1 {
-  color: #b52b2b; 
+  color: #b52b2b;
   /* DKREDcolor: #966b72; */
   /* GREY color: #444444; */
   font-size: 1.5em;
@@ -60,7 +60,7 @@
 h1 a:link {
   color: inherit;
   }
-  
+
 h1 a:hover {
   color: inherit;
   }
@@ -89,7 +89,7 @@
   }
 
 h3 {
-  color: #966b72; 
+  color: #966b72;
   /* color: #966b72; */
   }
 
@@ -114,7 +114,7 @@
   padding: 1ex;
   background: #7777FF;
         }
-dt:hover 
+dt:hover
   {
   background-color: black;
   }

=== modified file 'doc/developers/HACKING.txt'
--- doc/developers/HACKING.txt	2009-10-08 01:50:30 +0000
+++ doc/developers/HACKING.txt	2009-12-02 20:34:07 +0000
@@ -2,7 +2,7 @@
 Bazaar Developer Guide
 ======================
 
-This document describes the Bazaar internals and the development process.  
+This document describes the Bazaar internals and the development process.
 It's meant for people interested in developing Bazaar, and some parts will
 also be useful to people developing Bazaar plugins.
 
@@ -64,7 +64,7 @@
 
 * you get to build on the wisdom on others, saving time
 
-* if others can direct you to similar code, it minimises the work to be done 
+* if others can direct you to similar code, it minimises the work to be done
 
 * it assists everyone in coordinating direction, priorities and effort.
 
@@ -87,7 +87,7 @@
 -----------------
 
 First, get a local copy of the development mainline (See `Why make a local
-copy of bzr.dev?`_.) 
+copy of bzr.dev?`_.)
 ::
 
  $ bzr init-repo ~/bzr
@@ -100,7 +100,7 @@
 
 This will give you a branch called "123456-my-bugfix" that you can work on
 and commit in. Here, you can study the code, make a fix or a new feature.
-Feel free to commit early and often (after all, it's your branch!). 
+Feel free to commit early and often (after all, it's your branch!).
 
 Documentation improvements are an easy place to get started giving back to the
 Bazaar project.  The documentation is in the `doc/` subdirectory of the Bazaar
@@ -133,14 +133,14 @@
 Making a local mirror of bzr.dev is not strictly necessary, but it means
 
 - You can use that copy of bzr.dev as your main bzr executable, and keep it
-  up-to-date using ``bzr pull``.  
+  up-to-date using ``bzr pull``.
 - Certain operations are faster, and can be done when offline.  For example:
 
   - ``bzr bundle``
   - ``bzr diff -r ancestor:...``
   - ``bzr merge``
 
-- When it's time to create your next branch, it's more convenient.  When you 
+- When it's time to create your next branch, it's more convenient.  When you
   have further contributions to make, you should do them in their own branch::
 
     $ cd ~/bzr
@@ -193,9 +193,9 @@
 
 * create a local copy of the main development branch (bzr.dev) by using
   this command::
-  
+
     bzr branch http://bazaar-vcs.org/bzr/bzr.dev/ bzr.dev
-   
+
 * keep your copy of bzr.dev pristine (by not developing in it) and keep
   it up to date (by using bzr pull)
 
@@ -222,10 +222,10 @@
 
 README
     This file covers a brief introduction to Bazaar and lists some of its
-    key features. 
+    key features.
 
 NEWS
-    Summary of changes in each Bazaar release that can affect users or 
+    Summary of changes in each Bazaar release that can affect users or
     plugin developers.
 
 setup.py
@@ -237,7 +237,7 @@
     with this but don't be confused by it. The build process puts a copy
     of the main code base into this build directory, along with some other
     files. You don't need to go in here for anything discussed in this
-    guide. 
+    guide.
 
 bzrlib
     Possibly the most exciting folder of all, bzrlib holds the main code
@@ -248,17 +248,17 @@
     Holds documentation on a whole range of things on Bazaar from the
     origination of ideas within the project to information on Bazaar
     features and use cases.  Within this directory there is a subdirectory
-    for each translation into a human language.  All the documentation 
+    for each translation into a human language.  All the documentation
     is in the ReStructuredText markup language.
 
-doc/developers 
+doc/developers
     Documentation specifically targeted at Bazaar and plugin developers.
     (Including this document.)
-    
-        
-
-Automatically-generated API reference information is available at 
-<http://starship.python.net/crew/mwh/bzrlibapi/>.  
+
+
+
+Automatically-generated API reference information is available at
+<http://starship.python.net/crew/mwh/bzrlibapi/>.
 
 See also the `Bazaar Architectural Overview
 <http://doc.bazaar-vcs.org/developers/overview.html>`_.
@@ -291,7 +291,7 @@
 
 * **how** this change achieves this purpose
 
-* anything else you may have fixed in passing 
+* anything else you may have fixed in passing
 
 * anything significant that you thought of doing, such as a more
   extensive fix or a different approach, but didn't or couldn't do now
@@ -336,7 +336,7 @@
 welcome that only cleanup the code without changing the external
 behaviour.  The core developers take care to keep the code quality high
 and understandable while recognising that perfect is sometimes the enemy
-of good. 
+of good.
 
 It is easy for reviews to make people notice other things which should be
 fixed but those things should not hold up the original fix being accepted.
@@ -378,7 +378,7 @@
 ====================
 
 From May 2009 on, we prefer people to propose code reviews through
-Launchpad.  
+Launchpad.
 
  * <https://launchpad.net/+tour/code-review>
 
@@ -403,7 +403,7 @@
 Then go to the branch's web page, which in this case would be
 <https://code.launchpad.net/~mbp/bzr/doc>.  You can simplify this step by just
 running ::
- 
+
   bzr lp-open
 
 You can then click "Propose for merging into another branch", and enter your
@@ -425,7 +425,7 @@
 You can generate a merge request like this::
 
   bzr send -o bug-1234.diff
-  
+
 ``bzr send`` can also send mail directly if you prefer; see the help.
 
 Reviewing changes
@@ -457,7 +457,7 @@
 You can generate a merge request like this::
 
   bzr send -o bug-1234.patch
-  
+
 A ``.patch`` extension is recommended instead of .bundle as many mail clients
 will send the latter as a binary file.
 
@@ -512,7 +512,7 @@
 Code layout
 ===========
 
-Please write PEP-8__ compliant code.  
+Please write PEP-8__ compliant code.
 
 __ http://www.python.org/peps/pep-0008.html
 
@@ -530,7 +530,7 @@
 Each file must have a newline at the end of it.
 
 Lines should be no more than 79 characters if at all possible.
-Lines that continue a long statement may be indented in either of 
+Lines that continue a long statement may be indented in either of
 two ways:
 
 within the parenthesis or other character that opens the block, e.g.::
@@ -623,7 +623,7 @@
 Functions, methods or members that are relatively private are given
 a leading underscore prefix.  Names without a leading underscore are
 public not just across modules but to programmers using bzrlib as an
-API. 
+API.
 
 We prefer class names to be concatenated capital words (``TestCase``)
 and variables, methods and functions to be lowercase words joined by
@@ -702,8 +702,8 @@
 Registries
 ==========
 
-Several places in Bazaar use (or will use) a registry, which is a 
-mapping from names to objects or classes.  The registry allows for 
+Several places in Bazaar use (or will use) a registry, which is a
+mapping from names to objects or classes.  The registry allows for
 loading in registered code only when it's needed, and keeping
 associated information such as a help string or description.
 
@@ -713,13 +713,13 @@
 
 The ``InterObject`` provides for two-way `multiple dispatch`__: matching
 up for example a source and destination repository to find the right way
-to transfer data between them. 
+to transfer data between them.
 
 .. __: http://en.wikipedia.org/wiki/Multiple_dispatch
 
 There is a subclass ``InterObject`` classes for each type of object that is
 dispatched this way, e.g. ``InterRepository``.  Calling ``.get()`` on this
-class will return an ``InterObject`` instance providing the best match for 
+class will return an ``InterObject`` instance providing the best match for
 those parameters, and this instance then has methods for operations
 between the objects.
 
@@ -806,7 +806,7 @@
 
 If you add a new class you should generally add a ``__repr__`` method
 unless there is an adequate method in a parent class.  There should be a
-test for the repr.  
+test for the repr.
 
 Representations should typically look like Python constructor syntax, but
 they don't need to include every value in the object and they don't need
@@ -869,7 +869,7 @@
 way, you need to change its name as well. For instance, if I add an optional keyword
 parameter to branch.commit - that's fine. On the other hand, if I add a
 keyword parameter to branch.commit which is a *required* transaction
-object, I should rename the API - i.e. to 'branch.commit_transaction'. 
+object, I should rename the API - i.e. to 'branch.commit_transaction'.
 
   (Actually, that may break code that provides a new implementation of
   ``commit`` and doesn't expect to receive the parameter.)
@@ -1039,8 +1039,8 @@
 
     0. OK.
     1. Conflicts in merge-like operations, or changes are present in
-       diff-like operations. 
-    2. Unrepresentable diff changes (i.e. binary files that we cannot show 
+       diff-like operations.
+    2. Unrepresentable diff changes (i.e. binary files that we cannot show
        a diff of).
     3. An error or exception has occurred.
     4. An internal error occurred (one that shows a traceback.)
@@ -1077,13 +1077,13 @@
 format string.
 
 #. If it is something that a caller can recover from, a custom exception
-   is reasonable. 
+   is reasonable.
 
 #. If it is a data consistency issue, using a builtin like
-   ``ValueError``/``TypeError`` is reasonable. 
+   ``ValueError``/``TypeError`` is reasonable.
 
 #. If it is a programmer error (using an api incorrectly)
-   ``AssertionError`` is reasonable. 
+   ``AssertionError`` is reasonable.
 
 #. Otherwise, use ``BzrError`` or ``InternalBzrError``.
 
@@ -1142,7 +1142,7 @@
 Within each release, entries in the news file should have the most
 user-visible changes first.  So the order should be approximately:
 
- * changes to existing behaviour - the highest priority because the 
+ * changes to existing behaviour - the highest priority because the
    user's existing knowledge is incorrect
  * new features - should be brought to their attention
  * bug fixes - may be of interest if the bug was affecting them, and
@@ -1167,7 +1167,7 @@
 -----------------
 
 Functions, methods, classes and modules should have docstrings
-describing how they are used. 
+describing how they are used.
 
 The first line of the docstring should be a self-contained sentence.
 
@@ -1198,13 +1198,13 @@
     We had the problem that lots of our files were "Copyright Canonical
     Development Ltd" which is not a real company, and some other variations
     on this theme. Also, some files were missing the GPL statements.
-    
+
     I want to be clear about the intent of this patch, since copyright can
     be a little controversial.
-    
+
     1) The big motivation for this is not to shut out the community, but
     just to clean up all of the invalid copyright statements.
-    
+
     2) It has been the general policy for bzr that we want a single
     copyright holder for all of the core code. This is following the model
     set by the FSF, which makes it easier to update the code to a new
@@ -1217,15 +1217,15 @@
     I'm sure Canonical would do the same).
     As such, Canonical has requested copyright assignments from all of the
     major contributers.
-    
+
     3) If someone wants to add code and not attribute it to Canonical, there
     is a specific list of files that are excluded from this check. And the
     test failure indicates where that is, and how to update it.
-    
+
     4) If anyone feels that I changed a copyright statement incorrectly, just
     let me know, and I'll be happy to correct it. Whenever you have large
     mechanical changes like this, it is possible to make some mistakes.
-    
+
     Just to reiterate, this is a community project, and it is meant to stay
     that way. Core bzr code is copyright Canonical for legal reasons, and
     the tests are just there to help us maintain that.
@@ -1242,7 +1242,7 @@
 
 .. _pdb: http://docs.python.org/lib/debugger-commands.html
 
-If the ``BZR_PDB`` environment variable is set 
+If the ``BZR_PDB`` environment variable is set
 then bzr will go into pdb post-mortem mode when an unhandled exception
 occurs.
 
@@ -1310,7 +1310,7 @@
     for automated processing.
     For example: ``bzr log`` should not fail if one of the entries has text
     that cannot be displayed.
-  
+
   strict
     Attempting to print an unprintable character will cause a UnicodeError.
     This is for commands that are intended more as scripting support, rather
@@ -1320,7 +1320,7 @@
     printed a filename with a '?', the wrong file could be deleted. (At the
     very least, the correct file would not be deleted). An error is used to
     indicate that the requested action could not be performed.
-  
+
   exact
     Do not attempt to automatically convert Unicode strings. This is used
     for commands that must handle conversion themselves.
@@ -1374,16 +1374,16 @@
 
 To create an extension, add rules to setup.py for building it with pyrex,
 and with distutils. Now start with an empty .pyx file. At the top add
-"include 'yourmodule.py'". This will import the contents of foo.py into this 
+"include 'yourmodule.py'". This will import the contents of foo.py into this
 file at build time - remember that only one module will be loaded at
 runtime. Now you can subclass classes, or replace functions, and only your
 changes need to be present in the .pyx file.
 
 Note that pyrex does not support all 2.4 programming idioms, so some
-syntax changes may be required. I.e. 
+syntax changes may be required. I.e.
 
- - 'from foo import (bar, gam)' needs to change to not use the brackets. 
- - 'import foo.bar as bar' needs to be 'import foo.bar; bar = foo.bar' 
+ - 'from foo import (bar, gam)' needs to change to not use the brackets.
+ - 'import foo.bar as bar' needs to be 'import foo.bar; bar = foo.bar'
 
 If the changes are too dramatic, consider
 maintaining the python code twice - once in the .pyx, and once in the .py,
@@ -1666,7 +1666,7 @@
 .. note::
   As well as prioritizing bugs and nominating them against a
   target milestone, Launchpad lets core developers offer to mentor others in
-  fixing them. 
+  fixing them.
 
 
 ..

=== modified file 'doc/developers/add.txt'
--- doc/developers/add.txt	2007-06-05 08:02:04 +0000
+++ doc/developers/add.txt	2009-12-02 20:34:07 +0000
@@ -28,7 +28,7 @@
 ------------------
 
 #. If the path is versioned, and it is a directory, push onto the recurse stack.
-#. If the path is supplied by the user or is not ignored, version it, and if a 
+#. If the path is supplied by the user or is not ignored, version it, and if a
    directory, push onto the recurse stack. Versioning the path may require
    versioning the paths parents.
 #. Output or otherwise record the ignored rule as per the user interface selected.

=== modified file 'doc/developers/api-versioning.txt'
--- doc/developers/api-versioning.txt	2009-01-23 18:44:10 +0000
+++ doc/developers/api-versioning.txt	2009-12-02 20:34:07 +0000
@@ -86,8 +86,8 @@
 with ``(0, 18, 0)``.
 
 +------------+---------------+
-| API        | Covers        | 
-+============+===============+ 
+| API        | Covers        |
++============+===============+
 | bzrlib     | All of bzrlib |
 +------------+---------------+
 

=== modified file 'doc/developers/apport.txt'
--- doc/developers/apport.txt	2009-08-13 14:31:20 +0000
+++ doc/developers/apport.txt	2009-12-02 20:34:07 +0000
@@ -37,7 +37,7 @@
 report to file later.  At the moment we just show them the filename and
 let them take it from there.
 
-The process is 
+The process is
 
 #. An exception reaches the top-level handler.
 
@@ -83,5 +83,5 @@
 
   Possibly these bugs are better reported in the next time bzr runs.
 
-.. 
+..
     vim: ft=rst

=== modified file 'doc/developers/authentication-ring.txt'
--- doc/developers/authentication-ring.txt	2009-01-08 16:57:10 +0000
+++ doc/developers/authentication-ring.txt	2009-12-02 20:34:07 +0000
@@ -88,7 +88,7 @@
 really needed is (``user``, ``password``, ``host``, ``path``). The ``realm``
 can be ignored [#ignored_realm]_ as long as it is still presented to the user
 when prompting for the password (unless someone found a way to declare two
-different realms for the same path). 
+different realms for the same path).
 
 ``HTTP proxy`` can be handled as ``HTTP`` (or ``HTTPS``) by explicitly
 specifying the appropriate port.
@@ -260,7 +260,7 @@
         host=r.hobby.net
         user=jim
         password=obvious1234
-        
+
         # Home server
         [home]
         scheme=https
@@ -269,11 +269,11 @@
         password='c2VjcmV0LXBhc3M='
         password_encoding=base64
         verify_certificates=no # Still searching a free certificate provider
-        
+
         [DEFAULT]
         # Our local user is barbaz, on all remote sites we're known as foobar
         user=foobar
-        
+
   * an HTTP server and a proxy::
 
         # development branches on dev server
@@ -283,7 +283,7 @@
         path=/dev
         user=user1
         password=pass1
-        
+
         # toy branches
         [localhost]
         scheme=http
@@ -291,7 +291,7 @@
         path=/
         user=user2
         password=pass2
-        
+
         # proxy
         [proxy]
         scheme=http

=== modified file 'doc/developers/bug-handling.txt'
--- doc/developers/bug-handling.txt	2009-09-15 05:16:50 +0000
+++ doc/developers/bug-handling.txt	2009-12-02 20:34:07 +0000
@@ -51,7 +51,7 @@
 report, but they generally care more about getting bugs fixed.
 
 The aim of investigating bugs before starting concentrated work on them is
-therefore only to: 
+therefore only to:
 
 * determine if they are critical or high priority (and
   should displace existing work)
@@ -76,7 +76,7 @@
  | One of the things you should not do often is to start asking
  | questions/for more debug info and then forget about the bug. It's just
  | a waste of the reporter's and your time, and will create frustration
- | on the reporter side. 
+ | on the reporter side.
 
 
 Priorities
@@ -85,7 +85,7 @@
 The suggested priorities for bug work are:
 
 1. Fix critical bugs.
-   
+
 2. Get existing fixes through review and landed.
 
 3. Fix bugs that are already in progress.
@@ -137,7 +137,7 @@
 Incomplete
     The bug requires more information from the reporter to make progress.
 Confirmed
-    The bug report has been seen by a developer and we agree it's a bug.  
+    The bug report has been seen by a developer and we agree it's a bug.
     You don't have to reproduce the bug to mark it confirmed.  (Generally
     it's not a good idea for a developer to spend time reproducing the bug
     until they're going to work on it.)
@@ -256,53 +256,53 @@
 authentication
     authenticating to servers
 
-backport 
+backport
     candidate for backporting to an update of the previous release
 
-dirstate 
+dirstate
     WorkingTree4
 
-easy 
+easy
     should be possible to finish in an hour or two
 
-hpss 
+hpss
     bugs about the High-Performance Smart Server, i.e. bzr+ssh://, etc.
 
-hpssvfs 
+hpssvfs
     bugs for causes of VFS methods of the smart server
 
-launchpad 
+launchpad
     bugs about interactions with launchpad (typically this means bzrlib.plugins.launchpad).
 
-locale 
+locale
     problems using locales other than English
 
-memory 
+memory
     problems where we use too much memory for some reason
 
-newformat 
+newformat
     fixing this would need a new disk format
 
-performance 
+performance
     bugs about performance problems.
 
-test 
+test
     needs changes to the test framework
 
-transport 
+transport
     virtual filesystem for http, sftp, etc
 
-trivial 
+trivial
     should be very easy to fix (10-20 minutes) and easily landed: typically just spelling errors and the like
 
-ui 
+ui
     bugs relating to the bzr user interface, e.g. confusing error messages.
 
-win32 
-    bugs that mainly affects Windows. Also there is cygwin and win98 tags for marking specific bugs. 
+win32
+    bugs that mainly affects Windows. Also there is cygwin and win98 tags for marking specific bugs.
 
 You can see the full list of tags in use at
 <https://bugs.edge.launchpad.net/bzr/+bugs>.  As of September 2008 the
-list is on the right. 
+list is on the right.
 
 .. vim: ft=rst

=== modified file 'doc/developers/bundles.txt'
--- doc/developers/bundles.txt	2007-12-05 19:55:07 +0000
+++ doc/developers/bundles.txt	2009-12-02 20:34:07 +0000
@@ -1,5 +1,5 @@
 =======
-Bundles 
+Bundles
 =======
 
 Status

=== modified file 'doc/developers/case-insensitive-file-systems.txt'
--- doc/developers/case-insensitive-file-systems.txt	2008-12-23 04:20:49 +0000
+++ doc/developers/case-insensitive-file-systems.txt	2009-12-02 20:34:07 +0000
@@ -27,7 +27,7 @@
 * Case-insensitive: This is the file-system used by very old Windows versions
   and is rarely encountered "in the wild".  Two files that differ only by
   case is not allowed and the case used to create a file is not preserved.
-  
+
 As can be implied by the above descriptions, only the first two are considered
 relevant to a modern Bazaar.
 

=== modified file 'doc/developers/colocated-branches.txt'
--- doc/developers/colocated-branches.txt	2009-02-10 04:10:44 +0000
+++ doc/developers/colocated-branches.txt	2009-12-02 20:34:07 +0000
@@ -17,7 +17,7 @@
 Allowing multiple branches to live under the same directory in the file
 system means that it is possible to very easily share the same working
 tree and repository between those branches, without having a lot of fs
-infrastructure. 
+infrastructure.
 
 Git and Mercurial (can) store multiple branches under a single directory
 in the file system - per repository, so to speak. In order for this to
@@ -47,20 +47,20 @@
 ~~~~~~~~~~
 
 Bazaar URLs need to have some way to specify a colocated branch other
-than the current HEAD. Several options have been discussed, each with 
+than the current HEAD. Several options have been discussed, each with
 its own advantages and disadvantages: This was discussed on the mailing
 list, most notably the use of a ";branch=NAME" suffix as well as a special
-separation character (+, =, etc), but no final conclusion was reached. 
+separation character (+, =, etc), but no final conclusion was reached.
 
 https://lists.ubuntu.com/archives/bazaar/2008q4/050105.html
 
 Code Changes
 ~~~~~~~~~~~~
 
-BzrDir should support a BzrDir.supports_colocated_branches() call as well as 
+BzrDir should support a BzrDir.supports_colocated_branches() call as well as
 BzrDir.colocated_branches property that contains a colocated branch container,
-that can be used to add / remove colocated branches as well as change the 
-currently active colocated branch. 
+that can be used to add / remove colocated branches as well as change the
+currently active colocated branch.
 
 ::
 
@@ -87,11 +87,11 @@
 	   def destroy_branch(self, name):
 		 """Destroy the specified branch.
 			
-		This will remove the branch from disk.""" 
+		This will remove the branch from disk."""
 
 If the particular BzrDir implementation doesn't support colocated
 branches, it can just return a dummy container that just contains a
-HEAD branch. 
+HEAD branch.
 
 Looms can of course return a container with all their threads.
 
@@ -106,7 +106,7 @@
 feature in its own file formats.
 
 Eventually, Bazaar could easily support colocated branches by just
-creating a new branch transport for each colocated branch and have a 
+creating a new branch transport for each colocated branch and have a
 "regular" branch live there. This would require something like
 BzrDirMeta2 though.
 

=== modified file 'doc/developers/commit.txt'
--- doc/developers/commit.txt	2007-06-28 02:43:50 +0000
+++ doc/developers/commit.txt	2009-12-02 20:34:07 +0000
@@ -174,7 +174,7 @@
      happened several commits back. There are several edge cases to be
      handled here, like if both branches modified the same file, or if
      just one branch modified it.
-     
+
   b) The trickier case is when a file appears unmodified since last
      commit, but it was modified versus one of the merged branches. I
      believe there are a few ways this can happen, like if a merged
@@ -291,7 +291,7 @@
 It is desirable to avoid roundtrips to the Repository during commit,
 particularly because it may be remote.  If the WorkingTree can determine
 by itself that a text was in the parent and therefore should be in the
-Repository that avoids one roundtrip per file.  
+Repository that avoids one roundtrip per file.
 
 There is a possibility here that the parent revision is not stored, or not
 correctly stored, in the repository the tree is being committed into, and
@@ -311,9 +311,9 @@
 This creates a CommitBuilder object matched to the Branch, Repository and
 Tree.  It can vary depending on model differences or by knowledge of what
 is efficient with the Repository and Tree.  Model differences might
-include whether no-text-change merges need to be reported, and whether the 
+include whether no-text-change merges need to be reported, and whether the
 
-The basic CommitBuilder.commit structure can be 
+The basic CommitBuilder.commit structure can be
 
 1. Ask the branch if it is ready to commit (up to date with master if
    any.)
@@ -358,10 +358,10 @@
 
 * the working tree basis is up to date with the branch tip
 
-* the local branch is up to date with the master branch, if there 
+* the local branch is up to date with the master branch, if there
   is one and --local is not specified
 
-* an empty commit message is given, 
+* an empty commit message is given,
 
 * a hook flags an error
 
@@ -396,7 +396,7 @@
 * if there are tree references and recursing into them is enabled, then
   do so
 
-Commit needs to protect against duplicated file ids 
+Commit needs to protect against duplicated file ids
 
 
 Updates that need to be made in the working tree, either on conclusion
@@ -429,13 +429,13 @@
 * or an indication that it should be read interactively from the ui object;
 * a list of files to commit
 * an option for a dry-run commit
-* verbose option, or callback to indicate 
+* verbose option, or callback to indicate
 * timestamp, timezone, committer, chosen revision id
 * config (for what?)
 * option for local-only commit on a bound branch
 * option for strict commits (fail if there are unknown or missing files)
 * option to allow "pointless" commits (with no tree changes)
- 
+
 (This is rather a lot of options to pass individually and just for code tidyness maybe some of them should be combine into objects.)
 
 >>> Branch.commit(from_tree, message, files_to_commit, ...)
@@ -466,10 +466,10 @@
 This needs to collect a list of added/changed/removed files, each of which
 must have its text stored (if any) and containing directory updated.  This
 can be done by calling Tree._iter_changes on the source tree, asking for
-changes 
+changes
 
 In the 0.17 model the commit operation needs to know the per-file parents
-and per-file last-changed revision.  
+and per-file last-changed revision.
 
 (In this and other operations we must avoid having multiple layers walk
 over the tree separately.  For example, it is no good to have the Command
@@ -530,8 +530,8 @@
 The main things the tree needs to tell the Branch about are:
 
 * A file is modified from its parent revision (in text, permissions,
-  other), and so its text may need to be stored.  
-  
+  other), and so its text may need to be stored.
+
   Files should also be reported if they have more than one unique parent
   revision, for repositories that store per-file graphs or last-change
   revisions.  Perhaps this behaviour should be optional.
@@ -540,11 +540,11 @@
 
 * The complete contents of a modified directory, so that its inventory
   text may be stored.  This should be done after all the contained files
-  and directories have been reported.  If there are unmodified files, 
-  or unselected files carried through from 
+  and directories have been reported.  If there are unmodified files,
+  or unselected files carried through from
 
-  XXX: Actually perhaps not grouped by directory, but rather grouped 
-  appropriately for the shape of inventory storage in the repository. 
+  XXX: Actually perhaps not grouped by directory, but rather grouped
+  appropriately for the shape of inventory storage in the repository.
 
   In a zoomed-in checkout the workingtree may not have all the shape data
   for the entire tree.
@@ -577,7 +577,7 @@
 This might be construed as an enhanced version of ``set_parent_trees``.
 We can avoid a stat on each file by using the value that was observed when
 it was first read.
- 
+
 
 
 Selective commit
@@ -591,7 +591,7 @@
 However, the tree walking code does probably need to know about selected
 paths to avoid examining unselected files or directories.
 
-We never refuse selective file commits (except of merges).  
+We never refuse selective file commits (except of merges).
 
 
 

=== modified file 'doc/developers/container-format.txt'
--- doc/developers/container-format.txt	2009-02-22 16:54:02 +0000
+++ doc/developers/container-format.txt	2009-12-02 20:34:07 +0000
@@ -136,7 +136,7 @@
 
 Some proposed object names:
 
-  * to name a revision: "``revision:``\ *revision-id*".  e.g., 
+  * to name a revision: "``revision:``\ *revision-id*".  e.g.,
     `revision:pqm@pqm.ubuntu.com-20070531210833-8ptk86ocu822hjd5`.
   * to name an inventory delta: "``inventory.delta:``\ *revision-id*".  e.g.,
     `inventory.delta:pqm@pqm.ubuntu.com-20070531210833-8ptk86ocu822hjd5`.
@@ -155,7 +155,7 @@
 
   * a record's content could be self-describing in the context of a
     particular container, or
-  * a record could be accessed via an index based on SHA-1, or 
+  * a record could be accessed via an index based on SHA-1, or
   * when streaming, the first record could be treated specially.
 
 Reasonably cheap for small records
@@ -203,12 +203,12 @@
 A **Bytes** record:
 
   * has a kind marker of "``B``",
-  * followed by a mandatory **content length** [1]_: 
+  * followed by a mandatory **content length** [1]_:
     "*number*\ ``\n``", where *number* is in decimal, e.g::
 
       1234
 
-  * followed by zero or more optional **names**: 
+  * followed by zero or more optional **names**:
     "*name*\ ``\n``", e.g.::
 
       revision:pqm@pqm.ubuntu.com-20070531210833-8ptk86ocu822hjd5

=== modified file 'doc/developers/content-filtering.txt'
--- doc/developers/content-filtering.txt	2009-08-28 05:00:33 +0000
+++ doc/developers/content-filtering.txt	2009-12-02 20:34:07 +0000
@@ -106,7 +106,7 @@
 
 * In a future workingtree format, it might be better not to separately
   store the working-copy hash and size, but rather just a stat fingerprint
-  at which point it was known to have the same canonical form as the 
+  at which point it was known to have the same canonical form as the
   basis tree.
 
 * It may be worthwhile to have a virtual Tree-like object that does

=== modified file 'doc/developers/cycle.txt'
--- doc/developers/cycle.txt	2009-09-11 18:25:08 +0000
+++ doc/developers/cycle.txt	2009-12-02 20:34:07 +0000
@@ -2,7 +2,7 @@
 Bazaar Release Cycles
 *********************
 
-:status: Current policy, as of 2009-08. 
+:status: Current policy, as of 2009-08.
 :blueprint: <https://blueprints.launchpad.net/bzr/+spec/6m-cycle>
 
 
@@ -18,14 +18,14 @@
 
 * `Bazaar Developer Document Catalog <index.html>`_
 
-* `Releasing Bazaar <releasing.html>`_ -- the process for actually making 
+* `Releasing Bazaar <releasing.html>`_ -- the process for actually making
   a release or release candidate.
 
 The Problem Situation
 *********************
 
 Bazaar makes a release every month, preceded by a one-week
-release-candidate test.  
+release-candidate test.
 
 In any release we may fix bugs, add formats, change the default format,
 improve performance, add new commands or change command line behaviour,
@@ -105,7 +105,7 @@
                                                         +-- 3.0.0beta1 ...
 
 
-Starting from the date of a major release: 
+Starting from the date of a major release:
 
 At four-week intervals we make a new beta release.  There will be no
 separate release candidate, but if a serious problem is discovered we may
@@ -121,7 +121,7 @@
 We will then make a release candidate for the next major release, and at
 this point create a release branch for it.  We will iterate release
 candidates at approximately weekly intervals until there are no bugs
-blocking the final major release. 
+blocking the final major release.
 
 Compared to the current process this has approximately the same amount of
 release-related work, because the extra releases from the stable branch
@@ -192,7 +192,7 @@
 Bug Work
 --------
 
-Bug fixes should normally be done first against the stable branch, 
+Bug fixes should normally be done first against the stable branch,
 reviewed against that branch, and then merged forward to trunk.
 
 It may not always be easy to do this, if fixing the bug requires large
@@ -240,7 +240,7 @@
 of bzrlib, which is an elusive target in Python.
 
 This may mean that in cases where today a plugin would keep running but
-give warnings, it will now fail altogether with an error.   
+give warnings, it will now fail altogether with an error.
 
 In return we expect more freedom to change and cleanup bzrlib code without
 needing to keep old code around, or write extra compatibility shims, or
@@ -252,7 +252,7 @@
 but that aren't technically plugins.  The same approach, though the
 technical considerations are different, should apply to other extensions
 such as programs that use bzr through the shell interface.
-  
+
 
 
 Data and Network Formats
@@ -296,7 +296,7 @@
 This can be handled in various ways either at the OS packaging or the
 Python level.  We don't propose to directly address it in the upstream
 source.  (For example, we will not change the bzrlib library name from one
-release to the next.)  
+release to the next.)
 
 The issue already exists with people who may want to use for example the
 previous bzr release and the trunk.  There is a related issue that plugins
@@ -350,7 +350,7 @@
 
 * Early communication about changing dependencies or defaults
 
-* Reminder re lifecycle and where we're up to right now, in particular the 
+* Reminder re lifecycle and where we're up to right now, in particular the
   dates for the next release and/or candidate.
 
 * Summary of recent successes and pending work.
@@ -364,11 +364,11 @@
 Questions
 *********
 
-Do users actually want this?  
+Do users actually want this?
     Apparently yes, because it's often requested and often raised as a
     problem.
 
-Would this confuse users?  
+Would this confuse users?
     It shouldn't, because it's a fairly standard scheme.
 
 Won't it take more time to fix bugs in multiple places?
@@ -388,7 +388,7 @@
     really rather not test them, forcing them is not helpful.
 
 Isn't this a step backwards to a slower, less-agile process?
-    No, our trunk stays releasable, and we ship every month.  We're just 
+    No, our trunk stays releasable, and we ship every month.  We're just
     cutting out things that hold us back (continuous rather than episodic
     API stability; RCs every month) and giving users what they demand.
 
@@ -406,7 +406,7 @@
   and stable releases, indicating that each has value.
 
 * API changes are easier or safer to make during beta periods, without
-  being held back by fears of compatibility or 
+  being held back by fears of compatibility or
 
 * The stable releases are actually stable and don't introduce regressions
   or break plugins.

=== modified file 'doc/developers/development-repo.txt'
--- doc/developers/development-repo.txt	2009-04-09 20:23:07 +0000
+++ doc/developers/development-repo.txt	2009-12-02 20:34:07 +0000
@@ -28,7 +28,7 @@
 
 When a release of bzr is done, all the older numbered development
 formats will be removed from 'bzr.dev', so we will not be carrying the
-code for them around indefinately. 
+code for them around indefinately.
 
 Support for upgrade and migration
 ---------------------------------
@@ -40,7 +40,7 @@
  - users of a given development format can always get back onto regular
    formats by switching to the next bzr released version which is
    guaranteed to be able to upgrade from that development format.
- - users that routinely use bzr.dev should upgrade to the most recent 
+ - users that routinely use bzr.dev should upgrade to the most recent
    development version available before pulling in bzr.dev changes
    around release time, as that is when old format cleanups will occur.
 

=== modified file 'doc/developers/diff.txt'
--- doc/developers/diff.txt	2007-07-17 00:27:16 +0000
+++ doc/developers/diff.txt	2009-12-02 20:34:07 +0000
@@ -61,7 +61,7 @@
 that only certain files should be compared.
 
 Performance can be further improved by caching comparisons to avoid repeating
-them.  Caching could potentially be performed by ``diff`` and perhaps by 
+them.  Caching could potentially be performed by ``diff`` and perhaps by
 ``merge``.  Merge is aware of the relationship of a text merge's result to
 the THIS value, and the THIS value is generally the basis value.  So the
 comparison is latent, but present.  The only issue is extracting it.

=== modified file 'doc/developers/directory-fingerprints.txt'
--- doc/developers/directory-fingerprints.txt	2007-07-31 03:38:18 +0000
+++ doc/developers/directory-fingerprints.txt	2009-12-02 20:34:07 +0000
@@ -8,7 +8,7 @@
 
 The basic idea is that for a directory in a tree (committed or otherwise), we
 will have a single scalar value.  If these values are the same, the contents of
-the subtree under that directory are necessarily the same.  
+the subtree under that directory are necessarily the same.
 
 This is intended to help with these use cases, by allowing them to quickly skip
 over directories with no relevant changes, and to detect when a directory has
@@ -26,7 +26,7 @@
 
 Most of this will be hidden behind the Tree interface.  This should cover
 ``log -v``, ``diff``, ``status``, ``merge`` (and implicit merge during
-push, pull, update):: 
+push, pull, update)::
 
   tree.iter_changes(other_tree)
   tree.get_file_lines(file_id)   # and get_file, get_file_text
@@ -38,7 +38,7 @@
 compare to all the trees.  Commit currently needs to compare the working
 tree to all the parent trees, which is needed to update the last_modified
 field and would be unnecessary if we removed that field (for both files
-and directories) and did not store per-file graphs.  
+and directories) and did not store per-file graphs.
 This would potentially speed up commit after merge.
 
 Verbose commit also displays the merged files, which does
@@ -49,7 +49,7 @@
 ~~~~~~~
 
 Log is interested in two operations: finding the revisions that touched
-anything inside a directory, and getting the differences between 
+anything inside a directory, and getting the differences between
 consecutive revisions (possibly filtered to a directory)::
 
   find_touching_revisions(branch, file_id) # should be on Branch?
@@ -90,9 +90,9 @@
   Hashes converge: if you modify and then modify back, you get the same
   hash.  This is a pro because you can detect that there were ultimately
   no significant changes.  And also a con: you cannot use these hashes to form a graph
-  because they get cycles.  
-
-  
+  because they get cycles.
+
+
 * Are the values unique across the whole tree, or only when comparing
   different versions of the same object?
 
@@ -107,7 +107,7 @@
 
 
 * Is it reasonable to assume hashes won't collide?
-  
+
   The odds of SHA-1 hashes colliding "accidentally" are vanishingly small.
 
   It is possible that a `preimage attack`_ against SHA-1 may be discovered
@@ -132,7 +132,7 @@
 
   It is desirable that we have a hash that covers all data, to guard
   against bugs, transmission errors, or users trying to hand-hack files.
-  Since we need one hash of everything in the tree, perhaps we should also 
+  Since we need one hash of everything in the tree, perhaps we should also
   use it for the fingerprint.
 
   Testaments explicitly separate the form used for hashing/signing from
@@ -143,7 +143,7 @@
   stored data which is not protected by the signature: this data is less
   important, but corruption of it would still cause problems.
   We have encountered some specific problems with disagreement between
-  inventories as to the last-change of files, which is currently unsigned. 
+  inventories as to the last-change of files, which is currently unsigned.
   These problems can be introduced by ghosts.
 
   If we hash the representation, there is still a way to support old
@@ -156,16 +156,16 @@
 * Is hashing substantially slower than other possible approaches?
 
   We already hash all the plain files.  Except in unusual cases, the
-  directory metadata will be substantially smaller: perhaps 200:1 as a 
+  directory metadata will be substantially smaller: perhaps 200:1 as a
   rule of thumb.
 
   When building a bzr tree, we spend on the order of 100ms hashing all the
   source lines to validate them (about 13MB of source).
 
 
-* Can you calculate one from a directory in the working tree?  Without a basis?  
+* Can you calculate one from a directory in the working tree?  Without a basis?
 
-  This seems possible with either hashes or revision ids.  
+  This seems possible with either hashes or revision ids.
 
   Using last_changed means that calculating the fingerprint from a working
   tree necessarily requires reading the inventory for the basis
@@ -199,30 +199,30 @@
   This does rule out for example using ``last_modified=None`` or
   ``='current:'`` to mean "changed in the working tree."  Even if this is
   not supported there seems some risk that we would get the same
-  fingerprint for trees that are actually different.  
-  
-  We could assign a 
+  fingerprint for trees that are actually different.
+
+  We could assign a
   hypothetical revision id to the tree for uncommitted files.  In that
   case there is some risk that the not-yet-committed id would become
   visible or committed.
 
-  
+
 * Can we use an "approximate basis"?
 
   When using radix trees, you may need context beyond the specific
-  directory being compared.  
-
-
-* Can you get the fingerprint of parents directories with only selected file ids 
+  directory being compared.
+
+
+* Can you get the fingerprint of parents directories with only selected file ids
   taken from the working tree?
 
   With hashes, we'd want to carry through the unselected files and
-  directories from the values they had in the parent revision.  
-
-
-* Are unbalanced trees a significant problem?  Trees can be unbalanced by having 
-  many directories (deep or wide), or many files per directory.  
-  
+  directories from the values they had in the parent revision.
+
+
+* Are unbalanced trees a significant problem?  Trees can be unbalanced by having
+  many directories (deep or wide), or many files per directory.
+
   For small trees like bzr, 744 of 874 are in the bzrlib subtree.  In
   general, larger trees are more balanced, because humans, editors and
   other tools have trouble managing very unbalanced trees.  But there are
@@ -230,7 +230,7 @@
   entries in one directory.
 
 
-* Should we use a radix tree approach where fingerprints are calculated on a synthetic 
+* Should we use a radix tree approach where fingerprints are calculated on a synthetic
   tree that is by definition balanced, even when the actual tree is unbalanced?
 
 
@@ -268,10 +268,10 @@
      This has some consequences for how we can upgrade it in future: all
      the changed directories need to be rewritten up to the revision level.
 
-  1. If we address directories by hash we need hash-addressed 
+  1. If we address directories by hash we need hash-addressed
      storage.
 
-  1. If we address directories by hash then for consistency we'd probably 
+  1. If we address directories by hash then for consistency we'd probably
      (not necessarily) want to address file texts by hash.
 
   1. The per-file graph can't be indexed by hash because they can converge, so we
@@ -316,8 +316,8 @@
   If the version of a file or directory is identified by a hash, we can't
   use that to point into a per-file graph.  We can have a graph indexed by
   ``(file_id, hash, revision_id)``.  The last-modified could be stored as
-  part of this graph.  
-  
+  part of this graph.
+
   The graph would no longer be core data; it could be always present but
   might be rebuilt.  Treating it as non-core data may make some changes
   like shallow branches easier?
@@ -354,6 +354,6 @@
 -----------
 
 
-..  
+..
   vim: filetype=rst textwidth=78 expandtab spelllang=en spell
 

=== modified file 'doc/developers/ec2.txt'
--- doc/developers/ec2.txt	2009-03-23 00:25:27 +0000
+++ doc/developers/ec2.txt	2009-12-02 20:34:07 +0000
@@ -8,7 +8,7 @@
 but we aim to use it for the production Windows installer build of 1.13 in
 March.
 
-See also: 
+See also:
 
 * `Bazaar Developer Documentation Catalog <index.html>`_.
 
@@ -20,8 +20,8 @@
 =====
 
 * The instance is only running (and incurring charges) when it's needed
-  for testing or packaging.  
-  
+  for testing or packaging.
+
 * It can be started or stopped by anyone on the team using a
   straightforward script.
 
@@ -41,7 +41,7 @@
 ========
 
 The working disk and the AMI images are stored in one person's account for
-billing purposes.  
+billing purposes.
 
 Ideally we want to give other people access to run this machine without
 giving full access to the account.  I'm not sure if that's feasible.  If
@@ -76,7 +76,7 @@
 This is distinct from the account identifier - likely due to the different
 toolchains in use (the keypairs are used for unix ssh keys, and I (Robert)
 suspect a rather unix friendly core at Amazon).
-Once a custom image is made with a saved password, you can skip using 
+Once a custom image is made with a saved password, you can skip using
 ``ec2-get-password`` (which is only needed for Windows anyway).
 
 It would be nice if rdesktop could use private key authentication but
@@ -125,9 +125,9 @@
 * Install the rdesktop client, to actually access the machine.
 
 * Possibly read some of the `EC2 documentation`_ for background.
-   
-.. _`bug 330930`: https://bugs.edge.launchpad.net/ubuntu/+bug/330930 
-.. _`Amazon EC2 API tools`: 
+
+.. _`bug 330930`: https://bugs.edge.launchpad.net/ubuntu/+bug/330930
+.. _`Amazon EC2 API tools`:
      http://developer.amazonwebservices.com/connect/entry.jspa?externalID=368&categoryID=88
 .. _`EC2 documentation`: http://aws.amazon.com/
 .. _`ami-bdfe19d4`:
@@ -138,7 +138,7 @@
     ec2-add-group desolation-group -d 'bzr win32 build machine'
     ec2-authorize desolation-group -p 3389 -s 1.2.3.4/32
     ec2-authorize desolation-group -t -1:-1 -P icmp
-  
+
   Add your public IP there.  You can repeat that command to allow others
   in.
 
@@ -149,11 +149,11 @@
 1. Get the right AMI image ID from another developer.
 
 1. Start the instance::
-   
+
      ec2-run-instances $image_id -g desolation-group
 
    This will print out some information including the image id, something
-   like ``i-31a74258``.  
+   like ``i-31a74258``.
 
 1. Actually starting the machine will take a few minutes.  Once it's in
    the *running* state, get the machine's public IP with ::
@@ -171,18 +171,18 @@
 To save a system snapshot as an image
 -------------------------------------
 
-1. Bundle the current state.  *Doing this will reboot the machine.* 
+1. Bundle the current state.  *Doing this will reboot the machine.*
    You need to choose a unique s3 bucket name,
-   typically based on a domain or email address, which can contain 
+   typically based on a domain or email address, which can contain
    any number of images.  You also need a name unique within the bucket
-   for this image, like ``desolation-vs2008-20090219``.  And finally 
+   for this image, like ``desolation-vs2008-20090219``.  And finally
    it needs your AWS S3 access key and secret key, which should be set in
    ``~/.aws``::
-    
+
       ec2-bundle-instance -b ec2.sourcefrog.net \
           -p desolation-vs2008-2009021 \
           -o "$AWS_ACCESS_KEY_ID" \
-          -w "$AWS_SECRET_ACCESS_KEY" 
+          -w "$AWS_SECRET_ACCESS_KEY"
 
 1.  This will take several minutes:  You can check progress with ::
 

=== modified file 'doc/developers/improved_chk_index.txt'
--- doc/developers/improved_chk_index.txt	2009-03-24 16:35:22 +0000
+++ doc/developers/improved_chk_index.txt	2009-12-02 20:34:07 +0000
@@ -16,7 +16,7 @@
 per key, which is the same size as the binary representation of the hash. This
 means we could write an index format that gets approximately the same on-disk
 size, without having the overhead of ``zlib.decompress``. Some thought would
-still need to be put into how to efficiently access these records from remote. 
+still need to be put into how to efficiently access these records from remote.
 
 
 Required information
@@ -99,7 +99,7 @@
    offset + endpoint as a header in the group itself.)
 
 5. So for 1M keys, an ideal chk+group index would be:
-    
+
     a. 6-byte hash prefix
 
     b. 2-byte group number
@@ -149,13 +149,13 @@
       information to read the entire group block. For local ops, you could
       only read enough to get the header, and then only read enough to
       decompress just the content you want to get at.
-      
+
       Using an offset, you also don't need to decode the entire group header.
       If we assume that things are stored in fixed-size records, you can jump
       to exactly the entry that you care about, and read its 8-byte
       (start,length in uncompressed) info.  If we wanted more redundancy we
       could store the 20-byte hash, but the content can verify itself.
-      
+
    f. If the size of these mini headers becomes critical (8 bytes per record
       is 8% overhead for 100 byte records), we could also compress this mini
       header. Changing the number of bytes per entry is unlikely to be
@@ -172,7 +172,7 @@
       would also have the advantage that fixed width would be highly
       compressible itself. (Most nodes are going to have a length that fits
       1-2 bytes.)
-      
+
       An alternative form would be to use the base-128 encoding.  (If the MSB
       is set, then the next byte needs to be added to the current value
       shifted by 7*n bits.) This encodes 4GiB in 5 bytes, but stores 127B in 1
@@ -470,5 +470,5 @@
 group pointer, we can refer to 16.7M groups. It does add complexity, but it is
 likely necessary to allow for arbitrary cases.
 
-.. 
+..
   vim: ft=rst tw=78 ai

=== modified file 'doc/developers/incremental-push-pull.txt'
--- doc/developers/incremental-push-pull.txt	2009-02-22 16:54:02 +0000
+++ doc/developers/incremental-push-pull.txt	2009-12-02 20:34:07 +0000
@@ -94,8 +94,8 @@
       found to be a subset of the other, or a complete list of revisions to be
       transmitted is created.
 
- * Uncommon cases: 
-   
+ * Uncommon cases:
+
    1. Repositories with many projects or branches which are very old may
       require reading a lot of unrelated graph data.
 
@@ -109,7 +109,7 @@
  2. Determine one sided graph difference. To avoid obtaining a full graph over
     the wire this needs to be done without reference to the full graph, and
     with some logarthmic scaling algorithm. There are several already available
-    for this. 
+    for this.
 
 With ghost and new-signature detection:
 
@@ -219,7 +219,7 @@
 Data grouping:
 
 * File per full identifier (fileid:revisionid:meta|content): 104000
-* Delta-chain per object: object id count * constant overhead per object id 
+* Delta-chain per object: object id count * constant overhead per object id
   (26 -> 80006)
 * Collation/pack file: 1
 
@@ -251,7 +251,7 @@
 
  #. setup
 
-   look at graph of revisions for ~N comits to deretmine eligibility for 
+   look at graph of revisions for ~N comits to deretmine eligibility for
    if preserve mainline is on, check LH only
 
     identify objects to send that are not on the client repo

=== modified file 'doc/developers/index-plain.txt'
--- doc/developers/index-plain.txt	2009-09-09 12:57:43 +0000
+++ doc/developers/index-plain.txt	2009-12-02 20:34:07 +0000
@@ -11,7 +11,7 @@
 * `Architectural Overview <overview.html>`_ |--| describes some of the
   most important classes and concepts.
 
-* `bzrlib API reference <http://starship.python.net/crew/mwh/bzrlibapi/>`_ 
+* `bzrlib API reference <http://starship.python.net/crew/mwh/bzrlibapi/>`_
   (external link)
   |--| automatically generated API reference information
 
@@ -24,7 +24,7 @@
 
 * `Testing <testing.html>`_ |--| Guide to writing tests for Bazaar.
 
-* `Writing plugins <http://bazaar-vcs.org/WritingPlugins>`_ (wiki) 
+* `Writing plugins <http://bazaar-vcs.org/WritingPlugins>`_ (wiki)
   |--| specific advice on writing Bazaar plugins.
 
 Process
@@ -32,8 +32,8 @@
 
 * `The Bazaar Development Cycle <cycle.html>`_ |--| The monthly
   development cycle and how to run it.
-  
-* `Releasing Bazaar <releasing.html>`_ |--| 
+
+* `Releasing Bazaar <releasing.html>`_ |--|
   Checklist to make a release of Bazaar.
 
 * `Managing the Bazaar PPA <ppa.html>`_ |--| Packaging Bazaar for Ubuntu.
@@ -41,19 +41,19 @@
 * `Giving back <http://bazaar-vcs.org/BzrGivingBack>`_ (wiki) |--| How to get
   your changes to Bazaar integrated into a release.
 
-* `Profiling notes <profiling.html>`_ |--| Instructions on how to profile 
+* `Profiling notes <profiling.html>`_ |--| Instructions on how to profile
   bzr code and visualize the results.
 
-* `EC2 resources <ec2.html>`_ |--| A team resource for 
+* `EC2 resources <ec2.html>`_ |--| A team resource for
   Windows packaging and testing, and Ubuntu testing.
 
-* `Tracking Bugs in Bazaar <bug-handling.html>`_ |--| How we use the bug 
+* `Tracking Bugs in Bazaar <bug-handling.html>`_ |--| How we use the bug
   tracker.
 
 Plans
 =====
 
-* `Performance roadmap <performance-roadmap.html>`_ |--| The roadmap 
+* `Performance roadmap <performance-roadmap.html>`_ |--| The roadmap
   for fixing performance in bzr over the next few releases.
 
 * `Co-located branches <colocated-branches.html>`_ |--| Planned(?) support
@@ -114,7 +114,7 @@
 Data formats
 ============
 
-* `Knit pack repositories <packrepo.html>`_ |--| KnitPack repositories 
+* `Knit pack repositories <packrepo.html>`_ |--| KnitPack repositories
   (new in Bazaar 0.92).
 
 Implementation notes

=== modified file 'doc/developers/index.txt'
--- doc/developers/index.txt	2009-11-18 02:09:01 +0000
+++ doc/developers/index.txt	2009-12-02 20:34:07 +0000
@@ -34,9 +34,9 @@
    overview
    integration
 
-* `Writing plugins for Bazaar <http://bazaar-vcs.org/WritingPlugins>`_ (web link) 
+* `Writing plugins for Bazaar <http://bazaar-vcs.org/WritingPlugins>`_ (web link)
 
-* `bzrlib API reference <http://starship.python.net/crew/mwh/bzrlibapi/>`_ 
+* `bzrlib API reference <http://starship.python.net/crew/mwh/bzrlibapi/>`_
   (web link)
 
 

=== modified file 'doc/developers/inventory.txt'
--- doc/developers/inventory.txt	2009-08-28 05:00:33 +0000
+++ doc/developers/inventory.txt	2009-12-02 20:34:07 +0000
@@ -49,7 +49,7 @@
 that an inventory is stored as. We have a number of goals we want to achieve:
 
  1. Allow commit to write less than the full tree's data in to the repository
-    in the general case. 
+    in the general case.
  2. Allow the data that is written to be calculated without examining every
     versioned path in the tree.
  3. Generate the exact same representation for a given inventory regardless of
@@ -83,7 +83,7 @@
 -----------------
 
 The xml based implementation we use today layers the inventory as a bytestring
-which is stored under a single key; the bytestring is then compressed as a 
+which is stored under a single key; the bytestring is then compressed as a
 delta against the bytestring of its left hand parent by the knit code.
 
 Gap analysis:
@@ -140,8 +140,8 @@
 -------------------------------------------------------------------------
 
  * Split up the logical document into smaller serialised fragements. For
-   instance hash buckets or nodes in a tree of some sort. By serialising in 
-   smaller units, we can increase the number of smaller units rather than 
+   instance hash buckets or nodes in a tree of some sort. By serialising in
+   smaller units, we can increase the number of smaller units rather than
    their size as the tree grows; as long as two similar trees have similar
    serialised forms, the amount of different content should be quite high.
 
@@ -166,7 +166,7 @@
 
  * Working tree to arbitrary history revision deltas/comparisons can be scaled
    up by doing a two-step (fixed at two!) delta combining - delta(tree, basis)
-   and then combine that with delta(basis, arbitrary_revision) using the 
+   and then combine that with delta(basis, arbitrary_revision) using the
    repositories ability to get a delta cheaply.
 
  * The key primitives we need seem to be:
@@ -263,7 +263,7 @@
 
 The path and content maps are populated simply by serialising every inventory
 entry and inserting them into both the path map and the content map. The maps
-start with just a single leaf node with an empty prefix. 
+start with just a single leaf node with an empty prefix.
 
 
 Apply
@@ -439,10 +439,10 @@
    formerly linked. (This will normally bubble down due to keeping densely
    packed nodes).
    To shrink the prefix of a leaf node, create an internal node with the same
-   prefix, then choose a width for the internal node such that the contents 
+   prefix, then choose a width for the internal node such that the contents
    of the leaf all fit into new leaves obeying the min_size and max_size rules.
    The largest prefix possible should be chosen, to obey the
-   higher-nodes-are-denser rule. That rule also gives room in leaf nodes for 
+   higher-nodes-are-denser rule. That rule also gives room in leaf nodes for
    growth without affecting the parent node packing.
 #. Update the CHK pointers - serialise every altered node to generate a CHK,
    and update the CHK placeholder in the nodes parent; then reserialise the
@@ -590,7 +590,7 @@
 
 Different trees can use different algorithms to expand the request as long as
 they produce consistent deltas. As part of getting a consistent UI we require
-that all trees expand the paths requested downwards. Beyond that as long as 
+that all trees expand the paths requested downwards. Beyond that as long as
 the delta is consistent it is up to the tree.
 
 Given two trees, source and target, and a set of selected file ids to check for
@@ -598,7 +598,7 @@
 the following rules, to get consistent deltas. The test for consistency is that
 if the resulting delta is applied to source, to create a third tree 'output',
 and the paths in the delta match the paths in source and output, only one file
-id is at each path in output, and no file ids are missing parents, then the 
+id is at each path in output, and no file ids are missing parents, then the
 delta is consistent.
 
 Firstly, the parent ids to the root for all of the file ids that have actually

=== modified file 'doc/developers/last-modified.txt'
--- doc/developers/last-modified.txt	2007-08-06 22:22:58 +0000
+++ doc/developers/last-modified.txt	2009-12-02 20:34:07 +0000
@@ -30,7 +30,7 @@
 If there is still more than one head, a new last_modified is assigned.
 This points to the merge point in the file graph.
 
-If the file text and properties are the same as the sole remaining head, 
+If the file text and properties are the same as the sole remaining head,
 its last_modified is inherited. Property changes include executable bit,
 filename, and containing directory.
 
@@ -53,7 +53,7 @@
 For the single-parent commit case, we just need to determine which files have
 changed compared to the parent.  If the file was changed, it gets the
 revision id of the new revision; otherwise it inherits the value from the
-parent tree.  
+parent tree.
 
 In the multi-parent commit case (commit of a merge), it can take the value
 from any of the parent trees, or of the new revision.
@@ -74,11 +74,11 @@
 in fact do this even when not using per-file graphs.  In the current
 dirstate format we need to store the full data for all trees because they
 can be extracted from the dirstate, but it could mark some parents as
-already merged.  
+already merged.
 
 Alternatively, we could change the dirstate to include
 only the base and current trees, and cache the merged-in parents
-elsewhere. 
+elsewhere.
 
 (Offtopic other dirstate changes: we could also omit the working-copy
 hash, and just have a stat-fingerprint of when it was last known equal to
@@ -89,7 +89,7 @@
 Generation during conversion
 ----------------------------
 
-Accessing a foreign branch requires synthesizing this information. 
+Accessing a foreign branch requires synthesizing this information.
 If last_modified is removed from a future bzr version, we will also need
 to synthesize it to pull back to earlier formats.
 
@@ -172,5 +172,5 @@
 For a single file, if I am different from all parents, 'new'. (Do not need
 to evaluate last modified).
 
-..   
+..
   vim: ft=rst tw=74

=== modified file 'doc/developers/network-protocol.txt'
--- doc/developers/network-protocol.txt	2009-10-29 00:19:57 +0000
+++ doc/developers/network-protocol.txt	2009-12-02 20:34:07 +0000
@@ -172,13 +172,13 @@
 
 An extension to version two allows streamed bodies.  A streamed body looks
 a lot like HTTP's chunked encoding::
- 
+
   STREAMED_BODY := "chunked" NEWLINE CHUNKS TERMINATOR
   CHUNKS := CHUNK [CHUNKS]
   CHUNK := HEX_LENGTH CHUNK_CONTENT
   HEX_LENGTH := HEX_DIGITS NEWLINE
   CHUNK_CONTENT := bytes
-  
+
   TERMINATOR := SUCCESS_TERMINATOR | ERROR_TERMINATOR
   SUCCESS_TERMINATOR := 'END' NEWLINE
   ERROR_TERMINATOR := 'ERR' NEWLINE CHUNKS SUCCESS_TERMINATOR
@@ -201,7 +201,7 @@
 -------------
 
 .. note::
-  
+
   For some discussion of the requirements that led to this new protocol
   version, see `bug #83935`_.
 
@@ -226,7 +226,7 @@
   HEADERS := LENGTH_PREFIX bencoded_dict
   END_MESSAGE := "e"
 
-  BODY := MESSAGE_PART+ 
+  BODY := MESSAGE_PART+
   MESSAGE_PART := ONE_BYTE | STRUCTURE | BYTES
   ONE_BYTE := "o" byte
   STRUCTURE := "s" LENGTH_PREFIX bencoded_structure
@@ -262,10 +262,10 @@
 Conventional requests will send a CONTENTS of ::
 
   CONV_REQ := ARGS SINGLE_OR_STREAMED_BODY?
-  SINGLE_OR_STREAMED_BODY := BYTES 
+  SINGLE_OR_STREAMED_BODY := BYTES
         | BYTES+ TRAILER
-         
-  ARGS := STRUCTURE(argument_tuple) 
+
+  ARGS := STRUCTURE(argument_tuple)
   TRAILER := SUCCESS_STATUS | ERROR
   SUCCESS_STATUS := ONE_BYTE("S")
   ERROR := ONE_BYTE("E") STRUCTURE(argument_tuple)
@@ -276,7 +276,7 @@
   RESP_STATUS := ONE_BYTE("S") | ONE_BYTE("E")
 
 If the RESP_STATUS is success ("S"), the arguments are the
-method-dependent result.  
+method-dependent result.
 
 For errors (where the Status byte of a response or a streamed body is
 "E"), the situation is analagous to requests.  The first item in the
@@ -287,7 +287,7 @@
 Note that the streamed body from version two is now just multiple
 BYTES parts.
 
-The end of the request or response is indicated by the lower-level 
+The end of the request or response is indicated by the lower-level
 END_MESSAGE.  If there's only one BYTES element in the body, the TRAILER
 may or may not be present, depending on whether it was sent as a single
 chunk or as a stream that happens to have one element.
@@ -304,7 +304,7 @@
   initial success and then another byte part with no intervening bytes.
   If we stop sending the final success message and only flag errors
   they'll only get one if the error is detected after streaming starts but
-  before any bytes are actually sent.  Possibly we should wait until at 
+  before any bytes are actually sent.  Possibly we should wait until at
   least the first chunk is ready before declaring success.
 
 For new methods, these sequences are just a convention and may be varied
@@ -320,12 +320,12 @@
   be preserved in the rpc from end to end.  This may be useful when
   there's an iterator on one side feeding in to an iterator on the other,
   if it avoids doing chunking and byte-counting at two levels, and if
-  those iterators are a natural place to get good granularity.  Also, for 
+  those iterators are a natural place to get good granularity.  Also, for
   cases like ``insert_record_stream`` the server can't do much with the
   data until it gets a whole chunk, and so it'll be natural and efficient
   for it to be called with one chunk at a time.
 
-  On the other hand, there may be times when we've got some bytes from the 
+  On the other hand, there may be times when we've got some bytes from the
   network but not a full chunk, and it might be worthwhile to pass it up.
   If we promise to preserve chunks, then to do this we'd need two separate
   streaming interfaces: "we got a chunk" and "we got some bytes but not

=== modified file 'doc/developers/overview.txt'
--- doc/developers/overview.txt	2009-09-08 01:11:40 +0000
+++ doc/developers/overview.txt	2009-12-02 20:34:07 +0000
@@ -12,7 +12,7 @@
 document, send a merge request or new text to the mailing list.
 
 The current version of this document is available in the file
-``doc/developers/overview.txt`` in the source tree, and available online 
+``doc/developers/overview.txt`` in the source tree, and available online
 within the developer documentation, <http://doc.bazaar-vcs.org/developers/>.
 
 
@@ -101,11 +101,11 @@
 store a full text of the inventory, and of every new file text.
 
 At runtime, repository stacking is actually configured by the branch, not
-the repository.  So doing ``a_bzrdir.open_repository()`` 
-gets you just the single physical repository, while 
-``a_bzrdir.open_branch().repository`` gets one configured with a stacking. 
+the repository.  So doing ``a_bzrdir.open_repository()``
+gets you just the single physical repository, while
+``a_bzrdir.open_branch().repository`` gets one configured with a stacking.
 Therefore, to permanently change the fallback repository stored on disk,
-you must use ``Branch.set_stacked_on_url``.  
+you must use ``Branch.set_stacked_on_url``.
 
 Changing away from an existing stacked-on URL will copy across any
 necessary history so that the repository remains usable.

=== modified file 'doc/developers/performance-use-case-analysis.txt'
--- doc/developers/performance-use-case-analysis.txt	2007-06-18 02:04:20 +0000
+++ doc/developers/performance-use-case-analysis.txt	2009-12-02 20:34:07 +0000
@@ -1,6 +1,6 @@
 .. This document describes _how_ to do use case analyses and what we want
 .. to get out of them; for the specific cases see the files referenced by
-.. performance-roadmap.txt 
+.. performance-roadmap.txt
 
 Analysing a specific use case
 =============================
@@ -55,7 +55,7 @@
 - scaling: how does performance change when any of the follow aspects
   of the system are ratcheted massively up or down:
 
-   - number of files/dirs/symlinks/subtrees in a tree (both working and 
+   - number of files/dirs/symlinks/subtrees in a tree (both working and
      revision trees)
    - size of any particular file
    - number of elements within a single directory
@@ -77,9 +77,9 @@
    - bandwidth when performing semantic operations.
 
 - locality of reference: If an operation requires data that is located
-  within a small region at any point, we often get better performance 
+  within a small region at any point, we often get better performance
   than with an implementation of the same operation that requires the
-  same amount of data but with a lower locality of reference. Its 
+  same amount of data but with a lower locality of reference. Its
   fairly tricky to add locality of reference after the fact, so I think
   its worth considering up front.
 
@@ -89,7 +89,7 @@
 measurements, in an ideal world there would be no more than one round
 trip for each semantic operation. What there must not be is one round
 trip per revision involved in the revisionid->dotted number mapping, nor
-per each revision id attributed to a line in the text. 
+per each revision id attributed to a line in the text.
 
 Not all the items mentioned above are created equal. The analysis should
 include the parameters considered and the common case values for each - the

=== modified file 'doc/developers/planned-change-integration.txt'
--- doc/developers/planned-change-integration.txt	2009-06-10 05:03:42 +0000
+++ doc/developers/planned-change-integration.txt	2009-12-02 20:34:07 +0000
@@ -37,7 +37,7 @@
    provide strong feedback to the design process for those things which are
    considered optional or removable, so these APIs should be implemented
    before removing or making optional existing data.
- 
+
  * Deprecating versioned files as a supported API: This collaborates with the
    Repository API but can probably be done by adding a replacement API for
    places where the versioned-file api is used. We may well want to keep a
@@ -54,7 +54,7 @@
    layer changes to inventories so while we can create a revision validator
    API, we cannot create the final one until we have the inventory structural
    changes completed.
- 
+
  * Annotation caching API: This API is a prerequisite for new repository
    formats. If written after they are introduced we may find that the
    repository is lacking in functionality, so the API should be implemented
@@ -87,7 +87,7 @@
    of the newer API for accessing data about a file over time. It can be a
    separate step easily; but as it's in the same area of the library should not
    be done in parallel.
-  
+
  * Repository stacking API: The key dependency/change required for this is that
    repositories must individually be happy with having partial data - e.g. many
    ghosts. However the way the API needs to be used should be driven from the
@@ -97,7 +97,7 @@
    On the data insertion side commit will want to generate new data. The
    commands pull, bundle, merge, push, possibly uncommit will want to copy
    existing data in a streaming fashion.
- 
+
  * New container format: Its hard to tell what the right way to structure the
    layering is. Probably having smooth layering down to the point that code
    wants to operate on the containers directly will make this more clear. As
@@ -129,7 +129,7 @@
  * Delta storage optimisation: This has a strict dependency on a new repository
    format. Optimisation takes many forms - we probably cannot complete the
    desired optimisations under knits though we could use xdelta within a
-   knit-variation. 
+   knit-variation.
 
  * Greatest distance from origin cache: The potential users of this exist
    today, it is likely able to be implemented immediately, but we are not sure

=== modified file 'doc/developers/planned-performance-changes.txt'
--- doc/developers/planned-performance-changes.txt	2009-04-04 02:57:47 +0000
+++ doc/developers/planned-performance-changes.txt	2009-12-02 20:34:07 +0000
@@ -93,7 +93,7 @@
  * New container format to allow single-file description of multiple named
    objects. This will provide the basis for transmission of revisions over the
    network, the new bundle format, and possibly a new repository format as
-   well. [Core implemented] 
+   well. [Core implemented]
 
  * Separate the annotation cache from the storage of actual file texts and make
    the annotation style, and when to do it, configurable. This will reduce data

=== modified file 'doc/developers/plans.txt'
--- doc/developers/plans.txt	2009-09-07 07:44:36 +0000
+++ doc/developers/plans.txt	2009-12-02 20:34:07 +0000
@@ -10,7 +10,7 @@
    improved_chk_index
 
 
-* `Performance roadmap <performance-roadmap.html>`_ |--| The roadmap 
+* `Performance roadmap <performance-roadmap.html>`_ |--| The roadmap
   for fixing performance in bzr over the next few releases.
 
 * `Co-located branches <colocated-branches.html>`_ |--| Planned(?) support

=== modified file 'doc/developers/plugin-api.txt'
--- doc/developers/plugin-api.txt	2009-08-03 11:37:53 +0000
+++ doc/developers/plugin-api.txt	2009-12-02 20:34:07 +0000
@@ -128,7 +128,7 @@
 
   # (look for a .hg directory)
   bzr_control_formats = {"Mercurial":{'.hg/': None}}
-  
+
   # (look for a file called .svn/format with contents 4\n).
   bzr_control_formats = {"Subversion":{'.svn/format': '4\n'}}
 
@@ -137,15 +137,15 @@
 -------
 
 An example setup.py follows::
-  
+
   #!/usr/bin/env python2.4
   from distutils.core import setup
-  
+
   bzr_plugin_name = 'demo'
   bzr_commands = [
       'new-command',
       ]
-  
+
   bzr_branch_formats = {
       "Branch label on disk\n":"demo branch",
       }
@@ -153,10 +153,10 @@
   bzr_control_formats = {"Subversion":{'.svn/format': '4\n'}}
 
   bzr_transports = ["hg+ssh://"]
-  
+
   bzr_plugin_version = (1, 3, 0, 'dev', 0)
   bzr_minimum_version = (1, 0, 0)
-  
+
   if __name__ == 'main':
       setup(name="Demo",
             version="1.3.0dev0",

=== modified file 'doc/developers/ppa.txt'
--- doc/developers/ppa.txt	2009-09-02 10:41:30 +0000
+++ doc/developers/ppa.txt	2009-12-02 20:34:07 +0000
@@ -38,7 +38,7 @@
 versions it is also copied to the main PPA.
 
 The packaging information is kept in branches of bzr on Launchpad, named
-like 
+like
 <https://code.launchpad.net/~bzr/bzr/packaging-hardy>.
 or
 <lp:~bzr/bzr/packaging-hardy>.  These branches are intended to be used
@@ -46,8 +46,8 @@
 
 Preconditions
 -------------
-  
-* You must have a Launchpad account and be a member of the teams 
+
+* You must have a Launchpad account and be a member of the teams
   that own these PPAs (``~bzr``, ``~bzr-beta-ppa``).
 
 * You must have a GPG key registered to your Launchpad account.
@@ -75,7 +75,7 @@
 
     [DEFAULT]
     default_host_main = notspecified
-  
+
 * Configure ``bzr-builddeb`` to sign the package, which is required for
   Launchpad to build it.  Put this in ``~/.bazaar/builddeb.conf`` ::
 
@@ -189,7 +189,7 @@
       dch -v '1.17~rc1-1~bazaar1~hardy1' -D hardy
 
    dch will default to the distro you're working in and this isn't checked
-   against the version number (which is just our convention), so make sure 
+   against the version number (which is just our convention), so make sure
    to specify it.
 
    Make sure you have the correct email address for yourself (you may need
@@ -197,9 +197,9 @@
    distribution.  It should look something like this::
 
        bzr (1.17~rc1-1~bazaar1~hardy1) hardy; urgency=low
-     
+
         * New upstream release.
-     
+
        -- John Sample <sample@example.com>  Mon, 31 Mar 2008 12:36:27 +1100
 
    If you need to upload the package again to fix a problem, normally you
@@ -251,7 +251,7 @@
 Packaging bzr-svn
 ~~~~~~~~~~~~~~~~~
 
-bzr-svn uses a packaging branch that contains both the source 
+bzr-svn uses a packaging branch that contains both the source
 (including any changes against upstream) and the ``debian/`` directory.
 
 To build bzr-svn:

=== modified file 'doc/developers/process.txt'
--- doc/developers/process.txt	2009-09-09 02:21:47 +0000
+++ doc/developers/process.txt	2009-12-02 20:34:07 +0000
@@ -14,8 +14,8 @@
 
 * `The Bazaar Development Cycle <cycle.html>`_ |--| The monthly
   development cycle and how to run it.
-  
-* `Releasing Bazaar <releasing.html>`_ |--| 
+
+* `Releasing Bazaar <releasing.html>`_ |--|
   Checklist to make a release of Bazaar.
 
 * `Managing the Bazaar PPA <ppa.html>`_ |--| Packaging Bazaar for Ubuntu.
@@ -23,13 +23,13 @@
 * `Giving back <http://bazaar-vcs.org/BzrGivingBack>`_ (wiki) |--| How to get
   your changes to Bazaar integrated into a release.
 
-* `Profiling notes <profiling.html>`_ |--| Instructions on how to profile 
+* `Profiling notes <profiling.html>`_ |--| Instructions on how to profile
   bzr code and visualize the results.
 
-* `EC2 resources <ec2.html>`_ |--| A team resource for 
+* `EC2 resources <ec2.html>`_ |--| A team resource for
   Windows packaging and testing, and Ubuntu testing.
 
-* `Tracking Bugs in Bazaar <bug-handling.html>`_ |--| How we use the bug 
+* `Tracking Bugs in Bazaar <bug-handling.html>`_ |--| How we use the bug
   tracker.
 
 

=== modified file 'doc/developers/profiling.txt'
--- doc/developers/profiling.txt	2007-08-08 14:12:02 +0000
+++ doc/developers/profiling.txt	2009-12-02 20:34:07 +0000
@@ -50,7 +50,7 @@
 global option.
 
 This writes messages into ``~/.bzr.log``.
-At present this only logs actions relating to the on-disk lockdir.  It 
+At present this only logs actions relating to the on-disk lockdir.  It
 doesn't describe actions on in-memory lock counters, or OS locks (which
 are used for dirstate.)
 

=== modified file 'doc/developers/releasing.txt'
--- doc/developers/releasing.txt	2009-12-01 10:33:50 +0000
+++ doc/developers/releasing.txt	2009-12-02 20:34:07 +0000
@@ -2,7 +2,7 @@
 ================
 
 This document describes the processes for making and announcing a Bazaar
-release, and managing the release process.  This is just one phase of the 
+release, and managing the release process.  This is just one phase of the
 `overall development cycle <http://doc.bazaar-vcs.org/developers/cycle.html>`_,
 but it's the most complex part.
 This document gives a checklist you can follow from start to end in one
@@ -42,7 +42,7 @@
    will be available for targeting or nominating bugs.
 
 #. We create a new pqm-controlled branch for this release series, by
-   asking a Canonical sysadmin.  
+   asking a Canonical sysadmin.
    This branch means that from the first release beta or candidate onwards,
    general development continues on the trunk, and only
    specifically-targeted fixes go into the release branch.
@@ -61,7 +61,7 @@
    or that interact with other changes. This is called the metronome mail
    and is described in `Development cycles <cycle.html>`_.
 
-#. Make a local branch for preparing this release.  (Only for the first 
+#. Make a local branch for preparing this release.  (Only for the first
    release in a series, otherwise you should already have a branch.) ::
 
      bzr branch trunk prepare-1.14
@@ -123,18 +123,18 @@
 #. Summarize into one or two paragraphs what's new in this release.
 
 #. Commit these changes to the release branch, using a command like::
-    
-     bzr commit -m "Release 1.14." 
-   
+
+     bzr commit -m "Release 1.14."
+
    The diff before you commit will be something like::
 
      === modified file 'NEWS'
      --- NEWS        2008-09-17 23:09:18 +0000
      +++ NEWS        2008-09-23 16:14:54 +0000
      @@ -4,6 +4,23 @@
-     
+
       .. contents::
-     
+
      +bzr 1.7 2008-09-23
      +------------------
      +
@@ -147,21 +147,21 @@
      +
       bzr 1.7rc2 2008-09-17
       ---------------------
-     
-     
+
+
      === modified file 'bzrlib/__init__.py'
      --- bzrlib/__init__.py  2008-09-16 21:39:28 +0000
      +++ bzrlib/__init__.py  2008-09-23 16:14:54 +0000
      @@ -41,7 +41,7 @@
       # Python version 2.0 is (2, 0, 0, 'final', 0)."  Additionally we use a
       # releaselevel of 'dev' for unreleased under-development code.
-     
+
      -version_info = (1, 7, 0, 'candidate', 2)
      +version_info = (1, 7, 0, 'final', 0)
-     
-     
+
+
       # API compatibility version: bzrlib is currently API compatible with 1.7.
-      
+
 #. Tag the new release::
 
      bzr tag bzr-1.14
@@ -170,7 +170,7 @@
    the Internet. PQM will pull from this repository when it attempts to merge
    your changes. Then submit those changes to PQM for merge into the
    appropriate release branch::
- 
+
      bzr push
      bzr pqm-submit -m "(mbp) prepare 1.14"
 
@@ -181,12 +181,12 @@
 -------------------------
 
 #. Change into the source directory and run ::
-  
+
      make dist
 
 #. Now we'll try expanding this tarball and running the test suite
    to check for packaging problems::
- 
+
      make check-dist-tarball
 
    You may encounter failures while running the test suite caused
@@ -259,28 +259,28 @@
    ``bazaar-announce`` list too.
 
    For final releases, it should also be cc'd to ``info-gnu@gnu.org``,
-   ``python-announce-list@python.org``, ``bug-directory@gnu.org``.  
+   ``python-announce-list@python.org``, ``bug-directory@gnu.org``.
 
    In all cases, it is good to set ``Reply-To: bazaar@lists.canonical.com``,
    so that people who reply to the announcement don't spam other lists.
 
    The announce mail will look something like this::
-   
+
       Subject: bzr x.yy released!
-      
+
       <<Summary paragraph from news>>
-     
-      The Bazaar team is happy to announce availability of a new 
+
+      The Bazaar team is happy to announce availability of a new
       release of the bzr adaptive version control system.
       Bazaar is part of the GNU system <http://gnu.org/>.
-     
+
       Thanks to everyone who contributed patches, suggestions, and
       feedback.
-      
-      Bazaar is now available for download from 
-      http://bazaar-vcs.org/Download as a source tarball; packages 
+
+      Bazaar is now available for download from
+      http://bazaar-vcs.org/Download as a source tarball; packages
       for various systems will be available soon.
-      
+
       <<NEWS section from this release back to the last major release>>
 
    Feel free to tweak this to your taste.
@@ -291,7 +291,7 @@
    ensuring the new topic text keeps the project name, web site link, etc.
 
 #. Announce on http://freshmeat.net/projects/bzr/
-   
+
    This should be done for beta releases, release candidates and final
    releases. If you do not have a Freshmeat account yet, ask one of the
    existing admins.

=== modified file 'doc/developers/repository-stream.txt'
--- doc/developers/repository-stream.txt	2008-04-16 04:07:40 +0000
+++ doc/developers/repository-stream.txt	2009-12-02 20:34:07 +0000
@@ -158,7 +158,7 @@
 record. Each item that the iterator yields is a factory which has metadata
 about the entry and the ability to return the compressed bytes. This
 factory can be decorated to allow obtaining different representations (for
-example from a compressed knit fulltext to a plain fulltext). 
+example from a compressed knit fulltext to a plain fulltext).
 
 In pseudocode::
 

=== modified file 'doc/developers/repository.txt'
--- doc/developers/repository.txt	2008-03-19 09:41:24 +0000
+++ doc/developers/repository.txt	2009-12-02 20:34:07 +0000
@@ -44,7 +44,7 @@
                     introduced by a set of revisions in some cheap form, insert
                     data from a stream, validate data during insertion.
 Garbage Collection  Exclusive lock the repository preventing readers.
-Revert              Delta from working tree to historical tree, and then 
+Revert              Delta from working tree to historical tree, and then
                     arbitrary file access to obtain the texts of differing
                     files.
 Uncommit            Revision graph access.
@@ -98,7 +98,7 @@
                      Scan the inventory data introduced during the selected
                      revisions, and grab the on disk data for the found
                      file texts, annotation region data, per-file-graph
-                     data, piling all this into a stream. 
+                     data, piling all this into a stream.
 Garbage Collection   Basically a mass fetch of all the revisions which
                      branches point at, then a bait and switch with the old
                      repository thus removing unreferenced data.
@@ -106,14 +106,14 @@
                      to, inventory extraction of that revision,
                      dirblock-order file text extract for files that were
                      different.
-Uncommit             Revision graph access to synthesise pending-merges 
+Uncommit             Revision graph access to synthesise pending-merges
                      linear access down left-hand-side, with is_ancestor
                      checks between all the found non-left-hand-side
                      parents.
 Status               Lookup the revisions added by pending merges and their
                      commit messages. Then an inventory difference between
                      the trees involved, which may include a working tree.
-                     If there is a working tree involved then the file 
+                     If there is a working tree involved then the file
                      fingerprint for cache-misses on files will be needed.
                      Note that dirstate caches most of this making
                      repository performance largely irrelevant: but if it
@@ -256,7 +256,7 @@
 delta-compressed ever. Likewise signatures do not need the parent pointers
 at all as there is no 'signature graph'.
 
-Data 
+Data
 ----
 
 Moving to pack based repositories
@@ -273,7 +273,7 @@
 hashing the full file. OTOH hashing the full file is a cheap way to detect
 bit-errors in transfer (such as windows corruption). Non-reused file names
 are required for data integrity, as clients having read an index will
-readv at arbitrary times later. 
+readv at arbitrary times later.
 
 Discovery of files
 ~~~~~~~~~~~~~~~~~~
@@ -304,7 +304,7 @@
 ============================
 
 Repositories try to provide a consistent view of the data within them
-within a 'lock context'. 
+within a 'lock context'.
 
 Locks
 -----
@@ -318,7 +318,7 @@
 write lock, and allow write_groups to be acquired. For some repositories
 the presence of a write lock is exclusive to a single client, for others
 which are lock free or use server side locks (e.g.  svn), the write lock
-simply provides the cache context. 
+simply provides the cache context.
 
 Write Groups
 ------------

=== modified file 'doc/developers/revert.txt'
--- doc/developers/revert.txt	2007-06-05 08:02:04 +0000
+++ doc/developers/revert.txt	2009-12-02 20:34:07 +0000
@@ -21,6 +21,6 @@
  1. Use the hash tree data to tune the work done in finding matching paths/ids which are different in the two trees.
 
 For each thing that needs to change - group by target directory?
- 
+
  1. Extract new content.
  1. Backup old content or replace-in-place (except windows where we move and replace).

=== modified file 'doc/developers/specifications.txt'
--- doc/developers/specifications.txt	2009-09-07 07:44:36 +0000
+++ doc/developers/specifications.txt	2009-12-02 20:34:07 +0000
@@ -67,7 +67,7 @@
   Contains instructions for those implementing new formats, of course,
   but also for (bleeding-edge) end users of those formats.
 
-* `Knit pack repositories <packrepo.html>`_ |--| KnitPack repositories 
+* `Knit pack repositories <packrepo.html>`_ |--| KnitPack repositories
   (new in Bazaar 0.92).
 
 

=== modified file 'doc/developers/status.txt'
--- doc/developers/status.txt	2007-07-02 07:11:25 +0000
+++ doc/developers/status.txt	2009-12-02 20:34:07 +0000
@@ -54,7 +54,7 @@
    our hash cache from the dirstate allows us to avoid reading the file in the
    common case. There are alternative ways to achieve this - we could record
    a pointer to a revision which contained this fileid with the current content
-   rather than storing the content's hash; but this seems to be a pointless 
+   rather than storing the content's hash; but this seems to be a pointless
    double-indirection unless we save enough storage in the working tree. A
    variation of this is to not record an explicit pointer but instead
    define an implicit pointer as being to the left-hand-parent tree.
@@ -92,7 +92,7 @@
   difference for the top level of the selected path) then we can gain a
   larger win. This strongly suggests that path expansion and tree
   difference generation should be linked in terms of API.
- 
+
 
 
 ..

=== modified file 'doc/developers/testing.txt'
--- doc/developers/testing.txt	2009-09-18 08:55:12 +0000
+++ doc/developers/testing.txt	2009-12-02 20:34:07 +0000
@@ -154,7 +154,7 @@
     cmd_object.run() method directly. This is a lot faster than
     subprocesses and generates the same logging output as running it in a
     subprocess (which invoking the method directly does not).
- 
+
  3. Only test the one command in a single test script. Use the bzrlib
     library when setting up tests and when evaluating the side-effects of
     the command. We do this so that the library api has continual pressure
@@ -225,10 +225,10 @@
 the line.
 
 The execution stops as soon as an expected output or an expected error is not
-matched. 
+matched.
 
 When no output is specified, any ouput from the command is accepted
-and execution continue. 
+and execution continue.
 
 If an error occurs and no expected error is specified, the execution stops.
 
@@ -343,7 +343,7 @@
         The test exists but is known to fail, for example this might be
         appropriate to raise if you've committed a test for a bug but not
         the fix for it, or if something works on Unix but not on Windows.
-        
+
         Raising this allows you to distinguish these failures from the
         ones that are not expected to fail.  If the test would fail
         because of something we don't expect or intend to fix,
@@ -369,7 +369,7 @@
 UnavailableFeature      fail    pass    pass
 KnownFailure            fail    pass    pass
 ======================= ======= ======= ========
-     
+
 
 Test feature dependencies
 -------------------------
@@ -416,13 +416,13 @@
 ``_probe`` and ``feature_name`` methods.  For example::
 
     class _SymlinkFeature(Feature):
-    
+
         def _probe(self):
             return osutils.has_symlinks()
-    
+
         def feature_name(self):
             return 'symlinks'
-    
+
     SymlinkFeature = _SymlinkFeature()
 
 

=== modified file 'doc/developers/tortoise-strategy.txt'
--- doc/developers/tortoise-strategy.txt	2008-05-21 06:33:35 +0000
+++ doc/developers/tortoise-strategy.txt	2009-12-02 20:34:07 +0000
@@ -42,15 +42,15 @@
 exist in a separate process - DLLs are the only option, and they are loaded
 into other processes which take advantage of the Windows shell (although
 obviously this DLL is free to do whatever it likes).
- 
+
 For the sake of this discussion, there are 2 categories of shell extensions:
- 
+
 * Ones that create a new "namespace". The file-system itself is an example of
   such a namespace, as is the "Recycle Bin". For a user-created example,
   picture a new tree under "My Computer" which allows you to browse a remote
   server - it creates a new, stand-alone tree that doesn't really interact
   with the existing namespaces.
- 
+
 * Ones that enhance existing namespaces, including the filesystem. An example
   would be an extension which uses Icon Overlays to modify how existing files
   on disk are displayed or add items to their context menu, for example.
@@ -71,7 +71,7 @@
 this illustration is contrived - the code from these DLLs are already in
 memory and there is no reason to suggest TSVN adds any other unreasonable
 burden - but the general point remains valid.)
- 
+
 This has wide-ranging implications. It means that such shell extensions
 should be developed using a tool which can never cause conflict with
 arbitrary processes. For this very reason, MS recommend against using .NET
@@ -113,7 +113,7 @@
 commands. The command-line to the app has even been documented for people who
 wish to automate tasks using that GUI. This GUI is also implemented in C++
 using Windows resource files.
- 
+
 TortoiseSvn has an option (enabled by default) which enabled a cache using a
 separate process, aptly named TSVNCache.exe. It uses a named pipe to accept
 connections from other processes for various operations. When enabled, TSVN
@@ -149,11 +149,11 @@
 application using the shell. The GUI in the external application is written
 in PyGTK, which may not offer the best Windows "look and feel", but that
 discussion is beyond the scope of this document.
- 
+
 It has a better story for logging and debugging for the developer - but not
 for diagnosing issues in the field - although again, much of the heavy
 lifting remains done by the external application.
- 
+
 It uses a rudimentary in-memory cache for the status of files and
 directories, the implementation of which isn't really suitable (ie, no
 theoretical upper bound on cache size), and also means that there is no
@@ -261,7 +261,7 @@
 We will also allow all of the above to be disabled via user preferences.
 Thus, Icon Overlays could be disabled if it did cause a problem for some
 people, for example.
- 
+
 RPC options
 ~~~~~~~~~~~
 
@@ -433,7 +433,7 @@
   version. We will fork the current TSVN sources, including its new
   support for sharing icon overlays (although advice on how to setup this
   fork is needed!)
- 
+
 * Implement property pages and context menus in C++. Expand RPC server as
   necessary.
 

=== modified file 'doc/developers/update.txt'
--- doc/developers/update.txt	2007-09-03 02:37:35 +0000
+++ doc/developers/update.txt	2009-12-02 20:34:07 +0000
@@ -1,7 +1,7 @@
 "bzr update" performance analysis
 =================================
 
-There are 5 different slightly different situations in which bzr update 
+There are 5 different slightly different situations in which bzr update
 can be used:
 
 * local only (no-op)
@@ -27,7 +27,7 @@
 
 potential issue w/ serialized is having 50k files in limbo/
 
-the limbo/ directory could be avoided in some cases, for example when 
+the limbo/ directory could be avoided in some cases, for example when
 adding new files in new directories.
 
 modifying in place: reduces fragmentation of fs, not atomic
@@ -36,9 +36,9 @@
 
 "local mod" is diff between disk and last commit, not merge base
 
-Detecting name conflicts should be O(siblings). Alternatively, conflicts 
-with existing files can be detected using stat() and conflicts with new files 
-can be detected by examining the pending transform. This changes 
+Detecting name conflicts should be O(siblings). Alternatively, conflicts
+with existing files can be detected using stat() and conflicts with new files
+can be detected by examining the pending transform. This changes
 complexity to O(changes).
 
 out of date heavyweight checkout, out of date w/master

=== modified file 'doc/developers/win32_build_setup.txt'
--- doc/developers/win32_build_setup.txt	2009-11-19 20:31:19 +0000
+++ doc/developers/win32_build_setup.txt	2009-12-02 20:34:07 +0000
@@ -50,7 +50,7 @@
 
 3) Configure 'distutils' for the compiler that you will be using. For python
    2.4 and 2.5 we use gcc-mingw32, for 2.6 we use Visual Studio 2008.
-   
+
    Edit ``D:\Python25\Lib\disutils\distutils.cfg`` (you have to create the
    file). You want to add a section like::
 
@@ -61,7 +61,7 @@
    can find it. Specifically, it knows to look for ``gcc.exe`` however, the
    latest versions of cygwin start using "alternatives" and making ``gcc`` just
    a symlink.
-   
+
    You also need to add ``C:\cygwin\bin`` and ``C:\cygwin\lib`` into your
    environment path. This is generally done with::
 
@@ -119,7 +119,7 @@
 
    I usually get the 'all-in-one' installer, but only because it is easier. You
    only really need ``pageant.exe`` and possibly ``puttygen.exe``.
-   
+
    If you do this, you'll probably also want to install a shortcut to
    ``pageant.exe`` in Start / Programs / Startup so that it always starts when
    you log in (though you still have to manually add your ssh keys.)
@@ -128,7 +128,7 @@
    being created without the permission for the current user to actually read
    them. They seem to be owned by ``Administrator`` rather than by
    ``Administrators``.
-   
+
 6) Install bzr. Usually it is easiest to just get the latest all-in-one
    installer from https://launchpad.net/bzr/+download
 
@@ -204,5 +204,5 @@
     Studio key already supplied. There is also the possibility of using Visual
     Studio Express Edition, but it is currently unable to compile TortoiseBzr.
 
-.. 
+..
    vim: ft=rst tw=79 et

=== modified file 'doc/en/mini-tutorial/index.txt'
--- doc/en/mini-tutorial/index.txt	2009-11-24 14:34:42 +0000
+++ doc/en/mini-tutorial/index.txt	2009-12-02 23:09:40 +0000
@@ -6,13 +6,13 @@
 ============
 
 Bazaar is a distributed version control system that makes it easier for
-people to work together on software projects. 
+people to work together on software projects.
 
 Over the next five minutes, you'll learn how to put your files under
 version control, how to record changes to them, examine your work, publish
 it and send your work for merger into a project's trunk.
 
-If you'd prefer a more detailed introduction, take a look at 
+If you'd prefer a more detailed introduction, take a look at
 `Learning More`_.
 
 
@@ -44,7 +44,7 @@
 Using your name and email address, instead of John Doe's, type::
 
   $ bzr whoami "John Doe <john.doe@gmail.com>"
-  
+
 Bazaar will now create or modify a configuration file, including your
 name and email address.
 
@@ -63,15 +63,15 @@
  $ cd myproject
  $ mkdir subdirectory
  $ touch test1.txt test2.txt test3.txt subdirectory/test4.txt
- 
+
 **Note for Windows users:** use Windows Explorer to create your
-directories, then right-click in those directories and select 
+directories, then right-click in those directories and select
 ``New file`` to create your files.
 
 Now get Bazaar to initialize itself in your project directory::
 
   $ bzr init
-  
+
 If it looks like nothing happened, don't worry. Bazaar has created a
 branch_ where it will store your files and their revision histories.
 
@@ -87,13 +87,13 @@
  added test3.txt
  added subdirectory/test4.txt
 
-Next, take a snapshot of your files by committing them to your branch. Add 
+Next, take a snapshot of your files by committing them to your branch. Add
 a message to explain why you made the commit::
 
   $ bzr commit -m "Initial import"
-  
-As Bazaar is a distributed version control system, it doesn't need to 
-connect to a central server to make the commit. Instead, Bazaar stores your 
+
+As Bazaar is a distributed version control system, it doesn't need to
+connect to a central server to make the commit. Instead, Bazaar stores your
 branch and all its commits inside the directory you're working with; look
 for the ``.bzr`` sub-directory.
 
@@ -156,14 +156,14 @@
 
  $ bzr push --create-prefix sftp://your.name@example.com/~/public_html/myproject
  2 revision(s) pushed.
- 
+
 Bazaar will create a ``myproject`` directory on the remote server and
 push your branch to it.
- 
+
 Now anyone can create their own copy of your branch by typing::
 
  $ bzr branch http://www.example.com/myproject
- 
+
 **Note:** to use sftp, you may need to install ``paramiko`` and
 ``pyCrypto``. See http://bazaar-vcs.org/InstallationFaq for details.
 
@@ -171,7 +171,7 @@
 Publishing your branch with Launchpad
 =====================================
 
-Launchpad is a suite of development and hosting tools for free 
+Launchpad is a suite of development and hosting tools for free
 software projects. You can use it to publish your branch.
 
 If you don't have a Launchpad account, follow the `account signup guide`_
@@ -200,18 +200,18 @@
 Creating your own copy of another branch
 ========================================
 
-To work with someone else's code, you can make your own copy of their 
+To work with someone else's code, you can make your own copy of their
 branch. Let's take a real-world example, Bazaar's GTK interface::
 
   $ bzr branch lp:~bzr/bzr-gtk/trunk bzr-gtk.john
-  Branched 292 revision(s).                                                        
+  Branched 292 revision(s).
 
 Bazaar will download all the files and complete revision history from the
 bzr-gtk project's trunk branch and create a copy called bzr-gtk.john.
 
-Now, you have your own copy of the branch and can commit changes with 
-or without a net connection. You can share your branch at any time by 
-publishing it and, if the  bzr-gtk team want to use your work, Bazaar 
+Now, you have your own copy of the branch and can commit changes with
+or without a net connection. You can share your branch at any time by
+publishing it and, if the  bzr-gtk team want to use your work, Bazaar
 makes it easy for them to merge your branch back into their trunk branch.
 
 
@@ -227,11 +227,11 @@
   $ bzr merge
   Merging from saved parent location: http://bazaar.launchpad.net/~bzr/bzr-gtk/trunk
   All changes applied successfully.
-            
+
 Check what has changed::
 
   $ bzr diff
- 
+
 If you're happy with the changes, you can commit them to your personal
 branch::
 
@@ -246,20 +246,20 @@
 send your changes back upstream to the project. The easiest way is to
 use a merge directive.
 
-A merge directive is a machine-readable request to perform a 
-particular merge.  It usually contains a patch preview of the merge 
-and either contains the necessary revisions, or provides a branch 
+A merge directive is a machine-readable request to perform a
+particular merge.  It usually contains a patch preview of the merge
+and either contains the necessary revisions, or provides a branch
 where they can be found.
 
 Replacing ``mycode.patch``, create your merge directive::
 
  $ bzr send -o mycode.patch
  Using saved parent location: http://bazaar.launchpad.net/~bzr/bzr-gtk/trunk
- 
+
 You can now email the merge directive to the bzr-gtk project who, if
 they choose, can use it merge your work back into the parent branch.
- 
- 
+
+
 Learning more
 =============
 

=== modified file 'doc/en/tutorials/centralized_workflow.txt'
--- doc/en/tutorials/centralized_workflow.txt	2009-11-03 18:01:09 +0000
+++ doc/en/tutorials/centralized_workflow.txt	2009-12-02 20:34:07 +0000
@@ -38,7 +38,7 @@
 be accurate or unique, it will be used in log messages and
 annotations, so it is better to have something real.
 
-::  
+::
 
    % bzr whoami "John Doe <jdoe@organization.com>"
 
@@ -102,7 +102,7 @@
 
 .. _Tracking Upstream: http://bazaar-vcs.org/TrackingUpstream
 
-.. 
+..
    XXX: We really need a different document for discussing conversion of a
    project. Right now TrackingUpstream is the best we have, though.
 
@@ -282,7 +282,7 @@
 ::
 
   % bzr branch sftp://centralhost/srv/bzr/sigil/user-a \
-               sftp://centralhost/srv/bzr/sigil/user-a/feature 
+               sftp://centralhost/srv/bzr/sigil/user-a/feature
   % cd ~/work/sigil
   % bzr checkout sftp://centralhost/srv/bzr/sigil/user-a/feature myfeature
 
@@ -310,5 +310,5 @@
 well share the storage as well.
 
 
-.. 
+..
    vim: tw=74 ft=rst spell spelllang=en_us

=== modified file 'doc/en/tutorials/tutorial.txt'
--- doc/en/tutorials/tutorial.txt	2009-11-19 23:30:19 +0000
+++ doc/en/tutorials/tutorial.txt	2009-12-02 20:34:07 +0000
@@ -2,7 +2,7 @@
 .. into HTML or text.  In the future we plan to extract the example commands
 .. and automatically test them.
 
-.. This text was previously on the wiki at 
+.. This text was previously on the wiki at
 .. http://bazaar.canonical.com/IntroductionToBzr
 .. but has been moved into the source tree so it can be kept in sync with
 .. the source and possibly automatically checked.
@@ -20,7 +20,7 @@
 on the other hand, you are familiar with revision control but not
 decentralized revision control, then please start at "How DRCS is
 different." Otherwise, get some coffee or tea, get comfortable and get
-ready to catch up. 
+ready to catch up.
 
 The purpose of revision control
 ===============================
@@ -45,7 +45,7 @@
 Revision control systems give users the ability to save changes to a
 branch by "committing a **revision**". The revision created is essentially
 a summary of the changes that were made since the last time the tree was
-saved. 
+saved.
 
 These revisions have other uses as well. For example, one can comment
 revisions to record what the recent set of changes meant by providing an
@@ -53,7 +53,7 @@
 the web template to close the table" and "Added sftp suppport. Fixes #595"
 	
 We keep these logs so that if later there is some sort of problem with
-sftp, we can figure out when the problem probably happened. 
+sftp, we can figure out when the problem probably happened.
 
 How DRCS is different
 =====================
@@ -63,7 +63,7 @@
 server and "checkout" the code. Doing so gives one a directory in which a
 person can make changes and then commit. The RCS client then connects to
 the RCS server and stores the changes. This method is known as the
-centralized model. 
+centralized model.
 
 The centralized model can have some drawbacks. A centralized RCS requires
 that one is able to connect to the server whenever one wants to do version
@@ -79,13 +79,13 @@
 user only needs internet access when he wants to access the changes in
 someone else's branch that are somewhere else.
 
- 
+
 A common requirement that many people have is the need to keep track of
 the changes for a directory such as file and subdirectory changes.
 Performing this tracking by hand is a awkward process that over time
 becomes unwieldy. That is, until one considers version control tools such
 as Bazaar. These tools automate the process of storing data by creating
-a **revision** of the directory tree whenever the user asks. 
+a **revision** of the directory tree whenever the user asks.
 
 Revision control software such as Bazaar can do much more than just
 storage and performing undo.  For example, with Bazaar a developer can
@@ -105,7 +105,7 @@
 ==============================
 
 Bazaar installs a single new command, **bzr**.  Everything else is a
-subcommand of this.  You can get some help with ``bzr help``. Some arguments 
+subcommand of this.  You can get some help with ``bzr help``. Some arguments
 are grouped in topics: ``bzr help topics`` to see which topics are available.
 
 One function of a version control system is to keep track of who changed
@@ -147,7 +147,7 @@
 
 .. [1] On Windows, the users configuration files can be found in the
    application data directory. So instead of ``~/.bazaar/branch.conf``
-   the configuration file can be found as: 
+   the configuration file can be found as:
    ``C:\Documents and Settings\<username>\Application Data\Bazaar\2.0\branch.conf``.
    The same is true for ``locations.conf``, ``ignore``, and the
    ``plugins`` directory.
@@ -230,9 +230,9 @@
 its test suite before committing, to make sure that every revision is a
 known-good state.  You can also review your changes, to make sure you're
 committing what you intend to, and as a chance to rethink your work before
-you permanently record it. 
+you permanently record it.
 
-Two bzr commands are particularly useful here: **status** and **diff**.  
+Two bzr commands are particularly useful here: **status** and **diff**.
 
 bzr status
 ----------
@@ -277,7 +277,7 @@
 Some projects prefer patches to show a prefix at the start of the path
 for old and new files.  The ``--prefix`` option can be used to provide
 such a prefix.
-As a shortcut, ``bzr diff -p1`` produces a form that works with the 
+As a shortcut, ``bzr diff -p1`` produces a form that works with the
 command ``patch -p1``.
 
 
@@ -285,7 +285,7 @@
 ==================
 
 When the working tree state is satisfactory, it can be **committed** to
-the branch, creating a new revision holding a snapshot of that state.  
+the branch, creating a new revision holding a snapshot of that state.
 
 bzr commit
 ----------
@@ -406,10 +406,10 @@
 bzr ignore
 ----------
 
-As an alternative to editing the ``.bzrignore`` file, you can use the 
+As an alternative to editing the ``.bzrignore`` file, you can use the
 ``bzr ignore`` command. The ``bzr ignore`` command takes filenames and/or
 patterns as arguments and then adds them to the ``.bzrignore`` file. If a
-``.bzrignore`` file does not exist the ``bzr ignore`` command will 
+``.bzrignore`` file does not exist the ``bzr ignore`` command will
 automatically create one for you, and implicitly add it to be versioned::
 
     % bzr ignore tags
@@ -455,7 +455,7 @@
 =================
 
 The ``bzr info`` command shows some summary information about the working
-tree and the branch history.  
+tree and the branch history.
 
 
 Versioning directories
@@ -484,7 +484,7 @@
 
 ``bzr remove`` makes the file un-versioned, but may or may not delete the
 working copy [2]_.  This is useful when you add the wrong file, or decide that
-a file should actually not be versioned. 
+a file should actually not be versioned.
 
 ::
 
@@ -511,7 +511,7 @@
 the existing branch.  Because this new copy is potentially a new branch,
 the command is called **branch**::
 
-    % bzr branch http://bazaar-vcs.org/bzr/bzr.dev 
+    % bzr branch http://bazaar-vcs.org/bzr/bzr.dev
     % cd bzr.dev
 
 This copies down the complete history of this branch, so we can do all
@@ -530,7 +530,7 @@
     % bzr pull
 
 After this change, the local directory will be a mirror of the source. This
-includes the ''revision-history'' - which is a list of the commits done in 
+includes the ''revision-history'' - which is a list of the commits done in
 this branch, rather than merged from other branches.
 
 This command only works if your local (destination) branch is either an
@@ -584,7 +584,7 @@
 
   ::
 
-    % bzr push sftp://servername.com/path/to/directory 
+    % bzr push sftp://servername.com/path/to/directory
 
   (The destination directory must already exist unless the
   ``--create-prefix`` option is used.)
@@ -598,7 +598,7 @@
   than using ``push``, but may be faster or easier in some situations.
 
 
-Moving changes between trees 
+Moving changes between trees
 ============================
 
 It happens to the best of us: sometimes you'll make changes in the wrong

=== modified file 'doc/en/tutorials/using_bazaar_with_launchpad.txt'
--- doc/en/tutorials/using_bazaar_with_launchpad.txt	2009-09-02 16:03:51 +0000
+++ doc/en/tutorials/using_bazaar_with_launchpad.txt	2009-12-02 20:34:07 +0000
@@ -423,7 +423,7 @@
 Summary
 =======
 
-The communities we join, whether off-line or on-line, 
+The communities we join, whether off-line or on-line,
 say a lot about the sort of people we are. The flip-side
 to this is that the tools you choose for your community - particularly
 the CDE and version control tool - can have a large impact on who

=== modified file 'doc/en/user-guide/branching_a_project.txt'
--- doc/en/user-guide/branching_a_project.txt	2009-10-11 10:06:41 +0000
+++ doc/en/user-guide/branching_a_project.txt	2009-12-02 20:34:07 +0000
@@ -92,7 +92,7 @@
 the latest version.
 
 As explained in later chapters, Bazaar also has support for
-`lightweight checkouts <using_checkouts.html#getting-a-lightweight-checkout>`_ 
+`lightweight checkouts <using_checkouts.html#getting-a-lightweight-checkout>`_
 of a branch, i.e. working trees with
 no local storage of history. Of course, disconnected usage
 is not available then but that's a tradeoff you can decide

=== modified file 'doc/en/user-guide/configuring_bazaar.txt'
--- doc/en/user-guide/configuring_bazaar.txt	2008-08-14 17:25:43 +0000
+++ doc/en/user-guide/configuring_bazaar.txt	2009-12-02 20:34:07 +0000
@@ -13,7 +13,7 @@
 identifier you want::
 
     % bzr whoami "Your Name <email@example.com>"
- 
+
 If ``whoami`` is used without an argument, the current value is displayed.
 
 Configuration files

=== modified file 'doc/en/user-guide/controlling_registration.txt'
--- doc/en/user-guide/controlling_registration.txt	2008-04-18 01:06:17 +0000
+++ doc/en/user-guide/controlling_registration.txt	2009-12-02 20:34:07 +0000
@@ -100,7 +100,7 @@
 
 .. [#] On Windows, the users configuration files can be found in the
    application data directory. So instead of ``~/.bazaar/branch.conf``
-   the configuration file can be found as: 
+   the configuration file can be found as:
    ``C:\Documents and Settings\<username>\Application Data\Bazaar\2.0\branch.conf``.
    The same is true for ``locations.conf``, ``ignore``, and the
    ``plugins`` directory.

=== modified file 'doc/en/user-guide/distributed_intro.txt'
--- doc/en/user-guide/distributed_intro.txt	2008-05-06 14:34:57 +0000
+++ doc/en/user-guide/distributed_intro.txt	2009-12-02 20:34:07 +0000
@@ -19,5 +19,5 @@
 
 Other distributed workflows are explored later in this chapter.
 
-.. 
+..
    vim: tw=74 ft=rst

=== modified file 'doc/en/user-guide/http_smart_server.txt'
--- doc/en/user-guide/http_smart_server.txt	2008-10-20 09:26:03 +0000
+++ doc/en/user-guide/http_smart_server.txt	2009-12-02 20:34:07 +0000
@@ -30,7 +30,7 @@
 
     LoadModule fastcgi_module /usr/lib/apache2/modules/mod_fastcgi.so
     FastCgiIpcDir /var/lib/apache2/fastcgi
-    
+
 In our example, we're already serving `/srv/example.com/www/code` at
 `http://example.com/code`, so our existing Apache configuration would look
 like::
@@ -51,7 +51,7 @@
         RewriteBase /code
         RewriteRule ^(.*/|)\.bzr/smart$ /srv/example.com/scripts/bzr-smart.fcgi
     </Directory>
-    
+
     # bzr-smart.fcgi isn't under the DocumentRoot, so Alias it into the URL
     # namespace so it can be executed.
     Alias /srv/example.com/scripts/bzr-smart.fcgi /srv/example.com/scripts/bzr-smart.fcgi
@@ -61,7 +61,7 @@
             SetHandler fastcgi-script
         </Files>
     </Directory>
-    
+
 This instructs Apache to hand requests for any URL ending with `/.bzr/smart`
 inside `/code` to a Bazaar smart server via FastCGI.
 
@@ -136,11 +136,11 @@
         prefix='/code/',
         path_var='REQUEST_URI',
         readonly=True,
-        load_plugins=True, 
+        load_plugins=True,
         enable_logging=True)
 
     fcgi.WSGIServer(smart_server_app).run()
-        
+
 The `fcgi` module can be found at http://svn.saddi.com/py-lib/trunk/fcgi.py.  It
 is part of flup_.
 
@@ -162,14 +162,14 @@
         prefix='/code/',
         path_var='REQUEST_URI',
         readonly=True,
-        load_plugins=True, 
+        load_plugins=True,
         enable_logging=True)
 
     def handler(request):
         """Handle a single request."""
         wsgi_server = modpywsgi.WSGIServer(smart_server_app)
         return wsgi_server.run(request)
-        
+
 The `modpywsgi` module can be found at
 http://dev.pocoo.org/projects/pocoo/browser/pocoo/wrappers/modpy.py. It is
 part of pocoo_. You sould make sure you place modpywsgi.py in the same
@@ -232,5 +232,5 @@
 writable server, and plain HTTP allow read-only access.
 
 
-.. 
+..
    vim: ft=rst tw=74 et

=== modified file 'doc/en/user-guide/index-plain.txt'
--- doc/en/user-guide/index-plain.txt	2009-09-09 12:57:43 +0000
+++ doc/en/user-guide/index-plain.txt	2009-12-02 20:34:07 +0000
@@ -84,7 +84,7 @@
 .. include:: server.txt
 .. include:: hooks.txt
 .. include:: version_info.txt
- 
+
 
 A brief tour of some popular plugins
 ####################################

=== modified file 'doc/en/user-guide/index.txt'
--- doc/en/user-guide/index.txt	2009-09-02 16:03:51 +0000
+++ doc/en/user-guide/index.txt	2009-12-02 20:34:07 +0000
@@ -103,7 +103,7 @@
    server
    hooks
    version_info
- 
+
 
 A brief tour of some popular plugins
 ####################################

=== modified file 'doc/en/user-guide/introducing_bazaar.txt'
--- doc/en/user-guide/introducing_bazaar.txt	2009-06-01 22:45:06 +0000
+++ doc/en/user-guide/introducing_bazaar.txt	2009-12-02 20:34:07 +0000
@@ -18,7 +18,7 @@
 
 This guide takes you through installing Bazaar and how to use it,
 whether on your own or with a team of other people. If you're already
-familiar with distributed version control and want to dive straight in, 
+familiar with distributed version control and want to dive straight in,
 you may wish to skim this section and jump straight to
 `Learning more`_.
 
@@ -49,7 +49,7 @@
 To record or *commit* these changes, the user needs access to the central
 server and they need to ensure they have merged their work with the latest
 version stored before trying to commit. This approach is known as the
-centralized model. 
+centralized model.
 
 The centralized model has proven useful over time but it can have some notable
 drawbacks. Firstly, a centralized VCS requires that one is able to connect
@@ -87,7 +87,7 @@
      move them into the core
 
  * in companies, easier to work with distributed and outsourced teams.
-   
+
 For a detailed look at the advantages of distributed VCS tools over
 centralized VCS tools, see http://bazaar-vcs.org/BzrWhy.
 

=== modified file 'doc/en/user-guide/plugins.txt'
--- doc/en/user-guide/plugins.txt	2009-09-11 07:55:48 +0000
+++ doc/en/user-guide/plugins.txt	2009-12-02 20:34:07 +0000
@@ -15,7 +15,7 @@
 * adding new commands
 * providing additional network transports
 * customizing log output.
-  
+
 The sky is the limit for the customization that can be done through plugins.
 In fact, plugins often work as a way for developers to test new features for
 Bazaar prior to inclusion in the official codebase. Plugins are helpful
@@ -25,12 +25,12 @@
 Plugins are good for users, good for external developers and good for
 Bazaar itself.
 
-Where to find plugins 
+Where to find plugins
 ---------------------
 
 We keep our list of plugins on the http://bazaar-vcs.org/BzrPlugins page.
 
-How to install a plugin 
+How to install a plugin
 -----------------------
 
 Installing a plugin is very easy! If not already created, create a
@@ -42,7 +42,7 @@
 
 Plugins work particularly well with Bazaar branches. For example, to
 install the bzrtools plugins for your main user account on Linux,
-one can perform the following:: 
+one can perform the following::
 
     bzr branch http://panoramicfeedback.com/opensource/bzr/bzrtools
     ~/.bazaar/plugins/bzrtools

=== modified file 'doc/en/user-guide/recording_changes.txt'
--- doc/en/user-guide/recording_changes.txt	2009-03-02 13:02:13 +0000
+++ doc/en/user-guide/recording_changes.txt	2009-12-02 20:34:07 +0000
@@ -5,7 +5,7 @@
 ----------
 
 When the working tree state is satisfactory, it can be **committed** to
-the branch, creating a new revision holding a snapshot of that state.  
+the branch, creating a new revision holding a snapshot of that state.
 
 The **commit** command takes a message describing the changes in the
 revision.  It also records your userid, the current time and timezone, and

=== modified file 'doc/en/user-guide/resolving_conflicts.txt'
--- doc/en/user-guide/resolving_conflicts.txt	2008-03-05 10:26:17 +0000
+++ doc/en/user-guide/resolving_conflicts.txt	2009-12-02 20:34:07 +0000
@@ -35,7 +35,7 @@
 each file in question, fixing the relevant areas and removing the
 conflict markers as you go.
 
-After fixing all the files in conflict, and removing the markers, 
+After fixing all the files in conflict, and removing the markers,
 ask Bazaar to mark them as resolved using the ``resolve`` command like this::
 
   bzr resolve

=== modified file 'doc/en/user-guide/reviewing_changes.txt'
--- doc/en/user-guide/reviewing_changes.txt	2009-11-23 15:44:35 +0000
+++ doc/en/user-guide/reviewing_changes.txt	2009-12-02 20:34:07 +0000
@@ -8,7 +8,7 @@
 prior to permanently recording it. This way, you can make sure you'll be
 committing what you intend to.
 
-Two bzr commands are particularly useful here: **status** and **diff**.  
+Two bzr commands are particularly useful here: **status** and **diff**.
 
 bzr status
 ----------
@@ -49,7 +49,7 @@
 option to diff.
 
 ::
- 
+
     % bzr diff -c 1000            # changes from r1000
                                   # identical to -r999..1000
 
@@ -61,6 +61,6 @@
 Some projects prefer patches to show a prefix at the start of the path
 for old and new files.  The ``--prefix`` option can be used to provide
 such a prefix.
-As a shortcut, ``bzr diff -p1`` produces a form that works with the 
+As a shortcut, ``bzr diff -p1`` produces a form that works with the
 command ``patch -p1``.
 

=== modified file 'doc/en/user-guide/sending_changes.txt'
--- doc/en/user-guide/sending_changes.txt	2008-04-24 01:27:26 +0000
+++ doc/en/user-guide/sending_changes.txt	2009-12-02 20:34:07 +0000
@@ -34,11 +34,11 @@
 Creating a merge directive
 --------------------------
 
-To create and optionally send a merge directive, use the ``send`` command. 
+To create and optionally send a merge directive, use the ``send`` command.
 
 By default, ``send`` will email the merge directive to the "submission
 address" for the branch, which is typically the lead developer or the
-development mailing list.  
+development mailing list.
 ``send`` without options will create a merge directive, fire up your email
 tool and attach it, ready for you to add the explanatory text bit.
 (See the online help for ``send`` and

=== modified file 'doc/en/user-guide/server.txt'
--- doc/en/user-guide/server.txt	2009-09-17 03:16:05 +0000
+++ doc/en/user-guide/server.txt	2009-12-02 20:34:07 +0000
@@ -98,7 +98,7 @@
 server::
 
     bzr serve --port=localhost:1234 --directory=/srv/bzr/repo
-    
+
 client::
 
     bzr log bzr://localhost:1234/branchname

=== modified file 'doc/en/user-guide/setting_up_email.txt'
--- doc/en/user-guide/setting_up_email.txt	2009-04-04 02:50:01 +0000
+++ doc/en/user-guide/setting_up_email.txt	2009-12-02 20:34:07 +0000
@@ -13,7 +13,7 @@
 the email address in a revision gives others a way to contact the
 author of a revision for credit and/or blame.  :)
 
-How to set up your email address 
+How to set up your email address
 --------------------------------
 
 Bazaar will try to guess an email address based on your username and the
@@ -44,7 +44,7 @@
 
     % bzr whoami
     Joe Cool <joe@example.com>
-    
+
 Setting email via the 'whoami' command
 --------------------------------------
 

=== modified file 'doc/en/user-guide/shared_repository_layouts.txt'
--- doc/en/user-guide/shared_repository_layouts.txt	2009-02-26 11:28:50 +0000
+++ doc/en/user-guide/shared_repository_layouts.txt	2009-12-02 20:34:07 +0000
@@ -1,7 +1,7 @@
 Advanced shared repository layouts
 ==================================
 
-Bazaar is designed to give you flexibility in how you layout branches inside a shared repository. 
+Bazaar is designed to give you flexibility in how you layout branches inside a shared repository.
 This flexibility allows users to tailor Bazaar to their workflow,
 but it also leads to questions about what is a "good" layout.
 We present some alternatives and give some discussion about the benefits of each.
@@ -15,7 +15,7 @@
 "SVN-Style" (``trunk/``, ``branches/``)
 ---------------------------------------
 
-Most people coming from SVN will be familiar with their "standard" project layout. 
+Most people coming from SVN will be familiar with their "standard" project layout.
 Which is to layout the repository as::
 
   repository/       # Overall repository
@@ -27,11 +27,11 @@
        +- release-X # A branch specific to mark a given release version
           ...
 
-With Bazaar, that is a perfectly reasonable layout. 
-It has the benefit of being familiar to people coming from SVN, 
+With Bazaar, that is a perfectly reasonable layout.
+It has the benefit of being familiar to people coming from SVN,
 and making it clear where the development focus is.
 
-When you have multiple projects in the same repository, 
+When you have multiple projects in the same repository,
 the SVN layout is a little unclear what to do.
 
 
@@ -52,8 +52,8 @@
        +- branches/      # Container for project2 branches
 
 
-This also works with Bazaar. 
-However, with Bazaar repositories are cheap to create 
+This also works with Bazaar.
+However, with Bazaar repositories are cheap to create
 (a simple ``bzr init-repo`` away), and their primary benefit is when the
 branches share a common ancestry.
 
@@ -64,7 +64,7 @@
      +- branches/      # A container directory
          +- foo/       # Branch for developing feature foo of project1
            ...
-    
+
     project2/          # A repository for project2
      +- trunk/         # Mainline for project2
      +- branches/      # Container for project2 branches
@@ -100,17 +100,17 @@
         +- project1-foo/  # Branch 'foo' of project1
         +- project2-bar/  # Branch 'bar' of project2
 
-I believe the reason for this in SVN, is so that someone 
+I believe the reason for this in SVN, is so that someone
 can checkout all of "``trunk/``" and get the all the mainlines for all projects.
 
 This layout can be used for Bazaar, but it is not generally recommended.
 
- 1) ``bzr branch/checkout/get`` is a single branch at a time. 
+ 1) ``bzr branch/checkout/get`` is a single branch at a time.
     So you don't get the benefit of getting all mainlines with a single command. [1]_
 
- 2) It is less obvious of whether ``repository/trunk/foo`` is the ``trunk`` of project 
+ 2) It is less obvious of whether ``repository/trunk/foo`` is the ``trunk`` of project
     ``foo`` or it is just the ``foo`` directory in the ``trunk`` branch.
-    Some of this confusion is due to SVN, because it uses the same "namespace" 
+    Some of this confusion is due to SVN, because it uses the same "namespace"
     for files in a project that it uses for branches of a project.
     In Bazaar, there is a clear distinction of what files make up a project, versus
     the location of the Branch. (After all, there is only one ``.bzr/`` directory per branch,
@@ -148,7 +148,7 @@
       +- 1.0/
           +- 1.1.1/
 
-The idea with this layout is that you are creating a hierarchical layout for branches. 
+The idea with this layout is that you are creating a hierarchical layout for branches.
 Where changes generally flow upwards in the namespace. It also gives people a little
 corner of the namespace to work on their stuff.
 One nice feature of this layout, is it makes branching "cheaper" because it gives you
@@ -162,7 +162,7 @@
   bzr branch http://host/repository/project/branches/joe-feature-foo-bugfix-10/
 
 Versus::
-  
+
   bzr branch http://host/project/joe/foo/bugfix-10
 
 
@@ -175,7 +175,7 @@
   joe-bugfix-13/
   joe-frizban/
 
-Versus having these broken out by developer. 
+Versus having these broken out by developer.
 If the number of branches are small, ``branches/`` has the nice advantage
 of being able to see all branches in a single view.
 If the number of branches is large, ``branches/`` has the distinct disadvantage
@@ -183,7 +183,7 @@
 branch you are interested in, when there are 100 branches to look through).
 
 Nested branching seems to scale better to larger number of branches.
-However, each individual branch is less discoverable. 
+However, each individual branch is less discoverable.
 (eg. "Is Joe working on bugfix 10 in his feature foo branch, or his feature bar branch?")
 
 One other small advantage is that you can do something like::
@@ -192,7 +192,7 @@
   or
    bzr branch http://host/project/release/1/1/2
 
-To indicate release 1.1.1 and 1.1.2. This again depends on how many releases you have 
+To indicate release 1.1.1 and 1.1.2. This again depends on how many releases you have
 and whether the gain of splitting things up outweighs the ability to see more at a glance.
 
 
@@ -217,7 +217,7 @@
 It lets you see what branches are actively being developed on, which is usually
 only a small number, versus the total number of branches ever created.
 Old branches are not lost (versus deleting them), but they are "filed away",
-such that the more likely you are to want a branch the easier it is to find. 
+such that the more likely you are to want a branch the easier it is to find.
 (Conversely, older branches are likely to be harder to find).
 
 The biggest disadvantage with this layout, is that branches move around.
@@ -237,7 +237,7 @@
 that could be changed.
 This is actually how `Launchpad`_ allows you to ``bzr checkout https://launchpad.net/bzr``.
 Effectively a ``BranchReference`` is a symlink, but it allows you to reference any other URL.
-If it is extended to support relative references, it would even work over http, sftp, 
+If it is extended to support relative references, it would even work over http, sftp,
 and local paths.
 
 .. _Launchpad: https://launchpad.net
@@ -247,7 +247,7 @@
 --------------------------------------------------------------------------
 
 Another method of allowing some scalability while also allowing the
-browsing of "current" branches. Basically, this works on the assumption 
+browsing of "current" branches. Basically, this works on the assumption
 that actively developed branches will be "new" branches, and older branches
 are either merged or abandoned.
 
@@ -292,8 +292,8 @@
 The general idea is that by targeting a release, you can look at what branches are
 waiting to be merged. It doesn't necessarily give you a good idea of what the
 state of the branch (is it in development or finished awaiting review).
-It also has a history-hiding effect, and otherwise has the same benefits 
-and deficits as a date-based sorting. 
+It also has a history-hiding effect, and otherwise has the same benefits
+and deficits as a date-based sorting.
 
 
 Simple developer naming (``project/joe/foo``, ``project/barry/bar``)

=== modified file 'doc/en/user-guide/shelving_changes.txt'
--- doc/en/user-guide/shelving_changes.txt	2009-03-12 06:04:54 +0000
+++ doc/en/user-guide/shelving_changes.txt	2009-12-02 20:34:07 +0000
@@ -15,7 +15,7 @@
   +++ description.txt
   @@ -2,7 +2,7 @@
    ===============
-   
+
    These plugins
   -by Michael Ellerman
   +written by Michael Ellerman
@@ -23,7 +23,7 @@
    fine-grained 'undo'
    facility
   @@ -11,6 +11,6 @@
-   This allows you to 
+   This allows you to
    undo some of
    your changes,
   -commit, and get
@@ -39,7 +39,7 @@
   +++ description.txt
   @@ -2,7 +2,7 @@
    ===============
-   
+
    These plugins
   -by Michael Ellerman
   +written by Michael Ellerman
@@ -51,7 +51,7 @@
   --- description.txt
   +++ description.txt
   @@ -11,6 +11,6 @@
-   This allows you to 
+   This allows you to
    undo some of
    your changes,
   -commit, and get
@@ -63,7 +63,7 @@
   Shelve 2 change(s)? [yNfrq?]', 'y'
   Selected changes:
    M  description.txt
-  Changes shelved with id "1".  
+  Changes shelved with id "1".
 
 If there are lots of changes in the working tree, you
 can provide the ``shelve`` command with a list of files
@@ -77,7 +77,7 @@
   +++ description.txt
   @@ -2,7 +2,7 @@
    ===============
-   
+
    These plugins
   -by Michael Ellerman
   +written by Michael Ellerman

=== modified file 'doc/en/user-guide/specifying_revisions.txt'
--- doc/en/user-guide/specifying_revisions.txt	2009-11-30 18:52:36 +0000
+++ doc/en/user-guide/specifying_revisions.txt	2009-12-02 23:09:40 +0000
@@ -134,7 +134,7 @@
 ~~~~~~~~
 
 **ancestor**:*path*
-    specifies the common ancestor between the current branch and a 
+    specifies the common ancestor between the current branch and a
     different branch. This is the same ancestor that would be used for
     merging purposes.
 

=== modified file 'doc/en/user-guide/stacked.txt'
--- doc/en/user-guide/stacked.txt	2009-07-20 08:47:58 +0000
+++ doc/en/user-guide/stacked.txt	2009-12-02 20:34:07 +0000
@@ -18,7 +18,7 @@
   than leaving them in a shared repository).
 
 * Security is improved over shared repositories, because the stacked-on
-  repository can be physically readonly to developers committing to stacked 
+  repository can be physically readonly to developers committing to stacked
   branches.
 
 These benefits make stacked branches ideal for various scenarios

=== modified file 'doc/en/user-guide/version_info.txt'
--- doc/en/user-guide/version_info.txt	2008-03-13 18:51:13 +0000
+++ doc/en/user-guide/version_info.txt	2009-12-02 20:34:07 +0000
@@ -104,5 +104,5 @@
 set the ``clean`` flag in ``version_info``, as well as set entries in
 ``file_revisions`` as ``modified`` where appropriate.
 
-.. 
+..
    vim: tw=74 ft=rst spell spelllang=en_us

=== modified file 'doc/en/user-guide/web_browsing.txt'
--- doc/en/user-guide/web_browsing.txt	2009-03-21 02:00:59 +0000
+++ doc/en/user-guide/web_browsing.txt	2009-12-02 20:34:07 +0000
@@ -5,10 +5,10 @@
 --------
 
 There are a range of options available for providing a web view of a
-Bazaar repository, the main one being Loggerhead. The homepage of Loggerhead 
+Bazaar repository, the main one being Loggerhead. The homepage of Loggerhead
 can be found at https://launchpad.net/loggerhead.
 
-A list of alternative web viewers including download links can be found on 
+A list of alternative web viewers including download links can be found on
 http://bazaar-vcs.org/WebInterface.
 
 Note: If your project is hosted or mirrored on Launchpad,

=== modified file 'doc/en/user-guide/zen.txt'
--- doc/en/user-guide/zen.txt	2008-06-06 11:55:58 +0000
+++ doc/en/user-guide/zen.txt	2009-12-02 20:34:07 +0000
@@ -56,7 +56,7 @@
   102: Add code and tests for X
   101: Add tests for Y
   100: ...
-  
+
 Many teams use this approach because their tools make branching and merging
 difficult. As a consequence, developers update from and commit to the trunk
 frequently, minimizing integration pain by spreading it over every commit.

=== modified file 'doc/es/index.txt'
--- doc/es/index.txt	2009-09-09 02:30:32 +0000
+++ doc/es/index.txt	2009-12-02 20:34:07 +0000
@@ -24,7 +24,7 @@
 * `Guias de Migracion <http://doc.bazaar-vcs.org/migration/en/>`_
   - para equipos que mudan el historial de otros SCV
 
-* `Guias de Plugins <http://doc.bazaar-vcs.org/plugins/en/>`_ 
+* `Guias de Plugins <http://doc.bazaar-vcs.org/plugins/en/>`_
 
 Otros Documentos (enlances web):
 

=== modified file 'doc/es/mini-tutorial/index.txt'
--- doc/es/mini-tutorial/index.txt	2009-09-08 01:19:48 +0000
+++ doc/es/mini-tutorial/index.txt	2009-12-02 20:34:07 +0000
@@ -8,9 +8,9 @@
 Bazaar es un sistema de control de versiones distribuido que facilita que
 varias personas puedan trabajar de forma conjunta en proyectos de software.
 
-A lo largo de los próximos cinco minutos, aprenderá cómo poner sus archivos 
-bajo control de versiones, como registrar cambios en ellos, examinar su 
-trabajo, publicarlo y enviar su trabajo para que sea integrado en el trunk de 
+A lo largo de los próximos cinco minutos, aprenderá cómo poner sus archivos
+bajo control de versiones, como registrar cambios en ellos, examinar su
+trabajo, publicarlo y enviar su trabajo para que sea integrado en el trunk de
 un proyecto.
 
 Si prefiere una introducción más detallada, eche un vistazo a
@@ -39,14 +39,14 @@
 Preséntese
 ==========
 
-Antes de empezar a trabajar, es conveniente que le diga a Bazaar quién es 
-usted. De ese modo su trabajo será identificando correctamente en los logs 
+Antes de empezar a trabajar, es conveniente que le diga a Bazaar quién es
+usted. De ese modo su trabajo será identificando correctamente en los logs
 de revisión.
 
 Utilice su nombre y dirección de email en lugar de John Doe, teclee::
 
   $ bzr whoami "John Doe <john.doe@gmail.com>"
-  
+
 Bazaar creará o modificará ahora un archivo de configuración, incluyendo su
 nombre y dirección de email.
 
@@ -65,7 +65,7 @@
  $ cd miproyecto
  $ mkdir subdirectorio
  $ touch test1.txt test2.txt test3.txt subdirectorio/test4.txt
- 
+
 **Nota para usuarios de Windows:** utilice Windows Explorer para crear sus
 directorios, luego haga click derecho en dichos directorios y seleccione
 ``Nuevo archivo`` para crear sus archivos.
@@ -73,14 +73,14 @@
 Ahora vamos a hacer que Bazaar se inicialize en el directorio de su proyecto::
 
   $ bzr init
-  
+
 Si parece que no ha ocurrido nada no se preocupe. Bazaar ha creado un
 branch_ dónde guardará sus archivos y su histórico de revisiones.
 
 .. _branch: http://bazaar-vcs.org/Branch
 
 El siguiente paso es decirle a Bazaar a que archivos desea seguirles la pista.
-Ejecutando ``bzr add`` agregará recursivamente todos los elementos dentro del 
+Ejecutando ``bzr add`` agregará recursivamente todos los elementos dentro del
 proyecto::
 
  $ bzr add
@@ -90,11 +90,11 @@
  added test3.txt
  added subdirectorio/test4.txt
 
-A continuación tome una instantánea de sus archivos agregándolos a su branch. 
+A continuación tome una instantánea de sus archivos agregándolos a su branch.
 Agregue un mensaje para explicar por qué hace el commit::
 
   $ bzr commit -m "Importación inicial"
-  
+
 Como Bazaar es un sistema de control de versiones distribuido, no necesita
 conectar con un servidor central para hacer el commit. Bazaar guarda su
 branch y todos sus commits dentro del directorio con el que está trabajando,
@@ -158,14 +158,14 @@
 
  $ bzr push --create-prefix sftp://su.nombre@example.com/~/public_html/miproyecto
  2 revision(s) pushed.
- 
+
 Bazaar creará un directorio ``miproyecto`` en el servidor remoto e
 introducirá su branch en él.
- 
+
 Ahora cualquiera podrá crear su propia copia de su branch tecleando::
 
  $ bzr branch http://www.example.com/miproyecto
- 
+
 **Nota:** para utilizar sftp deberá instalar ``paramiko`` y
 ``pyCrypto``. Vea http://bazaar-vcs.org/InstallationFaq para más información.
 
@@ -186,13 +186,13 @@
 
  $ bzr push bzr+ssh://john.doe@bazaar.launchpad.net/~john.doe/+junk/miproyecto
 
-**Nota:** ``+junk`` significa que este branch no está asociado con ningún proyecto 
+**Nota:** ``+junk`` significa que este branch no está asociado con ningún proyecto
 concreto en Launchpad.
 
 Ahora cualquiera podrá crear su propia copia de su branch tecleando::
 
  $ bzr branch http://bazaar.launchpad.net/~john.doe/+junk/miproyecto
- 
+
 También puede ver información sobre su branch, histórico de revisiones
 incluido, en https://code.launchpad.net/people/+me/+junk/miproyecto
 
@@ -204,7 +204,7 @@
 copia de su branch. Vamos a coger un ejemplo real, la interfaz GTK de Bazaar::
 
   $ bzr branch http://bazaar.launchpad.net/~bzr/bzr-gtk/trunk bzr-gtk.john
-  Branched 292 revision(s).                                                        
+  Branched 292 revision(s).
 
 Bazaar descargará todos los archivos y el histórico de revisiones completo
 del trunk branch del proyecto bzr-gtk y creará una copia llamada
@@ -228,11 +228,11 @@
   $ bzr merge
   Merging from saved parent location: http://bazaar.launchpad.net/~bzr/bzr-gtk/trunk
   All changes applied successfully.
-            
+
 Compruebe qué ha cambiado::
 
   $ bzr diff
- 
+
 Si está contento con los cambios puede añadirlos en su branch personal::
 
   $ bzr commit -m "Integración desde el branch principal"
@@ -255,12 +255,12 @@
 
  $ bzr send -o mycode.patch
  Using saved parent location: http://bazaar.launchpad.net/~bzr/bzr-gtk/trunk
- 
+
 Ahora puede enviar por email la instruccion merge al proyecto bzr-gtk
 quien, si así lo quieren, pueden utilizarla para integrar su trabajo
 dentro del branch principal.
- 
- 
+
+
 Aprendiendo más
 ===============
 

=== modified file 'doc/es/user-guide/index-plain.txt'
--- doc/es/user-guide/index-plain.txt	2009-09-09 12:57:43 +0000
+++ doc/es/user-guide/index-plain.txt	2009-12-02 20:34:07 +0000
@@ -100,7 +100,7 @@
 .. include later - server.txt
 .. include later - hooks.txt
 .. include:: version_info.txt
- 
+
 
 Apéndice
 ########

=== modified file 'doc/es/user-guide/index.txt'
--- doc/es/user-guide/index.txt	2009-09-08 01:19:48 +0000
+++ doc/es/user-guide/index.txt	2009-12-02 20:34:07 +0000
@@ -100,7 +100,7 @@
 .. include later - server.txt
 .. include later - hooks.txt
 .. include:: version_info.txt
- 
+
 
 Apéndice
 ########

=== modified file 'doc/es/user-guide/resolving_conflicts.txt'
--- doc/es/user-guide/resolving_conflicts.txt	2008-05-12 00:59:13 +0000
+++ doc/es/user-guide/resolving_conflicts.txt	2009-12-02 20:34:07 +0000
@@ -5,7 +5,7 @@
 Algunas operaciones, como merge, revert y pull, modifican el contenido de su
 working tree. Estas modificaciones son generadas automaticamente, con lo cual
 pueden tener conflictos con el estado actual de su working tree.  Muchos tipos
-de cambios pueden ser combinados automaticamentem pero a veces solo algunos 
+de cambios pueden ser combinados automaticamentem pero a veces solo algunos
 humanos pueden determinar la decision correcta a tomar.  Cuando esto sucede,
 Bazaar lo informara que hay un conflict y pedira que lo resuelva. El comando
 para resolverlo es ``resolve``, pero debe realizar alguna accion antes de
@@ -25,7 +25,7 @@
 reconciliado entre dos cambios. Bazaar emitira archivos para cada version con
 extensiones THIS, OTHER, y BASE.  THIS es la version del archivo del tree
 de destino, por ejemplo, el tree al que estan unificando los cambios. OTHER
-es la version que estan uniendo al tree de destino. BASE es la version 
+es la version que estan uniendo al tree de destino. BASE es la version
 anterior que es usado como base para la comparacion.
 
 En la copia principal del archivo, Bazaar incluira los cambios que puede
@@ -33,7 +33,7 @@
 "herringbone" como ``<<<<<<<``.
 
 Digamos que el texto inicial es "El lider del proyecto lo lanzo.", y THIS lo
-modifica a "Martin Pool lo lanzo.", mientras que OTHER lo modifica a "El lider 
+modifica a "Martin Pool lo lanzo.", mientras que OTHER lo modifica a "El lider
 del proyecto lanzo Bazaar."  Un conflicto se veria asi::
 
   <<<<<<< TREE
@@ -45,16 +45,16 @@
 La resulucion correcta seria "Martin Pool lanzo Bazaar."
 
 Puede manejar conflictos de texto o editando la copia principal del archivo,
-o invocando herramientas externas on las versiones THIS, OTHER y BASE. Vale 
+o invocando herramientas externas on las versiones THIS, OTHER y BASE. Vale
 la pena mencionar que resolver conflictos de texto rara vez involucra elegir
-un conjunto de cambios u otros. Los mas comun es que tenga que combinar 
+un conjunto de cambios u otros. Los mas comun es que tenga que combinar
 inteligentemente.
 
 Si modifica la copia principal, asegurese de sacar los marcadores "herringbone".
-Cuando termino de modificar, el archivo debe estar como si nunca hubiese estado 
+Cuando termino de modificar, el archivo debe estar como si nunca hubiese estado
 con conflictos, y estar listo para hacer commit.
 
-Cuando resolvio los conflictos de texto, solo ejecute "bzr resolve", y Bazaar 
+Cuando resolvio los conflictos de texto, solo ejecute "bzr resolve", y Bazaar
 detectera automaticamente que resolvio.
 
 
@@ -64,19 +64,19 @@
 
   Contents conflict in ARCHIVO
 
-Este conflicto sucede cuando hay cambios que crean conflictos en el tree de 
-destino y el fuente a unificar, pero los items con conflictos no son archivos 
-de texto.  Pueden ser archivos binarios, symlinks o directorios.  Pueden suceder 
+Este conflicto sucede cuando hay cambios que crean conflictos en el tree de
+destino y el fuente a unificar, pero los items con conflictos no son archivos
+de texto.  Pueden ser archivos binarios, symlinks o directorios.  Pueden suceder
 con archivos que fueron eliminados en un lado, y modificados en el otro.
 
 Como los conflictos de texto, Bazaar creara archivos THIS, OTHER y BASE.
-(pueden ser archivos normales, symlinks o directorios).  Esto no incluira 
-la "copia principal" del archivo con marcadores "herringbone".  Parecera que la 
+(pueden ser archivos normales, symlinks o directorios).  Esto no incluira
+la "copia principal" del archivo con marcadores "herringbone".  Parecera que la
 "copia principal" fue renombrado a THIS o OTHER.
 
-Para resolver esto, utilice "bzr mv" para renombrar el archivo a su nombre 
-original, y combine los cambios manualmente. Cuando este satisfecho, ejecute 
-"bzr resolve ARCHIVO".  Bazaar no puede detectar cuando cambios de este tipo 
+Para resolver esto, utilice "bzr mv" para renombrar el archivo a su nombre
+original, y combine los cambios manualmente. Cuando este satisfecho, ejecute
+"bzr resolve ARCHIVO".  Bazaar no puede detectar cuando cambios de este tipo
 fueron resueltos.
 
 
@@ -87,9 +87,9 @@
   Conflict adding file ARCHIVO.  Moved existing file to ARCHIVO.moved.
 
 Bazaar a veces intentara crear un archivo usando la ruta que ya fue usada.
-El archivo existente ser renombrado a "ARCHIVO.moved".  Si lo desea, puede 
-renombrar cualquiera de estos archivos, o combinar su contenido. Cuando 
-este satisfecho, puede ejecutar "bzr resolve ARCHIVO" para marcar que el 
+El archivo existente ser renombrado a "ARCHIVO.moved".  Si lo desea, puede
+renombrar cualquiera de estos archivos, o combinar su contenido. Cuando
+este satisfecho, puede ejecutar "bzr resolve ARCHIVO" para marcar que el
 conflicto fue resuelto.
 
 
@@ -99,12 +99,12 @@
 
     Conflict because ARCHIVO no esta versionado, pero tiene hijos versionados.
 
-A veces Bazaar intentara crear un archivo cuyo directorio padre no esta 
-versionado. Esto sucede cuando el directorio fue eliminado en el destino, 
-pero tiene un hijo nuevo en origen, o vice versa. En esta situacion, Bazaar 
-versionara al directorio padre tambien.  Resolver este tema depende mucho 
-en el escenario particular.  Puede que quiera renombrar o eliminar o renombrar 
-cualquier archivo o directorio.  Cuando esta satisfecho, puede ejecutar "bzr 
+A veces Bazaar intentara crear un archivo cuyo directorio padre no esta
+versionado. Esto sucede cuando el directorio fue eliminado en el destino,
+pero tiene un hijo nuevo en origen, o vice versa. En esta situacion, Bazaar
+versionara al directorio padre tambien.  Resolver este tema depende mucho
+en el escenario particular.  Puede que quiera renombrar o eliminar o renombrar
+cualquier archivo o directorio.  Cuando esta satisfecho, puede ejecutar "bzr
 resolve ARCHIVO" para marcar el conflicto como resuelto.
 
 
@@ -114,12 +114,12 @@
 
   Conflict adding files to ARCHIVO.  Created directory.
 
-Esto sucede cuando un archivo fue eliminado en el destino, pero tiene hijos 
-en el origen.  Esto es similar al conflicto "Padre sin versionar", excepto 
-que el directorio padre *no existe*, en vez de no estar versionado. En esta 
-situacion, Bazaar creara al padre faltante.  Resolver estos temas depende 
-mucho de cada caso particular. Usted puede querer renombrar o eliminar 
-cualquiera de los archivos o directorios.  Cuando este satisfecho, puede 
+Esto sucede cuando un archivo fue eliminado en el destino, pero tiene hijos
+en el origen.  Esto es similar al conflicto "Padre sin versionar", excepto
+que el directorio padre *no existe*, en vez de no estar versionado. En esta
+situacion, Bazaar creara al padre faltante.  Resolver estos temas depende
+mucho de cada caso particular. Usted puede querer renombrar o eliminar
+cualquiera de los archivos o directorios.  Cuando este satisfecho, puede
 ejecutar "bzr resolve ARCHIVO" para marcar al archivo resuelto.
 
 
@@ -129,11 +129,11 @@
 
   Conflict: can't delete ARCHIVO because it is not empty.  Not deleting.
 
-Esto es el opuesto a "Padre faltante".  Un directorio es eliminado en el 
+Esto es el opuesto a "Padre faltante".  Un directorio es eliminado en el
 origen, pero tiene hijos en el destino.  Bazaar mantiene el directorio.
-Resolver este tema depende mucho de cada escenario particular.  Quizas quiera 
-renombrar o eliminar cualquiera de los archivos o directorios.  Cuando esta 
-satisfecho, puede ejecutar "bzr resolver ARCHIVO" para marcar al conflicto 
+Resolver este tema depende mucho de cada escenario particular.  Quizas quiera
+renombrar o eliminar cualquiera de los archivos o directorios.  Cuando esta
+satisfecho, puede ejecutar "bzr resolver ARCHIVO" para marcar al conflicto
 como resuelto.
 
 
@@ -143,9 +143,9 @@
 
   Path conflict: RUTA1 / RUTA2
 
-Esto sucede cuando en el origen y el destino han sido modificados el nombre 
-o directorio padre de un archivo. Bazaar usara la ruta de los elementos del 
-origen. Puede renombrar el archivo, y una vez que lo ha hecho, ejecutar 
+Esto sucede cuando en el origen y el destino han sido modificados el nombre
+o directorio padre de un archivo. Bazaar usara la ruta de los elementos del
+origen. Puede renombrar el archivo, y una vez que lo ha hecho, ejecutar
 "bzr resolve ARCHIVO" para marcarl el conflicto como resuelto.
 
 
@@ -155,8 +155,8 @@
 
   Conflict moving ARCHIVO into DIRECTORIO.  Cancelled move.
 
-Esto sucede cuando en el origen y el destino se han movido directorios, de 
-tal forma que, si se aplicaran los cambios, el directorios se contendria a 
+Esto sucede cuando en el origen y el destino se han movido directorios, de
+tal forma que, si se aplicaran los cambios, el directorios se contendria a
 si mismo.
 Por ejemplo::
 
@@ -172,14 +172,14 @@
   $ bzr merge ../other
 
 En esta situacion, Bazaar cancelara el movimiento, y dejara "a" en "b".
-Puede renombrar los directorios como desee, y una vez que lo ha hecho, 
+Puede renombrar los directorios como desee, y una vez que lo ha hecho,
 ejecute "bzr resolve ARCHIVO" para marcar el conflicto como resuelto.
 
 
 MalformedTransform
 ==================
 Es posible (aunque muy raro) que Bazaar de una excepcion MalformedTransform.
-Esto quiere decir que Bazaar encontro un conflicto en el sistema de archivos 
-que no le fue posible resolver.  Esto usualmente indica un bug.  Por favor 
-haganoslo saber si se encuentra en esta situacion. Nuestro sistema de bugs 
+Esto quiere decir que Bazaar encontro un conflicto en el sistema de archivos
+que no le fue posible resolver.  Esto usualmente indica un bug.  Por favor
+haganoslo saber si se encuentra en esta situacion. Nuestro sistema de bugs
 se encuentra en https://launchpad.net/bzr/+bugs

=== modified file 'doc/es/user-guide/version_info.txt'
--- doc/es/user-guide/version_info.txt	2008-05-04 18:17:45 +0000
+++ doc/es/user-guide/version_info.txt	2009-12-02 20:34:07 +0000
@@ -5,7 +5,7 @@
 Repaso General
 ==============
 
-Este documento describe las formas de usar ``bzr version-info`` como 
+Este documento describe las formas de usar ``bzr version-info`` como
 parte del proceso de embeber la informacion de vesion a un proyecto.
 
 
@@ -14,7 +14,7 @@
 
 TODO: Figure out how to attach into ``setup.py``
 
-Si usa un archivo Makefile para construir su proyecto, puede generar un 
+Si usa un archivo Makefile para construir su proyecto, puede generar un
 archivo on la informacion de version tan simple como::
 
   library/_version.py:
@@ -25,29 +25,29 @@
   * `version_info`: Un diccionario conteniendo informacion basica sobre el
     estado actual
 
-  * `revisions`: Un diccionario listando todas las revisiones en 
-    el historial del tree, junto con los tiempos y los mensajes de 
-    los commits. Esto por defecto esta en blanco salvi que use ``--all`` 
-    o `--include-history`` es provisto. Esto es util si quiere seguir 
-    que bugs arregla el lanzamiento de esa version. Para muchos proyectos 
+  * `revisions`: Un diccionario listando todas las revisiones en
+    el historial del tree, junto con los tiempos y los mensajes de
+    los commits. Esto por defecto esta en blanco salvi que use ``--all``
+    o `--include-history`` es provisto. Esto es util si quiere seguir
+    que bugs arregla el lanzamiento de esa version. Para muchos proyectos
     es mas informacion de la que se va a necesitar.
 
   * `file_revisions`: Un diccionario listando la revision que modifico
-    por ultima vez todos los archivos del proyecto. Esto puede ser usado 
-    similarmente a como se usan las palabras claves ``$Id$`` en los 
-    archivos controlados en CVS. La ultima fecha de modificacion puede 
-    ser determinada mirando en el mapa de ``revisions``. Esto tambien 
+    por ultima vez todos los archivos del proyecto. Esto puede ser usado
+    similarmente a como se usan las palabras claves ``$Id$`` en los
+    archivos controlados en CVS. La ultima fecha de modificacion puede
+    ser determinada mirando en el mapa de ``revisions``. Esto tambien
     esta vacio por defecto, y habilitado solo por ``--all`` o
     ``--include-file-revisions``.
-    
+
 
 Check Clean
 ===========
 
-La mayoria de la informacion sobre el contenido del proyecto puede 
+La mayoria de la informacion sobre el contenido del proyecto puede
 ser determinada a muy bajo costo con solo leer las entradas de revisiones.
-Sin embargo, puede ser util si el working tree fue actualizado completamente 
-cuando fue empaquetado, o si hubo alguna modificacion local. Al proveer 
-``--all`` o ``--check-clean``, ``bzr`` va a inspeccionar el working tree, 
-y definir el ``clean`` flag en ``version_info``, al igual que definir 
+Sin embargo, puede ser util si el working tree fue actualizado completamente
+cuando fue empaquetado, o si hubo alguna modificacion local. Al proveer
+``--all`` o ``--check-clean``, ``bzr`` va a inspeccionar el working tree,
+y definir el ``clean`` flag en ``version_info``, al igual que definir
 entradas en ``file_revisions`` como ``modified`` donde es apropiado.

=== modified file 'doc/index.es.txt'
--- doc/index.es.txt	2009-09-09 12:57:43 +0000
+++ doc/index.es.txt	2009-12-02 20:34:07 +0000
@@ -8,13 +8,13 @@
 Documentacion Principal
 =======================
 
-* `Mini Tutorial <es/mini-tutorial/index.html>`_ 
+* `Mini Tutorial <es/mini-tutorial/index.html>`_
 
 * `Referencia Rapida <es/_static/es/bzr-es-quick-reference.svg>`_
 
-* `Guia de Usuario <es/user-guide/index-plain.html>`_ 
+* `Guia de Usuario <es/user-guide/index-plain.html>`_
 
-* `Referencia <en/user-reference/bzr_man.html>`_ 
+* `Referencia <en/user-reference/bzr_man.html>`_
 
 * `Notas sobre la Version <en/release-notes/NEWS.html>`_
 
@@ -26,7 +26,7 @@
 
 Mudandose a Bazaar (enlances web):
 
-* `Guias de Mudanzas <http://bazaar-vcs.org/BzrSwitching>`_ 
+* `Guias de Mudanzas <http://bazaar-vcs.org/BzrSwitching>`_
   - para los usuarios que se mudan de otros SCV
 
 * `Guias de Migracion <http://bazaar-vcs.org/BzrMigration>`_

=== modified file 'doc/index.ru.txt'
--- doc/index.ru.txt	2009-09-09 12:57:43 +0000
+++ doc/index.ru.txt	2009-12-02 20:34:07 +0000
@@ -2,8 +2,8 @@
 Главный каталог документов Bazaar
 =================================
 
-Последняя версия этих документов доступа со страницы документации 
-на сайте Bazaar, <http://doc.bazaar-vcs.org/>. Еще больше информации 
+Последняя версия этих документов доступа со страницы документации
+на сайте Bazaar, <http://doc.bazaar-vcs.org/>. Еще больше информации
 можно получить по адресу <http://bazaar-vcs.org/Documentation>.
 
 Основная документация
@@ -19,7 +19,7 @@
 
 * `Список изменений <en/release-notes/NEWS.html>`_ (англ.)
 
-* `Каталог информации для разработчиков <developers/index-plain.html>`_ (англ.) |--| 
+* `Каталог информации для разработчиков <developers/index-plain.html>`_ (англ.) |--|
   для разработчиков Bazaar и плагинов
 
 Учебники
@@ -29,7 +29,7 @@
 
 * `Большой учебник <ru/tutorials/tutorial.html>`_
 
-* `Использование Bazaar с Launchpad 
+* `Использование Bazaar с Launchpad
   <ru/tutorials/using_bazaar_with_launchpad.html>`_
 
 * `Работа в централизованном стиле
@@ -44,9 +44,9 @@
 * `Руководство по миграции <http://bazaar-vcs.org/BzrMigration>`_
   |--| для команд переносящих историю с других систем контроля версий
 
-* `Словарь терминов <http://bazaar-vcs.org/BzrGlossary>`_ (англ.), 
-  см. также `русскую версию`__ 
-  
+* `Словарь терминов <http://bazaar-vcs.org/BzrGlossary>`_ (англ.),
+  см. также `русскую версию`__
+
 __  http://groups.google.com/group/ru_bzr/web/%D0%B3%D0%BB%D0%BE%D1%81%D1%81%D0%B0%D1%80%D0%B8%D0%B9
 
 * `Часто задаваемые вопросы <http://bazaar-vcs.org/FAQ>`_ (англ.)

=== modified file 'doc/ja/tutorials/using_bazaar_with_launchpad.txt'
--- doc/ja/tutorials/using_bazaar_with_launchpad.txt	2009-10-29 10:01:19 +0000
+++ doc/ja/tutorials/using_bazaar_with_launchpad.txt	2009-12-02 20:34:07 +0000
@@ -521,7 +521,7 @@
 Summary
 =======
 
-The communities we join, whether off-line or on-line, 
+The communities we join, whether off-line or on-line,
 say a lot about the sort of people we are. The flip-side
 to this is that the tools you choose for your community - particularly
 the CDE and version control tool - can have a large impact on who

=== modified file 'doc/ja/upgrade-guide/data_migration.txt'
--- doc/ja/upgrade-guide/data_migration.txt	2009-10-29 10:01:19 +0000
+++ doc/ja/upgrade-guide/data_migration.txt	2009-12-02 20:34:07 +0000
@@ -121,7 +121,7 @@
 
 4. 各ローカルブランチの移行に関して2つ選択肢があります。
 
- * 新しいリポジトリで1つ空のブランチを **init** して古いリポジトリからリビジョンを **pull** する。 
+ * 新しいリポジトリで1つ空のブランチを **init** して古いリポジトリからリビジョンを **pull** する。
 
  * 新リポジトリにおいて、 trunkから新しいブランチに **branch** した後古いリポジトリにおいてあなたが行った変更を **merge** する。
 

=== modified file 'doc/ja/user-guide/entering_commands.txt'
--- doc/ja/user-guide/entering_commands.txt	2009-10-29 10:01:19 +0000
+++ doc/ja/user-guide/entering_commands.txt	2009-12-02 20:34:07 +0000
@@ -32,5 +32,5 @@
 
 Quietモードはエラーと警告のみを表示します。これはスクリプトで使う際に便利です。
 
-注: 大抵のコマンドは1つのレベルの冗長性だけをサポートします。今後これは変更されるかもしれません。 
+注: 大抵のコマンドは1つのレベルの冗長性だけをサポートします。今後これは変更されるかもしれません。
 高度な冗長性を求めるためには、-vオプションを複数回指定するだけです。

=== modified file 'doc/ja/user-guide/http_smart_server.txt'
--- doc/ja/user-guide/http_smart_server.txt	2009-10-29 10:01:19 +0000
+++ doc/ja/user-guide/http_smart_server.txt	2009-12-02 20:34:07 +0000
@@ -26,7 +26,7 @@
 
     LoadModule fastcgi_module /usr/lib/apache2/modules/mod_fastcgi.so
     FastCgiIpcDir /var/lib/apache2/fastcgi
-    
+
 我々の例では、`http://example.com/code` で `/srv/example.com/www/code` をすでに提供しているので
 既存のApacheの設定は次のようになります::
 
@@ -46,7 +46,7 @@
         RewriteBase /code
         RewriteRule ^(.*/|)\.bzr/smart$ /srv/example.com/scripts/bzr-smart.fcgi
     </Directory>
-    
+
     # bzr-smart.fcgiはDocumentRootの元に存在しないので、実行されるように
     # AliasはこれをURLの名前空間のエイリアスにする。
     Alias /srv/example.com/scripts/bzr-smart.fcgi /srv/example.com/scripts/bzr-smart.fcgi
@@ -56,7 +56,7 @@
             SetHandler fastcgi-script
         </Files>
     </Directory>
-    
+
 この設定はFastCGIを通して `/code` 内部の `/.bzr/smart` で終わるURLに対する
 Bazaarのスマートサーバーへのリクエストを扱うようにApacheに指示します。
 
@@ -126,11 +126,11 @@
         prefix='/code/',
         path_var='REQUEST_URI',
         readonly=True,
-        load_plugins=True, 
+        load_plugins=True,
         enable_logging=True)
 
     fcgi.WSGIServer(smart_server_app).run()
-        
+
 　`fcgi`のモジュールはhttp://svn.saddi.com/py-lib/trunk/fcgi.pyで見つかります。
 これは flup_ の一部です。
 
@@ -151,14 +151,14 @@
         prefix='/code/',
         path_var='REQUEST_URI',
         readonly=True,
-        load_plugins=True, 
+        load_plugins=True,
         enable_logging=True)
 
     def handler(request):
         """Handle a single request."""
         wsgi_server = modpywsgi.WSGIServer(smart_server_app)
         return wsgi_server.run(request)
-        
+
 `modpywsgi` モジュールは
 `http://dev.pocoo.org/projects/pocoo/browser/pocoo/wrappers/modpy.py` で見つかります。
 これは pocoo_ の一部です。modpywsgi.pyをbzr-smart.pyと同じディレクトリ
@@ -191,7 +191,7 @@
 この例で使われている `make_app` ヘルパーは それに渡される `root` パスに基づいたトランスポートを伴う
 `SmartWSGIApp` をコンストラクトし、引数 `prefix` と`path_var` に基づくそれぞれのリクエストに対する
 　`bzrlib.relpath` を算出します。
-上記の例において、これは (Apacheによって設定される)'REQUEST_URI' を取り、接頭辞の '/code/' と接尾辞の '/.bzr/smart' 
+上記の例において、これは (Apacheによって設定される)'REQUEST_URI' を取り、接頭辞の '/code/' と接尾辞の '/.bzr/smart'
 をはぎ取り、それを 'bzrlib.relpath' として設定するので、 '/code/foo/bar/.bzr/smart' に対するリクエストは
 'foo/bzr' の 'bzrlib.relpath' になります。
 
@@ -217,5 +217,5 @@
 プレーンなHTTPは読み込み限定のアクセスを許可することは確実にできます。
 
 
-.. 
+..
    vim: ft=rst tw=74 et

=== modified file 'doc/ja/user-guide/introducing_bazaar.txt'
--- doc/ja/user-guide/introducing_bazaar.txt	2009-10-29 10:01:19 +0000
+++ doc/ja/user-guide/introducing_bazaar.txt	2009-12-02 20:34:07 +0000
@@ -43,13 +43,13 @@
 **チェックアウト** (*checkout*) する必要があります。
 チェックアウトにより、ユーザーが修正できるツリー(**作業ツリー**, *working tree*)ができます。
 これらの変更を記録(**コミット**, *commit*)するためには、集中型のサーバーにアクセスする権限が必要で、\
-コミットをする前に作業内容を最新バージョンとマージしなければなりません。 
+コミットをする前に作業内容を最新バージョンとマージしなければなりません。
 このアプローチは集中型モデルとして知られます。
 
 集中型モデルは長期にわたって有用であることを示してきましたが顕著な欠点がいくつかあります。
 先ず第一に、集中型のVCSはバージョン管理機能を利用するためにはサーバーに接続できることを要求します。
 二番目に、集中型のモデルは変更の **スナップショットの記録** のふるまいと変更の **公開**
-のふるまいと密接にリンクさせます。 
+のふるまいと密接にリンクさせます。
 これは状況によってはよいこともありますが別の状況では品質にわるい影響を与えることがあります。
 
 分散型のVCSツールは単独の集中型のレポジトリではなく複数のレポジトリをユーザーとチームに持たせます。

=== modified file 'doc/ja/user-guide/setting_up_email.txt'
--- doc/ja/user-guide/setting_up_email.txt	2009-10-29 10:01:19 +0000
+++ doc/ja/user-guide/setting_up_email.txt	2009-12-02 20:34:07 +0000
@@ -37,7 +37,7 @@
 
     % bzr whoami
     Joe Cool <joe@example.com>
-    
+
 'whoami'コマンドでEメールを設定する
 ------------------------------------
 
@@ -88,6 +88,6 @@
 
 スパムの標的にされないようにEメールアドレスを共有したくない人達がいます。
 公開された場所で自分でブランチもしくはチェンジセットを公開しない限り、BazaarはけっしてEメールアドレスを露出しません。
-他の人があなたに作業内容に関して連絡できるように実際のアドレスを使うことを *強く* お勧めしますが、必須ではありません。  
+他の人があなたに作業内容に関して連絡できるように実際のアドレスを使うことを *強く* お勧めしますが、必須ではありません。
 メールアドレスは難読にしたり、宛先がわからず戻ってくるようにする、もしくは `spamgourmet.cm` のような
 アンチスパムサービスの検査をうけさせたりします。

=== modified file 'doc/ja/user-guide/version_info.txt'
--- doc/ja/user-guide/version_info.txt	2009-10-29 10:01:19 +0000
+++ doc/ja/user-guide/version_info.txt	2009-12-02 20:34:07 +0000
@@ -56,7 +56,7 @@
 
   * `file_revisions`: プロジェクトのすべてのファイルに対する最終修正のリビジョンのリストを示すディクショナリ。
     これは ``$Id$`` キーワードがCVSで管理されたファイルと同じように使われます。
-    最終修正の日付は ``revisions`` マップで探すことで決定されます。 
+    最終修正の日付は ``revisions`` マップで探すことで決定されます。
     デフォルトではこれは空で、 ``--all`` もしくは ``--include-file-revisions`` によってのみ有効になります
 
 
@@ -74,7 +74,7 @@
       > version_info.h
 
 ``{revno}`` は作業ツリーのリビジョン番号に置き換えされます。
-(上記の例があなたのOSで動作しない場合、一行ですべてのコマンドを入力してみてください) 
+(上記の例があなたのOSで動作しない場合、一行ですべてのコマンドを入力してみてください)
 テンプレートの中で利用できる変数の詳細な情報に関しては、
 Bazaarのユーザーリファレンスの `Version Info`_ を参照してください。
 
@@ -93,5 +93,5 @@
 ``version_info`` ``clean`` を設定します。
 同様に ``modified`` が適切である場合に ``file_revisions`` でエントリを設定します。
 
-.. 
+..
    vim: tw=74 ft=rst spell spelllang=en_us

=== modified file 'doc/ja/user-reference/index.txt'
--- doc/ja/user-reference/index.txt	2009-10-29 10:01:19 +0000
+++ doc/ja/user-reference/index.txt	2009-12-02 20:34:07 +0000
@@ -50,7 +50,7 @@
 ブランチ
 =========
 
-ブランチは、すべての履歴を含む、プロジェクトの状態で構成されます。 
+ブランチは、すべての履歴を含む、プロジェクトの状態で構成されます。
 すべてのブランチは関連づけされたリポジトリ(ブランチの履歴が保存される場所)を持ちますが、
 複数のブランチは同じリポジトリを共有することもあります(共用リポジトリ)。
 ブランチはコピーしたりマージしたりできます。
@@ -174,7 +174,7 @@
 * さもなければ、デフォルトのフォーマットを使用します。大抵のプロジェクトはこれで十分です。
 
 (ディストロのパッケージを利用しているなどで)最新のBazaarを利用できない開発者がいるのであれば、
-それに応じてガイドラインを調整してください。 
+それに応じてガイドラインを調整してください。
 たとえば、プロジェクトがBazaar 1.7を標準化している場合、1.9の代わりに1.6を選ぶことが必要です。
 
 注: 現在サポートされるフォーマットの多くは2つのバリアントを持ちます:
@@ -308,7 +308,7 @@
 
 チェックアウト、ツリーもしくはブランチを軽量ブランチに再設定するとき、
 ローカルのブランチを破壊しなければなりません。
-(チェックアウトに関して、これはキャッシュとして最初に提供するローカルブランチです。)  
+(チェックアウトに関して、これはキャッシュとして最初に提供するローカルブランチです。)
 破壊されるブランチが同じ最終リビジョンを持たなければ、
 軽量用チェックアウト用の新しい参照ブランチ、データが失われる可能性があるので、
 Bazaarは拒否します。
@@ -342,8 +342,8 @@
 ブランチから 'bzr checkout .' を実行すると作業ツリーが作成されます。
 リモートでブランチが更新されると、そのディレクトリの中で'bzr update'を実行することで作業ツリーを更新できます。
 
-望まない作業ツリーを持つブランチがある場合、安全であれば'remove-tree'コマンドはツリーを除外します。 
-ブランチにプッシュするとき更新されないリモート作業ツリーに関する警告を回避することでこれは可能です。 
+望まない作業ツリーを持つブランチがある場合、安全であれば'remove-tree'コマンドはツリーを除外します。
+ブランチにプッシュするとき更新されないリモート作業ツリーに関する警告を回避することでこれは可能です。
 これは'--no-trees'リポジトリ('bzr help repositories'を参照)に取り組むときにも便利です。
 
 プッシュするリモートマシン上で作業ブランチを持ちたい場合、
@@ -406,7 +406,7 @@
   host=host.com
   user=joe
   password=secret
-  
+
 
 認証の定義
 -----------
@@ -423,7 +423,7 @@
 2. ユーザー、領域とパスワード
 
 ホストに対して認証するために ``HTTP`` と ``HTTPS`` は(``user, realm, password``)を必要とします。
-``.htaccess`` ファイルを利用することで、たとえば、任意の ``host`` 
+``.htaccess`` ファイルを利用することで、たとえば、任意の ``host``
 に対して (``user, realm, password``) をいくつか定義することが可能です。
 ですので本当に必要なのは (``user``, ``password``, ``host``, ``path``)です。
 ``realm`` は定義で考慮されませんが、bzrにパスワードを催促される場合表示されます。
@@ -501,7 +501,7 @@
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 すべての接続は同じ ``user`` で行われ
-(デフォルトのbzrのものが適切でない場合のためのリモートの接続) 
+(デフォルトのbzrのものが適切でない場合のためのリモートの接続)
 パスワードはいくつかの例外とともに常に催促されます::
 
         # hobby.netのPetプロジェクト
@@ -509,14 +509,14 @@
         host=r.hobby.net
         user=jim
         password=obvious1234
-        
+
         # ホームサーバー
         [home]
         scheme=https
         host=home.net
         user=joe
         password=1essobV10us
-        
+
         [DEFAULT]
         # ローカルユーザーがbarbazで、すべてのリモートサイト上ではfoobarとして
         user=foobar
@@ -556,7 +556,7 @@
         host=dev.company.com
         path=/dev/integration
         user=user2
-        
+
         # プロキシ
         [proxy]
         scheme=http
@@ -827,7 +827,7 @@
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 ``locations.conf`` によって特定のブランチ用に設定を上書きできます。
-フォーマットは1つの重大な変更を伴うbazaar.confのデフォルトセクションに対してほとんど理想的です: 
+フォーマットは1つの重大な変更を伴うbazaar.confのデフォルトセクションに対してほとんど理想的です:
 デフォルトを記述する代わりに、セクションヘッダーは値を上書きしたいブランチへのパスになります。
 ワイルドカードの '?' と '*' がサポートされます::
 
@@ -963,7 +963,7 @@
 
 :default: 上記を参照。
 :editor: マージリクエストを書くエディタを使用します。
-    これはコミットID( ``bzr whoami`` を参照), 
+    これはコミットID( ``bzr whoami`` を参照),
     smtp_serverと(オプションで)smtp_usernameとsmtp_passwordも使用します。
 :mapi: Windowsで好きなメールクライアントを使用します。
 :xdg-email: 好きなメールプラグラムを実行するためにxdg-emailを使用する
@@ -1180,7 +1180,7 @@
   $ bzr merge ../other
 
 この状況において、Bazaarは移動をキャンセルして、"a"を"b"の中に残しておきます。
-望むのであればディレクトリをリネームできれば 
+望むのであればディレクトリをリネームできれば
 衝突を解消したものとしてマークするために "bzr resolve FILE" を実行します。
 
 ディレクトリではない親
@@ -1219,7 +1219,7 @@
 ============================
 
 :pack-0.92:
-    (ネイティブ) (デフォルト) 0.92で新しく導入: 
+    (ネイティブ) (デフォルト) 0.92で新しく導入:
     dirstate-tagsフォーマットリポジトリと互換性のあるデータを持つパックベースのフォーマット。
     0.92以前のbzrリポジトリと相互運用できますが0.92以前のbzrでは読めません。
     以前はknitpack-experimentalと呼ばれていました。詳細な情報に関しては、
@@ -1596,7 +1596,7 @@
     (ネイティブ) 現在の開発フォーマット。
     pack-0.92 (とpack-0.92と互換性のある)フォーマットリポジトリにデータを変換できます。
     このフォーマットのリポジトリとブランチはbzr.devによってのみ読み込みできます。
-    使用する前に http://doc.bazaar-vcs.org/latest/developers/development-repo.html 
+    使用する前に http://doc.bazaar-vcs.org/latest/developers/development-repo.html
     をご覧下さるようお願いします。
 
 
@@ -1605,7 +1605,7 @@
     pack-0.92-subtree (pack-0.92-subtreeと互換性のあるものなら何でも)フォーマットリポジトリ
     から/へのデータの変換ができる。このフォーマットのリポジトリとブランチは
     bzr.devによってのみ読み込みできます。
-    使用する前に http://doc.bazaar-vcs.org/latest/developers/development-repo.html 
+    使用する前に http://doc.bazaar-vcs.org/latest/developers/development-repo.html
     をご覧下さるようお願いします。
 
 
@@ -1644,7 +1644,7 @@
 
 'REV1' と 'REV2' がリビジョンの識別子である場合、
 'REV1..REV2' はリビジョンの範囲を表示します。
-例: '3647..3649' 、 'date:yesterday..-1' と 'branch:/path/to/branch1/..branch:/branch2' 
+例: '3647..3649' 、 'date:yesterday..-1' と 'branch:/path/to/branch1/..branch:/branch2'
 ('..'周辺にはクォートもしくはスペースが存在しません)。
 
 範囲は異なるコマンドによって異なる解釈がなされます。
@@ -1777,7 +1777,7 @@
     投稿ブランチはbundleとmergeコマンドによって使用されます。
     投稿ブランチが指定されなければ、親ブランチが代わりに使用されます。
 
-    共通の祖先は両方のブランチ内に存在する最終リビジョンです。 
+    共通の祖先は両方のブランチ内に存在する最終リビジョンです。
     通常これはブランチポイントですが、マージされたリビジョンにもなり得ます。
 
     例::
@@ -1789,7 +1789,7 @@
 ===============
 
 標準オプションはすべてのコマンドで有効です。
-      
+
 --help, -h     ヘルプメッセージを表示する。
 --verbose, -v  詳細な情報を表示する。
 --quiet, -q    エラーと警告のみ表示する。
@@ -1876,7 +1876,7 @@
   non-recursiveモードでは、以前無視されたファイルであっても、
   名前つきのすべてのアイテムが追加されます。
   名前つきファイルがすでにバージョン管理されている場合は警告が表示されます。
-  
+
   recursiveモード(デフォルト)では、ファイルは同じ方法で扱われますが、
   ディレクトリに対するふるまいは異なります。
   すでにバージョン管理されているディレクトリであれば警告は表示されません。
@@ -1885,16 +1885,16 @@
   これらは追加されます。
   この検索はバージョン管理されたディレクトリにも再帰的に進められます。
   名前が渡されなければ、'.'が想定されます。
-  
+
   それゆえ単に 'bzr add' を実行すると現在未知であるファイルのすべてがバージョン管理されます。
-  
+
   親ディレクトリがバージョン管理されていないファイルを追加すると
   親およびそのrootまでも暗黙の内に追加されます。
   このことが意味するのはディレクトリを明示的に追加する必要はなく、
   ディレクトリの中のファイルを1つ追加するときにそれらのディレクトリも追加されます。
-  
+
   --dry-runは追加されるファイルを表示しますが、それらを実際に追加しません。
-  
+
   --file-ids-fromは提供されたパスからファイルのidの使用を試みます。
   これは同じファイル名を持ちマッチするディレクトリの発見をするためにidを探し、また純粋なパスによって行います。
   このオプションが必要になるのはめったにありませんが、後でマージする2つのブランチに同じ論理ファイルを追加する
@@ -1952,7 +1952,7 @@
 :説明:
   このコマンドは与えられたファイルの、変更によって導入されたリビジョン、
   筆者と日付を示す注釈を左側で表示します。
-  
+
   連続した行の続きに関してoriginが同じ場合、
   --allオプションが渡されない限り、これはトップでのみ表示されます。
 
@@ -2004,7 +2004,7 @@
   冒頭のスキームもしくはドライブの識別子を剥ぎ取ることで、
   FROM_LOCATIONからTO_LOCATIONが得られます。
   たとえば、"branch lp:foo-bar"は./foo-barを作成しようとします。
-  
+
   ブランチの特定のリビジョンを読み取るには、
   "branch foo/bar -r 5"のような、--revisionパラメータを提供します。
 
@@ -2024,7 +2024,7 @@
 
 :説明:
   警告: ロックを保持するプロセスが停止したときにのみロックはブレークします。
-  
+
   'bzr info'コマンドを通して開いているロックに関する情報を得ることができます。
 
 :例:
@@ -2047,7 +2047,7 @@
 
 :説明:
   リビジョンが指定されなければ、最後のリビジョンが使用されます。
-  
+
   注意: バイナリファイルでこのコマンドを使用する際には
         標準出力をリダイレクトするように気をつけてください。
 
@@ -2070,10 +2070,10 @@
 :説明:
   このコマンドはデータの破損もしくはbzrのバグを検出するために
   ブランチとリポジトリストレージに関するさまざまな不変量をチェックします・
-  
+
   問題が検出された場合のみ作業ツリーとブランチのチェックは出力をします。
   リポジトリチェックの出力フィールドは次のとおりです:
-  
+
       revisions: これはチェックされるリビジョンの番号です。
           これは問題を示しません。
       versionedfiles: これはチェックされるバージョン管理されたファイルの数です。
@@ -2088,7 +2088,7 @@
           テキストのエントリが修正されたときにテキストは繰り返しできますが、
           ファイルの内容は繰り返しできません。
           これは問題を示しません。
-  
+
   制限が指定されなければ、すべてのBazaarデータはチェックされる位置で見つかります。
 
 :例:
@@ -2131,16 +2131,16 @@
   チェックアウトは作業ツリーを再構成します。
   作業ツリーを削除した場合もしくはこれがけっして作成されない場合
   - すなわち、SFTPを使用してブランチを現在の位置にpushする場合、これは便利です。
-  
+
   TO_LOCATIONが省略されると、BRANCH_LOCATIONの最後のコンポーネントが使用されます。
   言い換えると、"checkout ../foo/bar" は./barを作成しようとします。
   BRANCH_LOCATIONが has no /を持たないもしくはパスの区切り文字が埋め込まれている場合、
   先頭のスキームもしくはドライブの識別子を除去することでBRANCH_LOCATIONからTO_LOCATIONが
   得られます。たとえば、"checkout lp:foo-bar"は./foo-barを作成しようとします。
-  
+
   特定のリビジョンのブランチを読み取るには、
-  "checkout foo/bar -r 5"のように--revisionパラメータを提供します。 
-  これはすぐに時代遅れになりますが[なのでコミットできない] 
+  "checkout foo/bar -r 5"のように--revisionパラメータを提供します。
+  これはすぐに時代遅れになりますが[なのでコミットできない]
   役に立つことがあります(すなわち古いコードを検査するため)。
 
 :エイリアス:  co
@@ -2175,22 +2175,22 @@
 
 :説明:
   引数が渡されなければ、ツリー全体がコミットされます。
-  
+
   選択されたファイルが指定されると、これらのファイルへの変更のみがコミットされます。
   ディレクトリが指定されるとディレクトリとその中のすべてがコミットされます。
-  
+
   excludesが渡されるとき、これらは選択されたファイルよりも優先されます。
   たとえば、fooの範囲での変更のみコミットされますが、foo/barの範囲の変更はコミットされません::
-  
+
     bzr commit foo -x foo/bar
-  
+
   変更の著者がコミッターと同じ人物でなければ、
   --authorオプションを使用して著者の名前を指定できます。
   名前はコミッターidと同じフォーマットです。たとえば"John Doe <jdoe@example.com>"です。
-  
+
   コミットされるツリーが無効である場合選択されたファイルのコミットが失敗することがあります。
   次の一連のコマンドを考えてみましょう::
-  
+
     bzr init foo
     mkdir foo/bar
     bzr add foo/bar
@@ -2199,12 +2199,12 @@
     mkdir foo/bar
     bzr add foo/bar
     bzr commit foo/bar -m "committing bar but not baz"
-  
+
   上記の例において、最終コミットは故意に失敗します。
   これによってユーザーは、同時に、最初に個別に、もしくはまったく
   リネームしたくないかどうかを決める機会を得ます。
   (一般的なルールとして、判断がつかないとき、Bazaarは安全に物事を行う方針を持ちます。)
-  
+
   注: マージの後の選択されたファイルのコミットはまだサポートされていません。
 
 :エイリアス:  ci, checkin
@@ -2227,11 +2227,11 @@
   人間だけが修正できるある種の問題が存在します。
   この問題に遭遇するとき、衝突がマークされます。
   衝突はコミットする前に何かを修正する必要があることを意味します。
-  
+
   通常の衝突は短く人間が読めるメッセージとして一覧が示されます。
   --textが提供される場合、代わりに、テキストの衝突を持つファイルのパスの一覧が表示されます。
   (これはテキストの衝突を持つファイルをすべて編集するために便利です。)
-  
+
   問題を修正したらbzr resolveを使用します。
 
 :関連コマンド: `resolve`_
@@ -2278,7 +2278,7 @@
   リモートと複数のブランチは--oldと--newオプションを使用して比較できます。
   これらのオプションが提供されなければ、両方のデフォルトは、存在すれば最初の引数、
   引数が渡されなければ現在のツリーから得られます。
-  
+
   "bzr diff -p1" は "bzr diff --prefix old/:new/"と同等で、
   "patch -p1"に最適なパッチが生成されます。
 
@@ -2346,19 +2346,19 @@
 
 :説明:
   リビジョンが指定されなければこれは最終コミットのリビジョンをエクスポートします。
-  
+
   フォーマットはtar、tgz、tbz2のような"exporter"の名前になることができます。
   何も渡されなければ、拡張子かｒフォーマットを見つけようとします。
   拡張子が見つからなければディレクトリにエクスポートします(--format=dirと同等)。
-  
+
   rootが提供されると、これはコンテナフォーマット(tar、zip、その他)内部のrootディレクトリとして使用されます。
   これが提供されなければエクスポートされるファイル名へのデフォルトになります。
   rootオプションは'dir'フォーマットに対して効果がありません。
-  
+
   ブランチが省略されると現在の作業ディレクトリを含むブランチが使用されます。
-  
+
   注: ASCIIではないファイル名でのツリーのエクスポートはサポートされません。
-  
+
     ==========================       =========================
     サポートされるフォーマット        拡張子で自動検出
     ==========================       =========================
@@ -2399,11 +2399,11 @@
 
 :説明:
   パターンの構文の詳細は ``bzr help patterns`` を参照。
-  
+
   無視リストからパターンを除外するには、.bzrignoreファイルを編集します。
   追加した後で、コマンドを使用して間接的に、もしくはエディタを使用して
   直接そのファイルを編集もしくは削除した後で、そのコミットを確認してください。
-  
+
   注: シェルのワイルドカードを含む無視パターンはUnixのシェルからクォートされなければなりません。
 
 :例:
@@ -2442,9 +2442,9 @@
 
 :説明:
   無視されるファイルと無視パターンのすべての一覧を表示します。
-  
+
   代わりにファイルの一覧だけを表示するには::
-  
+
       bzr ls --ignored
 
 :関連コマンド: `ignore`_, `ls`_
@@ -2463,7 +2463,7 @@
 :説明:
   このコマンドはツリー、ブランチもしくはリポジトリに関連する既知の位置とフォーマットのすべてを表示します。
   統計情報はそれぞれのレポートに含まれます。
-  
+
   ブランチと作業ツリーは見つからないリビジョンもレポートします。
 
 :関連項目: `リポジトリ`_, `revno`_, `作業ツリー`_
@@ -2514,8 +2514,8 @@
                         repo.html をご覧いただくようお願いします。
     --dirstate          0.15の新しいフォーマット: 速いローカルオペレーション。
                         ネットワークを通したアクセスのときbzr 0.8とそれ以降と互換性がある。
-    --dirstate-tags     0.15の新しいフォーマット: 速いローカルオペレーションで 
-                        ネットワークオペレーションに関するスケーリングを改善。 
+    --dirstate-tags     0.15の新しいフォーマット: 速いローカルオペレーションで
+                        ネットワークオペレーションに関するスケーリングを改善。
                         タグのサポートを追加。bzr < 0.15とは互換性がない。
     --knit              knitsを使用するフォーマット。bzr <= 0.14との相互運用に推奨。
     --metaweave         0.8での暫定フォーマット。knitよりも遅い。
@@ -2534,15 +2534,15 @@
 
 :説明:
   空のブランチを作成するもしくは既存のプロジェクトをインポートする前に使用します。
-  
+
   親ディレクトリの位置にリポジトリが存在する場合、
   ブランチの履歴はリポジトリに保存されます。
   さもなければinitは.bzrのディレクトリに独自の履歴を運ぶスタンドアロンのブランチを作成します。
-  
+
   ロケーションにブランチがすでにあるが作業ツリーがない場合、ツリーは'bzr checkout'で投入できます。
-  
+
   ファイルのツリーをインポートする方法のレシピです::
-  
+
       cd ~/project
       bzr init
       bzr add .
@@ -2594,8 +2594,8 @@
                         repo.html をご覧いただくようお願いします。
     --dirstate          0.15の新しいフォーマット: 速いローカルオペレーション。
                         ネットワークを通したアクセスのときbzr 0.8とそれ以降と互換性がある。
-    --dirstate-tags     0.15の新しいフォーマット: 速いローカルオペレーションで 
-                        ネットワークオペレーションに関するスケーリングを改善。 
+    --dirstate-tags     0.15の新しいフォーマット: 速いローカルオペレーションで
+                        ネットワークオペレーションに関するスケーリングを改善。
                         タグのサポートを追加。bzr < 0.15とは互換性がない。
     --knit              knitsを使用するフォーマット。bzr <= 0.14との相互運用に推奨。
     --metaweave         0.8での暫定フォーマット。knitよりも遅い。
@@ -2615,7 +2615,7 @@
 :説明:
   ブランチのディレクトリではなく、リポジトリにリビジョンを保存する
   リポジトリディレクトリの元で作成された新しいブランチ。
-  
+
   --no-treesオプションが使用されるとリポジトリのブランチはデフォルトで作業ツリーを持ちません。
 
 :例:
@@ -2661,7 +2661,7 @@
 
 :説明:
   デフォルトでは作業ディレクトリを含むブランチのログを表示する。
-  
+
   ログの範囲をリクエストするには、-r begin..endコマンドを使用できます。
   -r revisionは指定したリビジョンをリクエストし、
   -r ..end もしくは -r begin.. も有効です。
@@ -2742,35 +2742,35 @@
   mergeディレクティブを含むファイルへのパスの形式で指定できます。
   どちらも指定されなければ、デフォルトは上流ブランチもしくは
   --rememberを使用して最近マージされたブランチです。
-  
+
   マージをブランチするとき、デフォルトではチップがマージされます。
   異なるリビジョンをピックするには、--revisionを渡します。
   2つの値を指定する場合、最初の値はBASEとして、2番目の値はOTHERとして使用されます。
   個別のリビジョン、もしくはこのように利用可能なリビジョンのサブセットをマージすることは
   一般的に"チェリーピック"として言及されます。
-  
+
   リビジョン番号はマージされるブランチに対して常に相対的です。
-  
+
   デフォルトでは、bzrは、自動的に適切なベースを検出して、
   他のブランチからすべてのネットワークでマージしようとします。
   これが失敗すると、明示的なベースを渡すことが必要になることがあります。
-  
+
   マージは2つのブランチの変更を結合するために最善を尽くしますが、
   人間だけが修正できる種類の問題があります。
   この問題に遭遇するとき、衝突マークがつけられます。
   衝突はコミットする前に何かを修正する必要があることを意味します。
-  
+
   問題を修正したらbzr resolveを使用します。bzr conflictsも参照してください。
-  
+
   デフォルトのブランチセットが存在しない場合、最初のマージはそれを設定します。
   その後で、デフォルトを使用するブランチを省略できます。
   デフォルトを変更するには、--rememberを使用します。
   リモートロケーションがアクセス可能場合のみ値は保存されます。
-  
+
   マージの結果は目的の作業ディレクトリに設置されます。
   このディレクトリは(bzr diffで)閲覧、テスト、
   とマージの結果を記録するためにコミット可能です。
-  
+
   --forceが渡されない限り、コミットされていない変更が存在すればマージの実行は拒否されます。
 
 :例:
@@ -2857,13 +2857,13 @@
   他のすべての名前はそこに移動します。
   さもなければ、2つの引数だけにしなければならず
   ファイルは新しい名前に変更されます。
-  
+
   OLDNAMEがファイルシステム上に存在しないがバージョン管理されていて
   NEWNAMEはファイルシステム上に存在せずバージョン管理もされていない場合、
   mvはファイルが手動で移動させられその変更を反映するために
   内部インベントリだけを更新することを想定します。
   多くのSOURCEファイルをDESTINATIONに移動させるときも同じです。
-  
+
   ブランチの間でファイルを移動させることはできません。
 
 :エイリアス:  move, rename
@@ -2914,9 +2914,9 @@
 :説明:
   このコマンドはプラグインのバージョンとそれぞれの手短な説明を含めて
   インストールされたプラグインの一覧を表示します
-  
+
   --verboseはそれぞれのプラグインが設置されたパスを表示します。
-  
+
   プラグインはコードを追加したり置き換えたりすることで
   リビジョン管理システムを拡張する外部コンポーネントです。
   コマンドの上書き、新しいコマンドの追加、追加のネットワーク転送の提供や
@@ -2950,19 +2950,19 @@
   このコマンドは分岐されていないブランチのみで動作します。
   目的のブランチの最新の変更コミットが親にマージされなかった場合(直接もしくは間接)、
   ブランチは分岐したものとして見なされます。
-  
+
   ブランチが分岐していれば、あるブランチからの変更を他のブランチに統合するために
   'bzr merge'を使用できます。
   一旦あるブランチがマージされると、他のブランチは再びそれをpullできるようになります。
-  
+
   ローカルの変更を忘れてリモートブランチを満たすようにブランチを更新したいだけなら、
   pull --overwriteを使用します。
-  
+
   デフォルトのロケーションが存在しない場合、最初のpullはこれを設定します。
   その後で、デフォルトを使用するロケーションを省略できます。
   デフォルトを変更するには、--rememberを使用します。
   リモートロケーションがアクセスできる場合のみ値は保存されます。
-  
+
   注: 位置がブランチのフォーマットもしくはbzr sendで生成されたmergeディレクトリを格納する
       ファイルへのパスで指定できます。
 
@@ -2995,20 +2995,20 @@
 :説明:
   これは割高でリモートファイルシステムではサポートされないので、
   ターゲットブランチは投入された作業ツリーを持ちません。
-  
+
   スマートサーバーもしくはプロトコルの中には将来作業ツリーを導入しないものがあります。
-  
+
   このコマンドは分岐されていないブランチでのみ動作します。
   目的のブランチの最新のコミットがソースブランチによって(直接もしくは間接的に)マージされなければ
   ブランチは分岐されたものとして見なされます。
-  
+
   ブランチが分岐されると、他のブランチを完全に置き換えるために
   'bzr push --overwrite'を使用できます。この場合、マージされていない変更は廃棄されます。
-  
+
   他のブランチに異なる変更があることを保証したい場合は、
   他のブランチからマージを行い(bzr help mergeを参照)、それをコミットします。
   その後で'--overwrite'なしでpushを行うことができるようになります。
-  
+
   デフォルトのpush位置の設定がなければ、最初のpushはこれを設定します。
   その後では、デフォルトを省略できます。
   デフォルトを変更するには、--rememberを使用します。
@@ -3036,9 +3036,9 @@
   2番目のブランチが提供されると、
   ブランチをまたがる調整も行われます。これによってbzrの初期のバージョンでは存在しなかった
   ツリーのroot idのようなデータがチェックされ、両方のブランチで正しく表示されます。
-  
+
   同時にデータが再圧縮されるのでディスクスペースの節約やパフォーマンスのゲインにつながります。
-  
+
   ブランチはローカルディスクもしくはsftpのようにリスト可能なシステム上になければなりません。
 
 :関連項目: `check`_
@@ -3067,7 +3067,7 @@
 
 :説明:
   ターゲットの設定を指定しなければなりません。
-  
+
   チェックアウトに関しては指定されていなければ、bind-toのロケーションは自動検出されます。
   優先順位は
   1. 軽量チェックアウトに関しては、現在バインドされているロケーション。
@@ -3101,7 +3101,7 @@
 :説明:
   衝突を解消している間に異なるマージテクニックを試したい場合はこれを使用します。
   マージテクニックの中には他のものよりもすぐれたものがあり、
-  remergeによって異なるファイルで異なるテクニックを試すことができます。  
+  remergeによって異なるファイルで異なるテクニックを試すことができます。
   remergeのオプションはmergeのものと同じ意味とデフォルトを持ちます。
   違いは未解決のマージが存在するときのみremergeは実行できて
   特定のファイルを指定できることです。
@@ -3109,12 +3109,12 @@
 :例:
     すべてのファイルのマージを再実行し、通常のTHISとOTHERテキストに加えて、
     衝突領域のベーステキストを表示する::
-  
+
         bzr remerge --show-base
 
     weaveマージアルゴリズムを使用して"foobar"のマージを再実行して、
     衝突領域のサイズを減らすために追加処理を行う::
-  
+
         bzr remerge --merge-type weave --reprocess foobar
 
 
@@ -3138,7 +3138,7 @@
 
 :説明:
   このコマンドによってbzrは指定されたファイルへの変更の追跡を止めます。
-  rebertコマンドで容易に復元できるのであればbzrはこれらのファイルを削除します。 
+  rebertコマンドで容易に復元できるのであればbzrはこれらのファイルを削除します。
   オプションもしくはパラメータが与えられなければbzrは追跡されているファイルをスキャンしますが
   ツリーの中で見つからなければそれらの追跡を停止します。
 
@@ -3158,7 +3158,7 @@
 
 :説明:
   軽量チェックアウトは作業ツリーと大差ないので、これはそれに対する実行を拒絶します。
-  
+
   作業ツリーを再現するには、"bzr checkout"を使用します。
 
 :関連項目: `checkout`_, `working-trees`_
@@ -3193,11 +3193,11 @@
   人間だけが修正できる種類の問題があります。
   この問題に遭遇するとき、衝突がマークされます。
   衝突はコミットする前に何かを修正する必要があることを意味します。
-  
+
   一旦問題を修正すれば、自動的にテキストの衝突を修正したものとしてマークするために"bzr resolve"を使用し、
   特定の衝突を解消したものとしてマークするためにFILEをresolveします。
   すべての衝突が解消されたものとしてマークするにはor "bzr resolve --all"を行います。
-  
+
 :関連コマンド: `bzr conflicts`
 
 :エイリアス:  resolved
@@ -3221,29 +3221,29 @@
   指定されたテキストだけを差し戻すファイルのリストを渡します。
   さもなければ、すべてのファイルが差し戻されます。
   '--revision'でリビジョンが指定されなければ、最後にコミットされたリビジョンが使用されます。
-  
+
   以前のリビジョンに差し戻さずに、いくつかの変更を除外するには、代わりにmergeを使用します。
   たとえば、"merge . --revision -2..-3"は-2で導入された変更を除外しますが、
   -1で導入された変更には影響を与えません。
   hunk-by-hunkベースである変更を除外するには、Shelfプラグインを参照してください。
-  
+
   デフォルトでは、手動で変更されてきたファイルは最初にバックアップされます。
   (マージのみで変更されたファイルはバックアップされません。)
   バックアップファイルの名前には '.~#~' が追加されます。#は番号です。
-  
+
   ファイルを提供する場合、現在のパス名もしくはターゲットリビジョンからのパス名を使用できます。
   名前でファイルを"undelete"するためにrevertを使用できます。
   ディレクトリに名前をつけると、そのディレクトリのすべての内容が差し戻されます。
-  
+
   そのリビジョン以降に新しく追加されたファイルは削除されます。適切であればバックアップは維持されます。
   未知のファイルを持つディレクトリは削除されません。
-  
+
   作業ツリーは未解決のマージされたリビジョンのリストを含みます。
   これは次のコミットで親として含まれます。
   通常は、ファイルを差し戻すのと同様にrevertはそのリストをクリーンにします。
   ファイルが指定されていれば、revertは未解決のマージリストをそのままにしてファイルだけを差し戻します。
   すべてのファイルを差し戻すがマージの記録を維持するにはツリーのrootで"bzr revert ."を使用し、
-  ファイルの差し戻しを行わずに未解決のマージリストをクリアするには"bzr revert --forget-merges"を使用します。 
+  ファイルの差し戻しを行わずに未解決のマージリストをクリアするには"bzr revert --forget-merges"を使用します。
 
 :関連項目: `cat`_, `export`_
 
@@ -3302,41 +3302,41 @@
 
 :説明:
   mergeディレクティブはmergeリクエストを行うために必要な多くのものを提供します:
-  
+
   * 実行するマージのマシンが理解できる説明
-  
+
   * リクエストされた変更のプレビューであるオプションのパッチ
-  
+
   * リビジョンデータのオプションバンドル、
     ブランチからデータを読み込まずに、mergeディレクトリからの変更を直接適用できるようになります。
-  
+
   --no-bundleが指定されると、public_branchが必要です(また最新でなければなりません)、
   受け取り手がpublic_branchを使用するマージを実行できるように
   後で他の人がチェックできるように、知っているのであればpublic_branchを常に含まれていなければなりません。
-  
+
   投稿ブランチのデフォルトは親ですが、上書きできます。
   提供されれば投稿ブランチと公開ブランチの両方が記録されます。
-  
+
   public_branchがsubmit_branchに知られていれば、
   その公開と投稿ブランチはマージのインストラクションで使用されます。
   これはそのローカルミラーに対してpublic_branchを設定すれば、
   そのミラーは実際の投稿ブランチとして使用できることを意味します。
-  
+
   メールは好きなプログラムで送信されます。
   Windowsではこれは透過的です(MAPIが使用される)。
   Linuxでは、xdg-emailユーティリティを必要とします。
   望ましいクライアントが見つからなければ(もしくは使用できなければ)、エディタが使用されます。
-  
+
   特定のメールプログラムを使用するには、mail_client設定オプションを設定します。
-  (Thunderbird 1.5に関して、これはいくつかのバグに対処します。) 
+  (Thunderbird 1.5に関して、これはいくつかのバグに対処します。)
   特定のクライアント用にサポートされる値は"claws"、"evolution"、"kmail"、"mutt"、と"thunderbird";
   一般的なオプションは"default"、"editor"、"emacsclient"、"mapi"、と"xdg-email"です。
   プラグインがサポートされるクライアントを追加することもあります。
-  
+
   メールが送信されている場合、to addressが必要になります。
   これはコマンドライン、submit_to設定オプションをブランチ自身に設定するか、
   投稿ブランチでchild_submit_to設定オプションを設定することで提供できます。
-  
+
   現在2つのフォーマットがサポートされています: "4"はリビジョンバンドルフォーマット4
   とマージディレクトリフォーマット2です。
   これは古いフォーマットよりも顕著に速く小さいです。
@@ -3344,7 +3344,7 @@
   これはデフォルトです。
   "0.9"はリビジョンバンドルフォーマット0.9とマージディレクティブフォーマット1を使用します。
   これは0.12 - 0.18と互換性があります。
-  
+
   mergeもしくはpullコマンドを使用することでmergeディレクトリが適用されます。
 
 :関連項目: `merge`_, `pull`_
@@ -3393,18 +3393,18 @@
 :説明:
   shelveによって変更を一時的に"棚に上げる"、すなわち邪魔にならない場所に置くことができます。
   'unshelve'コマンドで後で元に戻すことができます。
-  
+
   shelve --listが指定されると、以前退避された変更の一覧が表示されます。
-  
+
   shelveは不適切に混ぜられた変更のいくつかのセットの分離を手助けすることを目的としています。
   すべての変更を除去したいだけで後で退避する必要がなければ、revertを使用します。
   一度にすべてのテキストの変更をshelveするには、shelve --allを使用します。
-  
+
   ファイル名が指定されると、それらのファイルの変更のみ退避されます。
   他のファイルは手つかずのままです。
-  
+
   リビジョンが指定されれば、そのリビジョン以降の変更は退避されます。
-  
+
   複数のアイテムを退避することができ、デフォルトでは、
   'unshelve'は最近shelveされた変更を復元します。
 
@@ -3425,7 +3425,7 @@
 :説明:
   位置が指定されなければローカルツリーが使用されます。
   コミッターが指定されなければデフォルトのコミッターが使用されます。
-  
+
   これはすでにシグネチャを持つコミットには署名しません。
 
 
@@ -3444,7 +3444,7 @@
   このコマンドは'rich-root' もしくは 'rich-root-pack'のように
   リッチrootをサポートするフォーマットでターゲットツリーを生み出します。
   これらのフォーマットは'dirstate-tags'のような初期のフォーマットに変換できません。
-  
+
   TREEの引数は作業ツリーのサブディレクトリになります。
   そのサブディレクトリは独自のブランチを持つ独立したツリーに変換されます。
   トップレベルツリーのコミットは新しいサブツリーに適用されません。
@@ -3472,38 +3472,38 @@
 :説明:
   これはバージョン管理されたファイルと未知のファイルを状態で
   分類してレポートします。利用可能な状態は次のとおりです:
-  
+
   added
       作業ツリーでバージョン管理されているが以前のリビジョンではない。
-  
+
   removed
       以前のリビジョンでバージョン管理されているが作業コピーでは移動もしくは削除されている。
-  
+
   renamed
       以前のリビジョンから変更されたファイルのパス;
       テキストも変更されていることがある。
       これは親ディレクトリがリネームされたファイルを含む。
-  
+
   modified
       以前のリビジョン以降変更されたテキスト。
-  
+
   kind changed
       変更されたファイルの種類(たとえばファイルからディレクトリへ)。
-  
+
   unknown
       バージョン管理されていないかつ無視パターンにマッチしない。
-  
+
   無視されるファイルを見るには'bzr ignored'を使用します。
   ファイルテキストへの詳細な変更に関しては、'bzr diff'を使用します。
-  
+
   --shortもしくは-Sは、Subversionのstatusコマンドに似た、
   それぞれのアイテムに対するステータスフラグを提供することに注意してください。
   svn -qと似たような出力を得るには、bzr status -SVを使用します。
-  
+
   引数が指定されなければ、作業ディレクトリ全体のステータスが示されます。
   さもなければ、指定されたファイルもしくはディレクトリのステータスのみが報告されます。
   ディレクトリが渡されれば、そのディレクトリ内部のすべてに関するステータスが報告されます。
-  
+
   1つのリビジョンの引数が渡されれば、ステータスはそのリビジョンに対して
   2つの引数の場合は2つのリビジョンの間で算出されます。
 
@@ -3527,12 +3527,12 @@
   重量チェックアウトに対して、これはローカルコミットがなく、
   バインドされたブランチがないことを確認して、
   ローカルブランチを新しいロケーションのミラーにしてそれにバインドします。
-  
+
   両方の場合において、作業ツリーはupdateされコミットされてない変更はマージされます。
   ユーザーは望むのであればcommitもしくはrevertできます。
-  
+
   マージの追加にはswithを使用する前にcommitもしくはrevertする必要があります。
-  
+
   swithするブランチへのパスは現在のブランチの親ディレクトリに対して相対的に指定できます。
   たとえば、現在/path/to/branchのチェックアウトの中にいるのであれば
   'newbranch'を指定すれば/path/to/newbranchでのブランチが発見されます。
@@ -3561,13 +3561,13 @@
   タグはリビジョンに人間が理解できる名前を与えます。
   -r (--revision)オプションをとるコマンドは-rtag:Xに渡されます。
   Xは以前作成されたタグです。
-  
+
   タグはブランチに保存されます。
   branch、push、pullもしくはmergeを行うときタグはあるブランチから他のブランチにコピーされます。
-  
+
   --forceを渡さない限り、既存のタグ名を与えるとエラーになります。
   この場合新しいリビジョンを示すようにタグは移動します。
-  
+
   タグをリネームする(名前を変更するが同じリビジョンで維持する)には、
   ``bzr tag new-name -r tag:old-name`` と ``bzr tag --delete oldname`` を実行します。
 
@@ -3649,11 +3649,11 @@
 :説明:
   --verboseは削除されているものを表示します。
   --dry-runはすべてのモーションを経験しますが、実際には何も削除しません。
-  
+
   --revisionが指定されると、指定されたリビジョンでブランチをそのままにするために
   リビジョンをuncommitします。たとえば、"bzr uncommit -r 15"はリビジョン15でのブランチを
   そのままにします。
-  
+
   uncommitは新しいコミットの準備ができている作業ツリーをそのままにします。
   唯一行われる変更はコミット以前に存在していた追加マージをリストアすることです。
 
@@ -3696,7 +3696,7 @@
   このコマンドは作業ツリーでマージを実行し、衝突を生成することがあります。
   ローカルの変更がある場合、updateを完了させるために
   updateの後でそれらをコミットする必要があります。
-  
+
   ローカルの変更を破棄したい場合、updateの後で'bzr commit'の代わりに
   'bzr revert'を使用できます。
 
@@ -3745,8 +3745,8 @@
                         repo.html をご覧いただくようお願いします。
     --dirstate          0.15の新しいフォーマット: 速いローカルオペレーション。
                         ネットワークを通したアクセスのときbzr 0.8とそれ以降と互換性がある。
-    --dirstate-tags     0.15の新しいフォーマット: 速いローカルオペレーションで 
-                        ネットワークオペレーションに関するスケーリングを改善。 
+    --dirstate-tags     0.15の新しいフォーマット: 速いローカルオペレーションで
+                        ネットワークオペレーションに関するスケーリングを改善。
                         タグのサポートを追加。bzr < 0.15とは互換性がない。
     --knit              knitsを使用するフォーマット。bzr <= 0.14との相互運用に推奨。
     --metaweave         0.8での暫定フォーマット。knitよりも遅い。
@@ -3809,15 +3809,15 @@
   バージョンに関する情報をアプリケーションのソースコードに追加するために
   このコマンドを使用できます。出力のフォーマットはサポートされているもの1つか
   テンプレートに基づいてカスタマイズされたものです。
-  
+
   例::
-  
+
     bzr version-info --custom \
       --template="#define VERSION_INFO \"Project 1.2.3 (r{revno})\"\n"
-  
+
   現在のリビジョン番号を含むフォーマットされた文字列でCヘッダファイルを生成します。
   テンプレートでのサポートされた他の変数は次のとおりです:
-  
+
     * {date} - 最終リビジョンの日付
     * {build_date} - 現在の日付
     * {revno} - リビジョン番号

=== modified file 'doc/ru/index.txt'
--- doc/ru/index.txt	2009-09-09 02:30:32 +0000
+++ doc/ru/index.txt	2009-12-02 20:34:07 +0000
@@ -2,7 +2,7 @@
 Главный каталог документов Bazaar
 =================================
 
-Последняя версия этих документов доступа со страницы документации 
+Последняя версия этих документов доступа со страницы документации
 на сайте Bazaar, <http://doc.bazaar-vcs.org/ru/>.
 
 Основная документация
@@ -25,9 +25,9 @@
 * `Руководство по миграции <http://doc.bazaar-vcs.org/migration/en/>`_
   |--| для команд переносящих историю с других систем контроля версий
 
-* `Словарь терминов <http://bazaar-vcs.org/BzrGlossary>`_ (англ.), 
-  см. также `русскую версию`__ 
-  
+* `Словарь терминов <http://bazaar-vcs.org/BzrGlossary>`_ (англ.),
+  см. также `русскую версию`__
+
 __  http://groups.google.com/group/ru_bzr/web/%D0%B3%D0%BB%D0%BE%D1%81%D1%81%D0%B0%D1%80%D0%B8%D0%B9
 
 * `Часто задаваемые вопросы <https://answers.launchpad.net/bzr>`_ (англ.)

=== modified file 'doc/ru/mini-tutorial/index.txt'
--- doc/ru/mini-tutorial/index.txt	2009-05-05 21:16:12 +0000
+++ doc/ru/mini-tutorial/index.txt	2009-12-02 20:34:07 +0000
@@ -15,20 +15,20 @@
 ваших файлов, как вносить изменения, проверять вашу работу, публиковать её и
 отправлять для объединения с главной веткой проекта.
 
-Если вы предпочитаете более подробное введение, обратитесь к разделу 
+Если вы предпочитаете более подробное введение, обратитесь к разделу
 `Узнать больше`_.
 
 Установка
 =========
 
-Это руководство не описывает как установить Bazaar, потому что обычно 
+Это руководство не описывает как установить Bazaar, потому что обычно
 это очень легко. Инструкции по установке вы найдете тут:
 
 - **GNU/Linux:** скорее всего Bazaar уже присутствует в вашем дистрибутиве GNU/Linux.
 - **Windows:** `инструкции по установке для Windows`_.
 - **Mac OS X:** `инструкции по установке для Mac OS X`_.
 
-Для других платформ и для установки из исходных кодов, обратитесь к страницам 
+Для других платформ и для установки из исходных кодов, обратитесь к страницам
 Загрузка_ и Установка_.
 
 .. _инструкции по установке для Windows: http://bazaar-vcs.org/WindowsDownloads
@@ -39,7 +39,7 @@
 Представьтесь
 =============
 
-Прежде чем начать работать, было бы неплохо сообщить Bazaar кто вы такой. 
+Прежде чем начать работать, было бы неплохо сообщить Bazaar кто вы такой.
 В этом случае ваша работа будет корректно идентифицирована в истории ревизий.
 
 Используя ваше имя и адрес электронной почты, вместо данных Васи Пупкина,
@@ -66,8 +66,8 @@
     $ mkdir subdirectory
     $ touch test1.txt test2.txt test3.txt subdirectory/test4.txt
 
-**Замечание для пользователей Windows:** используйте Windows Explorer 
-для создания ваших каталогов, затем нажимайте правую кнопку мыши 
+**Замечание для пользователей Windows:** используйте Windows Explorer
+для создания ваших каталогов, затем нажимайте правую кнопку мыши
 в этих каталогах и выбирайте ``Новый файл``, чтобы создать ваши файлы.
 
 Теперь дадим Bazaar возможность инициализировать свои данные в каталоге вашего
@@ -182,8 +182,8 @@
 свободного программного обеспечения. Вы можете использовать его для публикации
 своей ветки.
 
-Если у вас нет учетной записи Launchpad, следуйте 
-`руководству по получению учетной записи`_ и `зарегистрируйте SSH ключ`_ 
+Если у вас нет учетной записи Launchpad, следуйте
+`руководству по получению учетной записи`_ и `зарегистрируйте SSH ключ`_
 в своей новой учетной записи.
 
 .. _руководству по получению учетной записи: https://help.launchpad.net/CreatingYourLaunchpadAccount
@@ -264,14 +264,14 @@
     Using saved parent location: http://bazaar.launchpad.net/~bzr/bzr-gtk/trunk
 
 Теперь вы можете отправить директиву объединения по электронной почте
-в проект bzr-gtk. Если разработчики bzr-gtk захотят, то смогут использовать 
+в проект bzr-gtk. Если разработчики bzr-gtk захотят, то смогут использовать
 эту директиву для включения вашей работы в основную ветку.
 
 
 Узнать больше
 =============
 
-Больше информации о Bazaar вы найдете в 
+Больше информации о Bazaar вы найдете в
 `Руководстве пользователя Bazaar <../user-guide/index.html>`_.
 
 Чтобы узнать больше о Bazaar из командой строки::

=== modified file 'doc/ru/tutorials/centralized_workflow.txt'
--- doc/ru/tutorials/centralized_workflow.txt	2009-06-05 18:59:14 +0000
+++ doc/ru/tutorials/centralized_workflow.txt	2009-12-02 20:34:07 +0000
@@ -45,7 +45,7 @@
 использоваться в сообщениях журнала и аннотациях, таким образом лучше что
 бы она была похожа на что-то реальное.
 
-::  
+::
 
    % bzr whoami "Иван Пупкин <ivan@pupkin.ru>"
 
@@ -109,7 +109,7 @@
 
 .. _Отслеживание изменений на основной ветке: http://bazaar-vcs.org/TrackingUpstream
 
-.. 
+..
    TODO: На самом деле нам нужен другой документ для описания
    конвертирования проекта. Но пока ссылка выше - это лучшее.
 
@@ -288,7 +288,7 @@
 ::
 
   % bzr branch sftp://centralhost/srv/bzr/sigil/user-a \
-               sftp://centralhost/srv/bzr/sigil/user-a/feature 
+               sftp://centralhost/srv/bzr/sigil/user-a/feature
   % cd ~/work/sigil
   % bzr checkout sftp://centralhost/srv/bzr/sigil/user-a/feature myfeature
 
@@ -315,5 +315,5 @@
 ветки разделяют историю и они могут так же разделять и хранилище истории.
 
 
-.. 
+..
    vim: tw=74 ft=rst spell spelllang=en_us

=== modified file 'doc/ru/tutorials/tutorial.txt'
--- doc/ru/tutorials/tutorial.txt	2009-06-05 18:59:14 +0000
+++ doc/ru/tutorials/tutorial.txt	2009-12-02 20:34:07 +0000
@@ -482,7 +482,7 @@
 готовой ветки. Так как эта копия может быть потенциальной новой веткой эта
 команда называется **branch**::
 
-    % bzr branch http://bazaar-vcs.org/bzr/bzr.dev 
+    % bzr branch http://bazaar-vcs.org/bzr/bzr.dev
     % cd bzr.dev
 
 Эта команда копирует полную историю ветки и после этого вы можете делать все
@@ -553,7 +553,7 @@
 
   ::
 
-    % bzr push sftp://servername.com/path/to/directory 
+    % bzr push sftp://servername.com/path/to/directory
 
   (Каталог назначения должна быть создан заранее, если только не указана
   опция ``--create-prefix``)

=== modified file 'doc/ru/tutorials/using_bazaar_with_launchpad.txt'
--- doc/ru/tutorials/using_bazaar_with_launchpad.txt	2009-05-31 11:46:02 +0000
+++ doc/ru/tutorials/using_bazaar_with_launchpad.txt	2009-12-02 20:34:07 +0000
@@ -301,7 +301,7 @@
 Как поясняется далее, функция отслеживания объединений веток на Launchpad в
 настоящее время находится в стадии разработки. Как только эта функция будет
 готова более подходящим поведением станет автоматическое изменение состояния
-ошибки на *Fix Committed* (исправление зафиксировано). 
+ошибки на *Fix Committed* (исправление зафиксировано).
 
 
 Связь ветки с планом

=== modified file 'doc/ru/user-guide/branching_a_project.txt'
--- doc/ru/user-guide/branching_a_project.txt	2009-06-02 11:14:10 +0000
+++ doc/ru/user-guide/branching_a_project.txt	2009-12-02 20:34:07 +0000
@@ -93,7 +93,7 @@
 the latest version.
 
 As explained in later chapters, Bazaar also has support for
-`lightweight checkouts <#getting-a-lightweight-checkout>`_ 
+`lightweight checkouts <#getting-a-lightweight-checkout>`_
 of a branch, i.e. working trees with
 no local storage of history. Of course, disconnected usage
 is not available then but that's a tradeoff you can decide

=== modified file 'doc/ru/user-guide/index-plain.txt'
--- doc/ru/user-guide/index-plain.txt	2009-09-09 12:57:43 +0000
+++ doc/ru/user-guide/index-plain.txt	2009-12-02 20:34:07 +0000
@@ -87,7 +87,7 @@
 .. include:: ../../en/user-guide/server.txt
 .. include:: ../../en/user-guide/hooks.txt
 .. include:: ../../en/user-guide/version_info.txt
- 
+
 
 Краткое описание некоторых популярных плагинов
 ##############################################

=== modified file 'doc/ru/user-guide/index.txt'
--- doc/ru/user-guide/index.txt	2009-06-02 11:14:10 +0000
+++ doc/ru/user-guide/index.txt	2009-12-02 20:34:07 +0000
@@ -87,7 +87,7 @@
 .. include:: ../../en/user-guide/server.txt
 .. include:: ../../en/user-guide/hooks.txt
 .. include:: ../../en/user-guide/version_info.txt
- 
+
 
 Краткое описание некоторых популярных плагинов
 ##############################################

=== modified file 'doc/ru/user-guide/introducing_bazaar.txt'
--- doc/ru/user-guide/introducing_bazaar.txt	2009-06-02 11:14:10 +0000
+++ doc/ru/user-guide/introducing_bazaar.txt	2009-12-02 20:34:07 +0000
@@ -86,10 +86,10 @@
 
  * для сообществ с открытым исходным кодом:
 
-   * более легкое создание и поддержка изменений для сторонних разработчиков 
+   * более легкое создание и поддержка изменений для сторонних разработчиков
 
    * упрощение взаимодействия основных разработчиков со сторонними
-     разработчиками и более простая миграция сторонних разработчиков в основные 
+     разработчиками и более простая миграция сторонних разработчиков в основные
 
  * для компаний - упрощение работы с распределенными и внешними командами.
 

=== modified file 'doc/ru/user-guide/specifying_revisions.txt'
--- doc/ru/user-guide/specifying_revisions.txt	2009-06-02 11:14:10 +0000
+++ doc/ru/user-guide/specifying_revisions.txt	2009-12-02 20:34:07 +0000
@@ -128,7 +128,7 @@
 ~~~~~~~~
 
 **ancestor**:*path*
-    specifies the common ancestor between the current branch and a 
+    specifies the common ancestor between the current branch and a
     different branch. This is the same ancestor that would be used for
     merging purposes.
 

=== modified file 'doc/ru/user-guide/zen.txt'
--- doc/ru/user-guide/zen.txt	2009-06-05 20:06:14 +0000
+++ doc/ru/user-guide/zen.txt	2009-12-02 20:34:07 +0000
@@ -4,13 +4,13 @@
 Глубокое понимание Bazaar
 -------------------------
 
-Хотя Bazaar во многом похож на другие инструменты контроля версий, есть 
+Хотя Bazaar во многом похож на другие инструменты контроля версий, есть
 некоторые важные различия, которые не всегда очевидны на первый взгляд. Этот
 раздел пытается объяснить некоторые вещи, который пользователь должен знать
 чтобы разбираться в Bazaar, т.е. глубоко его понимать.
 
-Заметьте: чтобы использовать Bazaar совсем необязательно полностью понимать 
-этот раздел. Вы можете просмотреть этот раздел сейчас и вернуться к нему позже. 
+Заметьте: чтобы использовать Bazaar совсем необязательно полностью понимать
+этот раздел. Вы можете просмотреть этот раздел сейчас и вернуться к нему позже.
 
 Понимание номеров ревизий
 -------------------------
@@ -55,7 +55,7 @@
   102: Add code and tests for X
   101: Add tests for Y
   100: ...
-  
+
 Many teams use this approach because their tools make branching and merging
 difficult. As a consequence, developers update from and commit to the trunk
 frequently, minimizing integration pain by spreading it over every commit.
@@ -205,10 +205,10 @@
 ------
 
 Обычно, если вы следовали ранее полученным советам - организовать вашу работу
-в ветках и использовать объединение для сотрудничества - вы обнаружите что 
+в ветках и использовать объединение для сотрудничества - вы обнаружите что
 чаще всего Bazaar делает то что вы ожидаете.
 
-В следующих главах, мы проверим различный способы использования Bazaar, начиная 
+В следующих главах, мы проверим различный способы использования Bazaar, начиная
 с самого простого: использование Bazaar для личных проектов.
 
 ..

